#include "nv_push_cla097.h"

#include <stdio.h>

#include "util/u_math.h"





const char *P_PARSE_NV9297_MTHD(uint16_t idx) ATTRIBUTE_COLD;
void P_DUMP_NV9297_MTHD_DATA(FILE *fp, uint16_t idx, uint32_t data,
                                   const char *prefix) ATTRIBUTE_COLD;

const char*
P_PARSE_NVA097_MTHD(uint16_t idx)
{
    switch (idx) {

  
        
    case NVA097_SET_OBJECT:

        
    case NVA097_NO_OPERATION:

        
    case NVA097_SET_NOTIFY_A:

        
    case NVA097_SET_NOTIFY_B:

        
    case NVA097_NOTIFY:

        
    case NVA097_WAIT_FOR_IDLE:

        
    case NVA097_LOAD_MME_INSTRUCTION_RAM_POINTER:

        
    case NVA097_LOAD_MME_INSTRUCTION_RAM:

        
    case NVA097_LOAD_MME_START_ADDRESS_RAM_POINTER:

        
    case NVA097_LOAD_MME_START_ADDRESS_RAM:

        
    case NVA097_SET_MME_SHADOW_RAM_CONTROL:

        
    case NVA097_PEER_SEMAPHORE_RELEASE_OFFSET_UPPER:

        
    case NVA097_PEER_SEMAPHORE_RELEASE_OFFSET:

        
    case NVA097_SET_GLOBAL_RENDER_ENABLE_A:

        
    case NVA097_SET_GLOBAL_RENDER_ENABLE_B:

        
    case NVA097_SET_GLOBAL_RENDER_ENABLE_C:

        
    case NVA097_SEND_GO_IDLE:

        
    case NVA097_PM_TRIGGER:

        
    case NVA097_SET_INSTRUMENTATION_METHOD_HEADER:

        
    case NVA097_SET_INSTRUMENTATION_METHOD_DATA:

        
    case NVA097_RUN_DS_NOW:

        
    case NVA097_SET_OPPORTUNISTIC_EARLY_Z_HYSTERESIS:

        
    case NVA097_SET_RASTER_PIPE_SYNC_CONTROL:

        
    case NVA097_SET_ALIASED_LINE_WIDTH_ENABLE:

        
    case NVA097_SET_API_MANDATED_EARLY_Z:

        
    case NVA097_SET_GS_DM_FIFO:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_PREFETCH_READ_REQUESTS:

        

        

        

        

        

        

        

        

        

        

        
    case NVA097_SET_TASK_CIRCULAR_BUFFER_THROTTLE:

        
    case NVA097_SET_PRIM_CIRCULAR_BUFFER_THROTTLE:

        
    case NVA097_FLUSH_AND_INVALIDATE_ROP_MINI_CACHE:

        
    case NVA097_SET_SURFACE_CLIP_ID_BLOCK_SIZE:

        
    case NVA097_SET_ALPHA_CIRCULAR_BUFFER_SIZE:

        
    case NVA097_SET_ZCULL_ROP_BYPASS:

        
    case NVA097_SET_ZCULL_SUBREGION:

        
    case NVA097_SET_RASTER_BOUNDING_BOX:

        
    case NVA097_PEER_SEMAPHORE_RELEASE:

        
    case NVA097_SET_ZCULL_SUBREGION_ALLOCATION:

        
    case NVA097_ASSIGN_ZCULL_SUBREGIONS:

        
    case NVA097_SET_PS_OUTPUT_SAMPLE_MASK_USAGE:

        
    case NVA097_DRAW_ZERO_INDEX:

        
    case NVA097_SET_L1_CONFIGURATION:

        
    case NVA097_SET_RENDER_ENABLE_CONTROL:

        
    case NVA097_SET_IEEE_CLEAN_UPDATE:

        
    case NVA097_SET_SNAP_GRID_LINE:

        
    case NVA097_SET_SNAP_GRID_NON_LINE:

        
    case NVA097_SET_TESSELLATION_PARAMETERS:

        
    case NVA097_SET_TESSELLATION_LOD_U0_OR_DENSITY:

        
    case NVA097_SET_TESSELLATION_LOD_V0_OR_DETAIL:

        
    case NVA097_SET_TESSELLATION_LOD_U1_OR_W0:

        
    case NVA097_SET_TESSELLATION_LOD_V1:

        
    case NVA097_SET_TG_LOD_INTERIOR_U:

        
    case NVA097_SET_TG_LOD_INTERIOR_V:

        
    case NVA097_RESERVED_TG07:

        
    case NVA097_RESERVED_TG08:

        
    case NVA097_RESERVED_TG09:

        
    case NVA097_RESERVED_TG10:

        
    case NVA097_RESERVED_TG11:

        
    case NVA097_RESERVED_TG12:

        
    case NVA097_RESERVED_TG13:

        
    case NVA097_RESERVED_TG14:

        
    case NVA097_RESERVED_TG15:

        
    case NVA097_SET_SUBTILING_PERF_KNOB_A:

        
    case NVA097_SET_SUBTILING_PERF_KNOB_B:

        
    case NVA097_SET_SUBTILING_PERF_KNOB_C:

        
    case NVA097_SET_ZCULL_SUBREGION_TO_REPORT:

        
    case NVA097_SET_ZCULL_SUBREGION_REPORT_TYPE:

        
    case NVA097_SET_BALANCED_PRIMITIVE_WORKLOAD:

        
    case NVA097_SET_MAX_PATCHES_PER_BATCH:

        
    case NVA097_SET_RASTER_ENABLE:

        
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(0):
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(1):
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(2):
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(0):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(1):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(2):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(0):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(1):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(2):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(0):
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(1):
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(2):
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(0):
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(1):
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(2):
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(3):

        

        
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(0):
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(1):
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(2):
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(3):

        
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(0):
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(1):
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(2):
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(3):

        
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(0):
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(1):
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(2):
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(3):

        
    case NVA097_SET_RASTER_INPUT:

        
    case NVA097_SET_STREAM_OUTPUT:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_TOPOLOGY_CHANGE:

        
    case NVA097_SET_ALPHA_FRACTION:

        
    case NVA097_SET_HYBRID_ANTI_ALIAS_CONTROL:

        
    case NVA097_SET_MAX_TI_WARPS_PER_BATCH:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_WINDOW:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_A:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_B:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_C:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_D:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_E:

        
    case NVA097_SET_COLOR_ZERO_BANDWIDTH_CLEAR:

        
    case NVA097_SET_Z_ZERO_BANDWIDTH_CLEAR:

        

        
    case NVA097_SET_ZCULL_REGION_SIZE_A:

        
    case NVA097_SET_ZCULL_REGION_SIZE_B:

        
    case NVA097_SET_ZCULL_REGION_SIZE_C:

        
    case NVA097_SET_ZCULL_REGION_PIXEL_OFFSET_C:

        
    case NVA097_SET_CULL_BEFORE_FETCH:

        
    case NVA097_SET_ZCULL_REGION_LOCATION:

        
    case NVA097_SET_ZCULL_REGION_ALIQUOTS:

        
    case NVA097_SET_ZCULL_STORAGE_A:

        
    case NVA097_SET_ZCULL_STORAGE_B:

        
    case NVA097_SET_ZCULL_STORAGE_C:

        
    case NVA097_SET_ZCULL_STORAGE_D:

        
    case NVA097_SET_ZT_READ_ONLY:

        
    case NVA097_SET_COLOR_TARGET_A(0):
    case NVA097_SET_COLOR_TARGET_A(1):
    case NVA097_SET_COLOR_TARGET_A(2):
    case NVA097_SET_COLOR_TARGET_A(3):
    case NVA097_SET_COLOR_TARGET_A(4):
    case NVA097_SET_COLOR_TARGET_A(5):
    case NVA097_SET_COLOR_TARGET_A(6):
    case NVA097_SET_COLOR_TARGET_A(7):

        
    case NVA097_SET_COLOR_TARGET_B(0):
    case NVA097_SET_COLOR_TARGET_B(1):
    case NVA097_SET_COLOR_TARGET_B(2):
    case NVA097_SET_COLOR_TARGET_B(3):
    case NVA097_SET_COLOR_TARGET_B(4):
    case NVA097_SET_COLOR_TARGET_B(5):
    case NVA097_SET_COLOR_TARGET_B(6):
    case NVA097_SET_COLOR_TARGET_B(7):

        
    case NVA097_SET_COLOR_TARGET_WIDTH(0):
    case NVA097_SET_COLOR_TARGET_WIDTH(1):
    case NVA097_SET_COLOR_TARGET_WIDTH(2):
    case NVA097_SET_COLOR_TARGET_WIDTH(3):
    case NVA097_SET_COLOR_TARGET_WIDTH(4):
    case NVA097_SET_COLOR_TARGET_WIDTH(5):
    case NVA097_SET_COLOR_TARGET_WIDTH(6):
    case NVA097_SET_COLOR_TARGET_WIDTH(7):

        
    case NVA097_SET_COLOR_TARGET_HEIGHT(0):
    case NVA097_SET_COLOR_TARGET_HEIGHT(1):
    case NVA097_SET_COLOR_TARGET_HEIGHT(2):
    case NVA097_SET_COLOR_TARGET_HEIGHT(3):
    case NVA097_SET_COLOR_TARGET_HEIGHT(4):
    case NVA097_SET_COLOR_TARGET_HEIGHT(5):
    case NVA097_SET_COLOR_TARGET_HEIGHT(6):
    case NVA097_SET_COLOR_TARGET_HEIGHT(7):

        
    case NVA097_SET_COLOR_TARGET_FORMAT(0):
    case NVA097_SET_COLOR_TARGET_FORMAT(1):
    case NVA097_SET_COLOR_TARGET_FORMAT(2):
    case NVA097_SET_COLOR_TARGET_FORMAT(3):
    case NVA097_SET_COLOR_TARGET_FORMAT(4):
    case NVA097_SET_COLOR_TARGET_FORMAT(5):
    case NVA097_SET_COLOR_TARGET_FORMAT(6):
    case NVA097_SET_COLOR_TARGET_FORMAT(7):

        
    case NVA097_SET_COLOR_TARGET_MEMORY(0):
    case NVA097_SET_COLOR_TARGET_MEMORY(1):
    case NVA097_SET_COLOR_TARGET_MEMORY(2):
    case NVA097_SET_COLOR_TARGET_MEMORY(3):
    case NVA097_SET_COLOR_TARGET_MEMORY(4):
    case NVA097_SET_COLOR_TARGET_MEMORY(5):
    case NVA097_SET_COLOR_TARGET_MEMORY(6):
    case NVA097_SET_COLOR_TARGET_MEMORY(7):

        
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(0):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(1):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(2):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(3):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(4):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(5):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(6):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(7):

        
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(0):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(1):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(2):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(3):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(4):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(5):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(6):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(7):

        
    case NVA097_SET_COLOR_TARGET_LAYER(0):
    case NVA097_SET_COLOR_TARGET_LAYER(1):
    case NVA097_SET_COLOR_TARGET_LAYER(2):
    case NVA097_SET_COLOR_TARGET_LAYER(3):
    case NVA097_SET_COLOR_TARGET_LAYER(4):
    case NVA097_SET_COLOR_TARGET_LAYER(5):
    case NVA097_SET_COLOR_TARGET_LAYER(6):
    case NVA097_SET_COLOR_TARGET_LAYER(7):

        
    case NVA097_SET_COLOR_TARGET_MARK(0):
    case NVA097_SET_COLOR_TARGET_MARK(1):
    case NVA097_SET_COLOR_TARGET_MARK(2):
    case NVA097_SET_COLOR_TARGET_MARK(3):
    case NVA097_SET_COLOR_TARGET_MARK(4):
    case NVA097_SET_COLOR_TARGET_MARK(5):
    case NVA097_SET_COLOR_TARGET_MARK(6):
    case NVA097_SET_COLOR_TARGET_MARK(7):

        
    case NVA097_SET_VIEWPORT_SCALE_X(0):
    case NVA097_SET_VIEWPORT_SCALE_X(1):
    case NVA097_SET_VIEWPORT_SCALE_X(2):
    case NVA097_SET_VIEWPORT_SCALE_X(3):
    case NVA097_SET_VIEWPORT_SCALE_X(4):
    case NVA097_SET_VIEWPORT_SCALE_X(5):
    case NVA097_SET_VIEWPORT_SCALE_X(6):
    case NVA097_SET_VIEWPORT_SCALE_X(7):
    case NVA097_SET_VIEWPORT_SCALE_X(8):
    case NVA097_SET_VIEWPORT_SCALE_X(9):
    case NVA097_SET_VIEWPORT_SCALE_X(10):
    case NVA097_SET_VIEWPORT_SCALE_X(11):
    case NVA097_SET_VIEWPORT_SCALE_X(12):
    case NVA097_SET_VIEWPORT_SCALE_X(13):
    case NVA097_SET_VIEWPORT_SCALE_X(14):
    case NVA097_SET_VIEWPORT_SCALE_X(15):

        
    case NVA097_SET_VIEWPORT_SCALE_Y(0):
    case NVA097_SET_VIEWPORT_SCALE_Y(1):
    case NVA097_SET_VIEWPORT_SCALE_Y(2):
    case NVA097_SET_VIEWPORT_SCALE_Y(3):
    case NVA097_SET_VIEWPORT_SCALE_Y(4):
    case NVA097_SET_VIEWPORT_SCALE_Y(5):
    case NVA097_SET_VIEWPORT_SCALE_Y(6):
    case NVA097_SET_VIEWPORT_SCALE_Y(7):
    case NVA097_SET_VIEWPORT_SCALE_Y(8):
    case NVA097_SET_VIEWPORT_SCALE_Y(9):
    case NVA097_SET_VIEWPORT_SCALE_Y(10):
    case NVA097_SET_VIEWPORT_SCALE_Y(11):
    case NVA097_SET_VIEWPORT_SCALE_Y(12):
    case NVA097_SET_VIEWPORT_SCALE_Y(13):
    case NVA097_SET_VIEWPORT_SCALE_Y(14):
    case NVA097_SET_VIEWPORT_SCALE_Y(15):

        
    case NVA097_SET_VIEWPORT_SCALE_Z(0):
    case NVA097_SET_VIEWPORT_SCALE_Z(1):
    case NVA097_SET_VIEWPORT_SCALE_Z(2):
    case NVA097_SET_VIEWPORT_SCALE_Z(3):
    case NVA097_SET_VIEWPORT_SCALE_Z(4):
    case NVA097_SET_VIEWPORT_SCALE_Z(5):
    case NVA097_SET_VIEWPORT_SCALE_Z(6):
    case NVA097_SET_VIEWPORT_SCALE_Z(7):
    case NVA097_SET_VIEWPORT_SCALE_Z(8):
    case NVA097_SET_VIEWPORT_SCALE_Z(9):
    case NVA097_SET_VIEWPORT_SCALE_Z(10):
    case NVA097_SET_VIEWPORT_SCALE_Z(11):
    case NVA097_SET_VIEWPORT_SCALE_Z(12):
    case NVA097_SET_VIEWPORT_SCALE_Z(13):
    case NVA097_SET_VIEWPORT_SCALE_Z(14):
    case NVA097_SET_VIEWPORT_SCALE_Z(15):

        
    case NVA097_SET_VIEWPORT_OFFSET_X(0):
    case NVA097_SET_VIEWPORT_OFFSET_X(1):
    case NVA097_SET_VIEWPORT_OFFSET_X(2):
    case NVA097_SET_VIEWPORT_OFFSET_X(3):
    case NVA097_SET_VIEWPORT_OFFSET_X(4):
    case NVA097_SET_VIEWPORT_OFFSET_X(5):
    case NVA097_SET_VIEWPORT_OFFSET_X(6):
    case NVA097_SET_VIEWPORT_OFFSET_X(7):
    case NVA097_SET_VIEWPORT_OFFSET_X(8):
    case NVA097_SET_VIEWPORT_OFFSET_X(9):
    case NVA097_SET_VIEWPORT_OFFSET_X(10):
    case NVA097_SET_VIEWPORT_OFFSET_X(11):
    case NVA097_SET_VIEWPORT_OFFSET_X(12):
    case NVA097_SET_VIEWPORT_OFFSET_X(13):
    case NVA097_SET_VIEWPORT_OFFSET_X(14):
    case NVA097_SET_VIEWPORT_OFFSET_X(15):

        
    case NVA097_SET_VIEWPORT_OFFSET_Y(0):
    case NVA097_SET_VIEWPORT_OFFSET_Y(1):
    case NVA097_SET_VIEWPORT_OFFSET_Y(2):
    case NVA097_SET_VIEWPORT_OFFSET_Y(3):
    case NVA097_SET_VIEWPORT_OFFSET_Y(4):
    case NVA097_SET_VIEWPORT_OFFSET_Y(5):
    case NVA097_SET_VIEWPORT_OFFSET_Y(6):
    case NVA097_SET_VIEWPORT_OFFSET_Y(7):
    case NVA097_SET_VIEWPORT_OFFSET_Y(8):
    case NVA097_SET_VIEWPORT_OFFSET_Y(9):
    case NVA097_SET_VIEWPORT_OFFSET_Y(10):
    case NVA097_SET_VIEWPORT_OFFSET_Y(11):
    case NVA097_SET_VIEWPORT_OFFSET_Y(12):
    case NVA097_SET_VIEWPORT_OFFSET_Y(13):
    case NVA097_SET_VIEWPORT_OFFSET_Y(14):
    case NVA097_SET_VIEWPORT_OFFSET_Y(15):

        
    case NVA097_SET_VIEWPORT_OFFSET_Z(0):
    case NVA097_SET_VIEWPORT_OFFSET_Z(1):
    case NVA097_SET_VIEWPORT_OFFSET_Z(2):
    case NVA097_SET_VIEWPORT_OFFSET_Z(3):
    case NVA097_SET_VIEWPORT_OFFSET_Z(4):
    case NVA097_SET_VIEWPORT_OFFSET_Z(5):
    case NVA097_SET_VIEWPORT_OFFSET_Z(6):
    case NVA097_SET_VIEWPORT_OFFSET_Z(7):
    case NVA097_SET_VIEWPORT_OFFSET_Z(8):
    case NVA097_SET_VIEWPORT_OFFSET_Z(9):
    case NVA097_SET_VIEWPORT_OFFSET_Z(10):
    case NVA097_SET_VIEWPORT_OFFSET_Z(11):
    case NVA097_SET_VIEWPORT_OFFSET_Z(12):
    case NVA097_SET_VIEWPORT_OFFSET_Z(13):
    case NVA097_SET_VIEWPORT_OFFSET_Z(14):
    case NVA097_SET_VIEWPORT_OFFSET_Z(15):

        
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(0):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(1):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(2):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(3):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(4):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(5):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(6):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(7):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(8):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(9):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(10):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(11):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(12):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(13):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(14):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(15):

        
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(0):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(1):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(2):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(3):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(4):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(5):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(6):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(7):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(8):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(9):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(10):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(11):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(12):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(13):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(14):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(15):

        
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(0):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(1):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(2):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(3):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(4):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(5):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(6):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(7):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(8):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(9):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(10):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(11):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(12):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(13):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(14):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(15):

        
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(0):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(1):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(2):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(3):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(4):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(5):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(6):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(7):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(8):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(9):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(10):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(11):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(12):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(13):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(14):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(15):

        
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(0):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(1):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(2):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(3):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(4):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(5):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(6):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(7):

        
    case NVA097_SET_WINDOW_CLIP_VERTICAL(0):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(1):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(2):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(3):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(4):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(5):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(6):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(7):

        
    case NVA097_SET_CLIP_ID_EXTENT_X(0):
    case NVA097_SET_CLIP_ID_EXTENT_X(1):
    case NVA097_SET_CLIP_ID_EXTENT_X(2):
    case NVA097_SET_CLIP_ID_EXTENT_X(3):

        
    case NVA097_SET_CLIP_ID_EXTENT_Y(0):
    case NVA097_SET_CLIP_ID_EXTENT_Y(1):
    case NVA097_SET_CLIP_ID_EXTENT_Y(2):
    case NVA097_SET_CLIP_ID_EXTENT_Y(3):

        
    case NVA097_SET_MAX_STREAM_OUTPUT_GS_INSTANCES_PER_TASK:

        
    case NVA097_SET_API_VISIBLE_CALL_LIMIT:

        
    case NVA097_SET_STATISTICS_COUNTER:

        
    case NVA097_SET_CLEAR_RECT_HORIZONTAL:

        
    case NVA097_SET_CLEAR_RECT_VERTICAL:

        
    case NVA097_SET_VERTEX_ARRAY_START:

        
    case NVA097_DRAW_VERTEX_ARRAY:

        
    case NVA097_SET_VIEWPORT_Z_CLIP:

        
    case NVA097_SET_COLOR_CLEAR_VALUE(0):
    case NVA097_SET_COLOR_CLEAR_VALUE(1):
    case NVA097_SET_COLOR_CLEAR_VALUE(2):
    case NVA097_SET_COLOR_CLEAR_VALUE(3):

        
    case NVA097_SET_Z_CLEAR_VALUE:

        
    case NVA097_SET_SHADER_CACHE_CONTROL:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_ENABLE:

        
    case NVA097_SET_STENCIL_CLEAR_VALUE:

        
    case NVA097_SET_FRONT_POLYGON_MODE:

        
    case NVA097_SET_BACK_POLYGON_MODE:

        
    case NVA097_SET_POLY_SMOOTH:

        
    case NVA097_SET_ZT_MARK:

        
    case NVA097_SET_ZCULL_DIR_FORMAT:

        
    case NVA097_SET_POLY_OFFSET_POINT:

        
    case NVA097_SET_POLY_OFFSET_LINE:

        
    case NVA097_SET_POLY_OFFSET_FILL:

        
    case NVA097_SET_PATCH:

        
    case NVA097_SET_ZCULL_CRITERION:

        
    case NVA097_SET_SM_TIMEOUT_INTERVAL:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_VERTEX_ARRAY:

        
    case NVA097_SET_DRAW_INLINE_VERTEX_VAB_UPDATE:

        
    case NVA097_SET_WINDOW_OFFSET_X:

        
    case NVA097_SET_WINDOW_OFFSET_Y:

        
    case NVA097_SET_SCISSOR_ENABLE(0):
    case NVA097_SET_SCISSOR_ENABLE(1):
    case NVA097_SET_SCISSOR_ENABLE(2):
    case NVA097_SET_SCISSOR_ENABLE(3):
    case NVA097_SET_SCISSOR_ENABLE(4):
    case NVA097_SET_SCISSOR_ENABLE(5):
    case NVA097_SET_SCISSOR_ENABLE(6):
    case NVA097_SET_SCISSOR_ENABLE(7):
    case NVA097_SET_SCISSOR_ENABLE(8):
    case NVA097_SET_SCISSOR_ENABLE(9):
    case NVA097_SET_SCISSOR_ENABLE(10):
    case NVA097_SET_SCISSOR_ENABLE(11):
    case NVA097_SET_SCISSOR_ENABLE(12):
    case NVA097_SET_SCISSOR_ENABLE(13):
    case NVA097_SET_SCISSOR_ENABLE(14):
    case NVA097_SET_SCISSOR_ENABLE(15):

        
    case NVA097_SET_SCISSOR_HORIZONTAL(0):
    case NVA097_SET_SCISSOR_HORIZONTAL(1):
    case NVA097_SET_SCISSOR_HORIZONTAL(2):
    case NVA097_SET_SCISSOR_HORIZONTAL(3):
    case NVA097_SET_SCISSOR_HORIZONTAL(4):
    case NVA097_SET_SCISSOR_HORIZONTAL(5):
    case NVA097_SET_SCISSOR_HORIZONTAL(6):
    case NVA097_SET_SCISSOR_HORIZONTAL(7):
    case NVA097_SET_SCISSOR_HORIZONTAL(8):
    case NVA097_SET_SCISSOR_HORIZONTAL(9):
    case NVA097_SET_SCISSOR_HORIZONTAL(10):
    case NVA097_SET_SCISSOR_HORIZONTAL(11):
    case NVA097_SET_SCISSOR_HORIZONTAL(12):
    case NVA097_SET_SCISSOR_HORIZONTAL(13):
    case NVA097_SET_SCISSOR_HORIZONTAL(14):
    case NVA097_SET_SCISSOR_HORIZONTAL(15):

        
    case NVA097_SET_SCISSOR_VERTICAL(0):
    case NVA097_SET_SCISSOR_VERTICAL(1):
    case NVA097_SET_SCISSOR_VERTICAL(2):
    case NVA097_SET_SCISSOR_VERTICAL(3):
    case NVA097_SET_SCISSOR_VERTICAL(4):
    case NVA097_SET_SCISSOR_VERTICAL(5):
    case NVA097_SET_SCISSOR_VERTICAL(6):
    case NVA097_SET_SCISSOR_VERTICAL(7):
    case NVA097_SET_SCISSOR_VERTICAL(8):
    case NVA097_SET_SCISSOR_VERTICAL(9):
    case NVA097_SET_SCISSOR_VERTICAL(10):
    case NVA097_SET_SCISSOR_VERTICAL(11):
    case NVA097_SET_SCISSOR_VERTICAL(12):
    case NVA097_SET_SCISSOR_VERTICAL(13):
    case NVA097_SET_SCISSOR_VERTICAL(14):
    case NVA097_SET_SCISSOR_VERTICAL(15):

        

        
    case NVA097_SET_BACK_STENCIL_FUNC_REF:

        
    case NVA097_SET_BACK_STENCIL_MASK:

        
    case NVA097_SET_BACK_STENCIL_FUNC_MASK:

        
    case NVA097_SET_VERTEX_STREAM_SUBSTITUTE_A:

        
    case NVA097_SET_VERTEX_STREAM_SUBSTITUTE_B:

        
    case NVA097_SET_LINE_MODE_POLYGON_CLIP:

        
    case NVA097_SET_SINGLE_CT_WRITE_CONTROL:

        
    case NVA097_SET_VTG_WARP_WATERMARKS:

        
    case NVA097_SET_DEPTH_BOUNDS_MIN:

        
    case NVA097_SET_DEPTH_BOUNDS_MAX:

        
    case NVA097_SET_CT_MRT_ENABLE:

        
    case NVA097_SET_NONMULTISAMPLED_Z:

        
    case NVA097_SET_SAMPLE_MASK_X0_Y0:

        
    case NVA097_SET_SAMPLE_MASK_X1_Y0:

        
    case NVA097_SET_SAMPLE_MASK_X0_Y1:

        
    case NVA097_SET_SAMPLE_MASK_X1_Y1:

        
    case NVA097_SET_SURFACE_CLIP_ID_MEMORY_A:

        
    case NVA097_SET_SURFACE_CLIP_ID_MEMORY_B:

        
    case NVA097_SET_BLEND_OPT_CONTROL:

        
    case NVA097_SET_ZT_A:

        
    case NVA097_SET_ZT_B:

        
    case NVA097_SET_ZT_FORMAT:

        
    case NVA097_SET_ZT_BLOCK_SIZE:

        
    case NVA097_SET_ZT_ARRAY_PITCH:

        
    case NVA097_SET_SURFACE_CLIP_HORIZONTAL:

        
    case NVA097_SET_SURFACE_CLIP_VERTICAL:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_VAF_REQUESTS:

        
    case NVA097_SET_TESSELLATION_CUT_HEIGHT:

        
    case NVA097_SET_MAX_GS_INSTANCES_PER_TASK:

        
    case NVA097_SET_MAX_GS_OUTPUT_VERTICES_PER_TASK:

        
    case NVA097_SET_GS_OUTPUT_CB_STORAGE_MULTIPLIER:

        
    case NVA097_SET_BETA_CB_STORAGE_CONSTRAINT:

        
    case NVA097_SET_TI_OUTPUT_CB_STORAGE_MULTIPLIER:

        
    case NVA097_SET_ALPHA_CB_STORAGE_CONSTRAINT:

        
    case NVA097_SET_SPARE_NOOP00:

        
    case NVA097_SET_SPARE_NOOP01:

        
    case NVA097_SET_SPARE_NOOP02:

        
    case NVA097_SET_SPARE_NOOP03:

        
    case NVA097_SET_SPARE_NOOP04:

        
    case NVA097_SET_SPARE_NOOP05:

        
    case NVA097_SET_SPARE_NOOP06:

        
    case NVA097_SET_SPARE_NOOP07:

        
    case NVA097_SET_SPARE_NOOP08:

        
    case NVA097_SET_SPARE_NOOP09:

        
    case NVA097_SET_SPARE_NOOP10:

        
    case NVA097_SET_SPARE_NOOP11:

        
    case NVA097_SET_SPARE_NOOP12:

        
    case NVA097_SET_SPARE_NOOP13:

        
    case NVA097_SET_SPARE_NOOP14:

        
    case NVA097_SET_SPARE_NOOP15:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_UNORM8:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_UNORM10:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_UNORM16:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_FP11:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_FP16:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_SRGB8:

        
    case NVA097_SET_CLEAR_SURFACE_CONTROL:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_NONINTERLOCKED_READ_REQUESTS:

        
    case NVA097_NO_OPERATION_DATA_HI:

        
    case NVA097_SET_DEPTH_BIAS_CONTROL:

        
    case NVA097_PM_TRIGGER_END:

        
    case NVA097_SET_VERTEX_ID_BASE:

        

        

        
    case NVA097_SET_BLEND_PER_FORMAT_ENABLE:

        
    case NVA097_FLUSH_PENDING_WRITES:

        
    case NVA097_SET_VAB_DATA_CONTROL:

        

        
    case NVA097_SET_VERTEX_ATTRIBUTE_A(0):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(1):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(2):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(3):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(4):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(5):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(6):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(7):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(8):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(9):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(10):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(11):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(12):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(13):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(14):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(15):

        
    case NVA097_SET_VERTEX_ATTRIBUTE_B(0):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(1):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(2):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(3):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(4):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(5):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(6):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(7):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(8):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(9):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(10):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(11):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(12):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(13):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(14):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(15):

        
    case NVA097_DRAW_VERTEX_ARRAY_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_VERTEX_ARRAY_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_SET_CT_SELECT:

        
    case NVA097_SET_COMPRESSION_THRESHOLD:

        
    case NVA097_SET_ZT_SIZE_A:

        
    case NVA097_SET_ZT_SIZE_B:

        
    case NVA097_SET_ZT_SIZE_C:

        
    case NVA097_SET_SAMPLER_BINDING:

        
    case NVA097_DRAW_AUTO:

        
    case NVA097_SET_CIRCULAR_BUFFER_SIZE:

        
    case NVA097_SET_VTG_REGISTER_WATERMARKS:

        
    case NVA097_INVALIDATE_TEXTURE_DATA_CACHE_NO_WFI:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_INTERLOCKED_READ_REQUESTS:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_INDEX_TOPOLOGY_CHANGE:

        
    case NVA097_SET_SHADER_SCHEDULING:

        
    case NVA097_CLEAR_ZCULL_REGION:

        
    case NVA097_SET_DEPTH_TEST:

        
    case NVA097_SET_FILL_MODE:

        
    case NVA097_SET_SHADE_MODE:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_NONINTERLOCKED_WRITE_REQUESTS:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_INTERLOCKED_WRITE_REQUESTS:

        
    case NVA097_SET_ALPHA_TO_COVERAGE_DITHER_CONTROL:

        
    case NVA097_SET_BLEND_STATE_PER_TARGET:

        
    case NVA097_SET_DEPTH_WRITE:

        
    case NVA097_SET_ALPHA_TEST:

        
    case NVA097_SET_INLINE_INDEX4X8_ALIGN:

        
    case NVA097_DRAW_INLINE_INDEX4X8:

        
    case NVA097_D3D_SET_CULL_MODE:

        
    case NVA097_SET_DEPTH_FUNC:

        
    case NVA097_SET_ALPHA_REF:

        
    case NVA097_SET_ALPHA_FUNC:

        
    case NVA097_SET_DRAW_AUTO_STRIDE:

        
    case NVA097_SET_BLEND_CONST_RED:

        
    case NVA097_SET_BLEND_CONST_GREEN:

        
    case NVA097_SET_BLEND_CONST_BLUE:

        
    case NVA097_SET_BLEND_CONST_ALPHA:

        
    case NVA097_INVALIDATE_SAMPLER_CACHE:

        
    case NVA097_INVALIDATE_TEXTURE_HEADER_CACHE:

        
    case NVA097_SET_BLEND_SEPARATE_FOR_ALPHA:

        
    case NVA097_SET_BLEND_COLOR_OP:

        
    case NVA097_SET_BLEND_COLOR_SOURCE_COEFF:

        
    case NVA097_SET_BLEND_COLOR_DEST_COEFF:

        
    case NVA097_SET_BLEND_ALPHA_OP:

        
    case NVA097_SET_BLEND_ALPHA_SOURCE_COEFF:

        
    case NVA097_SET_GLOBAL_COLOR_KEY:

        
    case NVA097_SET_BLEND_ALPHA_DEST_COEFF:

        
    case NVA097_SET_SINGLE_ROP_CONTROL:

        
    case NVA097_SET_BLEND(0):
    case NVA097_SET_BLEND(1):
    case NVA097_SET_BLEND(2):
    case NVA097_SET_BLEND(3):
    case NVA097_SET_BLEND(4):
    case NVA097_SET_BLEND(5):
    case NVA097_SET_BLEND(6):
    case NVA097_SET_BLEND(7):

        
    case NVA097_SET_STENCIL_TEST:

        
    case NVA097_SET_STENCIL_OP_FAIL:

        
    case NVA097_SET_STENCIL_OP_ZFAIL:

        
    case NVA097_SET_STENCIL_OP_ZPASS:

        
    case NVA097_SET_STENCIL_FUNC:

        
    case NVA097_SET_STENCIL_FUNC_REF:

        
    case NVA097_SET_STENCIL_FUNC_MASK:

        
    case NVA097_SET_STENCIL_MASK:

        
    case NVA097_SET_DRAW_AUTO_START:

        
    case NVA097_SET_PS_SATURATE:

        
    case NVA097_SET_WINDOW_ORIGIN:

        
    case NVA097_SET_LINE_WIDTH_FLOAT:

        
    case NVA097_SET_ALIASED_LINE_WIDTH_FLOAT:

        
    case NVA097_SET_LINE_MULTISAMPLE_OVERRIDE:

        
    case NVA097_SET_ALPHA_HYSTERESIS:

        
    case NVA097_INVALIDATE_SAMPLER_CACHE_NO_WFI:

        
    case NVA097_INVALIDATE_TEXTURE_HEADER_CACHE_NO_WFI:

        
    case NVA097_INVALIDATE_DA_DMA_CACHE:

        
    case NVA097_SET_GLOBAL_BASE_VERTEX_INDEX:

        
    case NVA097_SET_GLOBAL_BASE_INSTANCE_INDEX:

        
    case NVA097_SET_PS_WARP_WATERMARKS:

        
    case NVA097_SET_PS_REGISTER_WATERMARKS:

        
    case NVA097_STORE_ZCULL:

        
    case NVA097_LOAD_ZCULL:

        
    case NVA097_SET_SURFACE_CLIP_ID_HEIGHT:

        
    case NVA097_SET_CLIP_ID_CLEAR_RECT_HORIZONTAL:

        
    case NVA097_SET_CLIP_ID_CLEAR_RECT_VERTICAL:

        
    case NVA097_SET_USER_CLIP_ENABLE:

        
    case NVA097_SET_ZPASS_PIXEL_COUNT:

        
    case NVA097_SET_POINT_SIZE:

        
    case NVA097_SET_ZCULL_STATS:

        
    case NVA097_SET_POINT_SPRITE:

        
    case NVA097_SET_SHADER_EXCEPTIONS:

        
    case NVA097_CLEAR_REPORT_VALUE:

        
    case NVA097_SET_ANTI_ALIAS_ENABLE:

        
    case NVA097_SET_ZT_SELECT:

        
    case NVA097_SET_ANTI_ALIAS_ALPHA_CONTROL:

        
    case NVA097_SET_RENDER_ENABLE_A:

        
    case NVA097_SET_RENDER_ENABLE_B:

        
    case NVA097_SET_RENDER_ENABLE_C:

        
    case NVA097_SET_TEX_SAMPLER_POOL_A:

        
    case NVA097_SET_TEX_SAMPLER_POOL_B:

        
    case NVA097_SET_TEX_SAMPLER_POOL_C:

        
    case NVA097_SET_SLOPE_SCALE_DEPTH_BIAS:

        
    case NVA097_SET_ANTI_ALIASED_LINE:

        
    case NVA097_SET_TEX_HEADER_POOL_A:

        
    case NVA097_SET_TEX_HEADER_POOL_B:

        
    case NVA097_SET_TEX_HEADER_POOL_C:

        
    case NVA097_SET_ACTIVE_ZCULL_REGION:

        
    case NVA097_SET_TWO_SIDED_STENCIL_TEST:

        
    case NVA097_SET_BACK_STENCIL_OP_FAIL:

        
    case NVA097_SET_BACK_STENCIL_OP_ZFAIL:

        
    case NVA097_SET_BACK_STENCIL_OP_ZPASS:

        
    case NVA097_SET_BACK_STENCIL_FUNC:

        
    case NVA097_SET_SRGB_WRITE:

        
    case NVA097_SET_DEPTH_BIAS:

        
    case NVA097_SET_ZCULL_REGION_FORMAT:

        
    case NVA097_SET_RT_LAYER:

        
    case NVA097_SET_ANTI_ALIAS:

        
    case NVA097_SET_EDGE_FLAG:

        
    case NVA097_DRAW_INLINE_INDEX:

        
    case NVA097_SET_INLINE_INDEX2X16_ALIGN:

        
    case NVA097_DRAW_INLINE_INDEX2X16:

        
    case NVA097_SET_VERTEX_GLOBAL_BASE_OFFSET_A:

        
    case NVA097_SET_VERTEX_GLOBAL_BASE_OFFSET_B:

        
    case NVA097_SET_ZCULL_REGION_PIXEL_OFFSET_A:

        
    case NVA097_SET_ZCULL_REGION_PIXEL_OFFSET_B:

        
    case NVA097_SET_POINT_SPRITE_SELECT:

        
    case NVA097_SET_PROGRAM_REGION_A:

        
    case NVA097_SET_PROGRAM_REGION_B:

        
    case NVA097_SET_ATTRIBUTE_DEFAULT:

        
    case NVA097_END:

        
    case NVA097_BEGIN:

        
    case NVA097_SET_VERTEX_ID_COPY:

        
    case NVA097_ADD_TO_PRIMITIVE_ID:

        
    case NVA097_LOAD_PRIMITIVE_ID:

        
    case NVA097_SET_SHADER_BASED_CULL:

        
    case NVA097_SET_VAB_PAGE:

        
    case NVA097_DRAW_INLINE_VERTEX:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_INDEX:

        
    case NVA097_SET_DA_OUTPUT:

        
    case NVA097_SET_ANTI_ALIASED_POINT:

        
    case NVA097_SET_POINT_CENTER_MODE:

        
    case NVA097_SET_LINE_SMOOTH_PARAMETERS:

        
    case NVA097_SET_LINE_STIPPLE:

        

        
    case NVA097_SET_LINE_STIPPLE_PARAMETERS:

        
    case NVA097_SET_PROVOKING_VERTEX:

        
    case NVA097_SET_TWO_SIDED_LIGHT:

        
    case NVA097_SET_POLYGON_STIPPLE:

        
    case NVA097_LAUNCH_VERTEX:

        
    case NVA097_SET_SPH_VERSION:

        
    case NVA097_CHECK_SPH_VERSION:

        
    case NVA097_SET_ALPHA_TO_COVERAGE_OVERRIDE:

        

        
    case NVA097_SET_AAM_VERSION:

        
    case NVA097_CHECK_AAM_VERSION:

        
    case NVA097_SET_ZT_LAYER:

        
    case NVA097_SET_VAB_MEMORY_AREA_A:

        
    case NVA097_SET_VAB_MEMORY_AREA_B:

        
    case NVA097_SET_VAB_MEMORY_AREA_C:

        
    case NVA097_SET_INDEX_BUFFER_A:

        
    case NVA097_SET_INDEX_BUFFER_B:

        
    case NVA097_SET_INDEX_BUFFER_C:

        
    case NVA097_SET_INDEX_BUFFER_D:

        
    case NVA097_SET_INDEX_BUFFER_E:

        
    case NVA097_SET_INDEX_BUFFER_F:

        
    case NVA097_DRAW_INDEX_BUFFER:

        
    case NVA097_DRAW_INDEX_BUFFER32_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_INDEX_BUFFER16_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_INDEX_BUFFER8_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_INDEX_BUFFER32_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_DRAW_INDEX_BUFFER16_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_DRAW_INDEX_BUFFER8_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_SET_DEPTH_BIAS_CLAMP:

        
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(0):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(1):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(2):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(3):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(4):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(5):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(6):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(7):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(8):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(9):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(10):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(11):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(12):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(13):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(14):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(15):

        
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(0):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(1):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(2):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(3):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(4):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(5):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(6):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(7):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(8):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(9):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(10):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(11):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(12):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(13):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(14):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(15):

        
    case NVA097_SET_ATTRIBUTE_POINT_SIZE:

        
    case NVA097_OGL_SET_CULL:

        
    case NVA097_OGL_SET_FRONT_FACE:

        
    case NVA097_OGL_SET_CULL_FACE:

        
    case NVA097_SET_VIEWPORT_PIXEL:

        
    case NVA097_SET_VIEWPORT_SCALE_OFFSET:

        
    case NVA097_INVALIDATE_CONSTANT_BUFFER_CACHE:

        
    case NVA097_SET_VIEWPORT_CLIP_CONTROL:

        
    case NVA097_SET_USER_CLIP_OP:

        
    case NVA097_SET_RENDER_ENABLE_OVERRIDE:

        
    case NVA097_SET_PRIMITIVE_TOPOLOGY_CONTROL:

        
    case NVA097_SET_WINDOW_CLIP_ENABLE:

        
    case NVA097_SET_WINDOW_CLIP_TYPE:

        
    case NVA097_INVALIDATE_ZCULL:

        
    case NVA097_SET_ZCULL:

        
    case NVA097_SET_ZCULL_BOUNDS:

        
    case NVA097_SET_PRIMITIVE_TOPOLOGY:

        
    case NVA097_ZCULL_SYNC:

        
    case NVA097_SET_CLIP_ID_TEST:

        
    case NVA097_SET_SURFACE_CLIP_ID_WIDTH:

        
    case NVA097_SET_CLIP_ID:

        
    case NVA097_SET_DEPTH_BOUNDS_TEST:

        
    case NVA097_SET_BLEND_FLOAT_OPTION:

        
    case NVA097_SET_LOGIC_OP:

        
    case NVA097_SET_LOGIC_OP_FUNC:

        
    case NVA097_SET_Z_COMPRESSION:

        
    case NVA097_CLEAR_SURFACE:

        
    case NVA097_CLEAR_CLIP_ID_SURFACE:

        
    case NVA097_SET_COLOR_COMPRESSION(0):
    case NVA097_SET_COLOR_COMPRESSION(1):
    case NVA097_SET_COLOR_COMPRESSION(2):
    case NVA097_SET_COLOR_COMPRESSION(3):
    case NVA097_SET_COLOR_COMPRESSION(4):
    case NVA097_SET_COLOR_COMPRESSION(5):
    case NVA097_SET_COLOR_COMPRESSION(6):
    case NVA097_SET_COLOR_COMPRESSION(7):

        
    case NVA097_SET_CT_WRITE(0):
    case NVA097_SET_CT_WRITE(1):
    case NVA097_SET_CT_WRITE(2):
    case NVA097_SET_CT_WRITE(3):
    case NVA097_SET_CT_WRITE(4):
    case NVA097_SET_CT_WRITE(5):
    case NVA097_SET_CT_WRITE(6):
    case NVA097_SET_CT_WRITE(7):

        
    case NVA097_PIPE_NOP:

        
    case NVA097_SET_SPARE00:

        
    case NVA097_SET_SPARE01:

        
    case NVA097_SET_SPARE02:

        
    case NVA097_SET_SPARE03:

        
    case NVA097_SET_REPORT_SEMAPHORE_A:

        
    case NVA097_SET_REPORT_SEMAPHORE_B:

        
    case NVA097_SET_REPORT_SEMAPHORE_C:

        
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(0):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(1):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(2):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(3):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(4):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(5):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(6):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(7):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(8):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(9):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(10):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(11):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(12):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(13):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(14):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(15):

        
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(0):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(1):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(2):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(3):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(4):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(5):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(6):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(7):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(8):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(9):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(10):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(11):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(12):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(13):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(14):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(15):

        
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(0):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(1):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(2):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(3):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(4):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(5):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(6):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(7):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(8):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(9):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(10):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(11):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(12):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(13):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(14):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(15):

        
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(0):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(1):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(2):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(3):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(4):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(5):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(6):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(7):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(8):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(9):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(10):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(11):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(12):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(13):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(14):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(15):

        
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(0):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(1):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(2):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(3):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(4):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(5):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(6):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(7):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(8):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(9):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(10):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(11):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(12):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(13):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(14):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(15):

        
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(0):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(1):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(2):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(3):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(4):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(5):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(6):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(7):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(8):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(9):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(10):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(11):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(12):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(13):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(14):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(15):

        
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(0):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(1):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(2):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(3):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(4):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(5):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(6):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(7):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(8):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(9):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(10):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(11):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(12):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(13):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(14):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(15):

        
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(0):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(1):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(2):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(3):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(4):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(5):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(6):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(7):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(8):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(9):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(10):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(11):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(12):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(13):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(14):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(15):

        
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(0):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(1):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(2):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(3):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(4):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(5):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(6):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(7):

        
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(0):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(1):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(2):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(3):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(4):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(5):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(6):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(7):

        
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(7):

        
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(7):

        
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(0):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(1):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(2):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(3):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(4):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(5):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(6):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(7):

        
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(7):

        
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(7):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(15):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(15):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(15):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(15):

        
    case NVA097_SET_PIPELINE_SHADER(0):
    case NVA097_SET_PIPELINE_SHADER(1):
    case NVA097_SET_PIPELINE_SHADER(2):
    case NVA097_SET_PIPELINE_SHADER(3):
    case NVA097_SET_PIPELINE_SHADER(4):
    case NVA097_SET_PIPELINE_SHADER(5):

        
    case NVA097_SET_PIPELINE_PROGRAM(0):
    case NVA097_SET_PIPELINE_PROGRAM(1):
    case NVA097_SET_PIPELINE_PROGRAM(2):
    case NVA097_SET_PIPELINE_PROGRAM(3):
    case NVA097_SET_PIPELINE_PROGRAM(4):
    case NVA097_SET_PIPELINE_PROGRAM(5):

        
    case NVA097_SET_PIPELINE_RESERVED_A(0):
    case NVA097_SET_PIPELINE_RESERVED_A(1):
    case NVA097_SET_PIPELINE_RESERVED_A(2):
    case NVA097_SET_PIPELINE_RESERVED_A(3):
    case NVA097_SET_PIPELINE_RESERVED_A(4):
    case NVA097_SET_PIPELINE_RESERVED_A(5):

        
    case NVA097_SET_PIPELINE_REGISTER_COUNT(0):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(1):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(2):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(3):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(4):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(5):

        
    case NVA097_SET_PIPELINE_BINDING(0):
    case NVA097_SET_PIPELINE_BINDING(1):
    case NVA097_SET_PIPELINE_BINDING(2):
    case NVA097_SET_PIPELINE_BINDING(3):
    case NVA097_SET_PIPELINE_BINDING(4):
    case NVA097_SET_PIPELINE_BINDING(5):

        
    case NVA097_SET_PIPELINE_RESERVED_B(0):
    case NVA097_SET_PIPELINE_RESERVED_B(1):
    case NVA097_SET_PIPELINE_RESERVED_B(2):
    case NVA097_SET_PIPELINE_RESERVED_B(3):
    case NVA097_SET_PIPELINE_RESERVED_B(4):
    case NVA097_SET_PIPELINE_RESERVED_B(5):

        
    case NVA097_SET_PIPELINE_RESERVED_C(0):
    case NVA097_SET_PIPELINE_RESERVED_C(1):
    case NVA097_SET_PIPELINE_RESERVED_C(2):
    case NVA097_SET_PIPELINE_RESERVED_C(3):
    case NVA097_SET_PIPELINE_RESERVED_C(4):
    case NVA097_SET_PIPELINE_RESERVED_C(5):

        
    case NVA097_SET_PIPELINE_RESERVED_D(0):
    case NVA097_SET_PIPELINE_RESERVED_D(1):
    case NVA097_SET_PIPELINE_RESERVED_D(2):
    case NVA097_SET_PIPELINE_RESERVED_D(3):
    case NVA097_SET_PIPELINE_RESERVED_D(4):
    case NVA097_SET_PIPELINE_RESERVED_D(5):

        
    case NVA097_SET_PIPELINE_RESERVED_E(0):
    case NVA097_SET_PIPELINE_RESERVED_E(1):
    case NVA097_SET_PIPELINE_RESERVED_E(2):
    case NVA097_SET_PIPELINE_RESERVED_E(3):
    case NVA097_SET_PIPELINE_RESERVED_E(4):
    case NVA097_SET_PIPELINE_RESERVED_E(5):

        
    case NVA097_SET_FALCON00:

        
    case NVA097_SET_FALCON01:

        
    case NVA097_SET_FALCON02:

        
    case NVA097_SET_FALCON03:

        
    case NVA097_SET_FALCON04:

        
    case NVA097_SET_FALCON05:

        
    case NVA097_SET_FALCON06:

        
    case NVA097_SET_FALCON07:

        
    case NVA097_SET_FALCON08:

        
    case NVA097_SET_FALCON09:

        
    case NVA097_SET_FALCON10:

        
    case NVA097_SET_FALCON11:

        
    case NVA097_SET_FALCON12:

        
    case NVA097_SET_FALCON13:

        
    case NVA097_SET_FALCON14:

        
    case NVA097_SET_FALCON15:

        
    case NVA097_SET_FALCON16:

        
    case NVA097_SET_FALCON17:

        
    case NVA097_SET_FALCON18:

        
    case NVA097_SET_FALCON19:

        
    case NVA097_SET_FALCON20:

        
    case NVA097_SET_FALCON21:

        
    case NVA097_SET_FALCON22:

        
    case NVA097_SET_FALCON23:

        
    case NVA097_SET_FALCON24:

        
    case NVA097_SET_FALCON25:

        
    case NVA097_SET_FALCON26:

        
    case NVA097_SET_FALCON27:

        
    case NVA097_SET_FALCON28:

        
    case NVA097_SET_FALCON29:

        
    case NVA097_SET_FALCON30:

        
    case NVA097_SET_FALCON31:

        
    case NVA097_SET_CONSTANT_BUFFER_SELECTOR_A:

        
    case NVA097_SET_CONSTANT_BUFFER_SELECTOR_B:

        
    case NVA097_SET_CONSTANT_BUFFER_SELECTOR_C:

        
    case NVA097_LOAD_CONSTANT_BUFFER_OFFSET:

        
    case NVA097_LOAD_CONSTANT_BUFFER(0):
    case NVA097_LOAD_CONSTANT_BUFFER(1):
    case NVA097_LOAD_CONSTANT_BUFFER(2):
    case NVA097_LOAD_CONSTANT_BUFFER(3):
    case NVA097_LOAD_CONSTANT_BUFFER(4):
    case NVA097_LOAD_CONSTANT_BUFFER(5):
    case NVA097_LOAD_CONSTANT_BUFFER(6):
    case NVA097_LOAD_CONSTANT_BUFFER(7):
    case NVA097_LOAD_CONSTANT_BUFFER(8):
    case NVA097_LOAD_CONSTANT_BUFFER(9):
    case NVA097_LOAD_CONSTANT_BUFFER(10):
    case NVA097_LOAD_CONSTANT_BUFFER(11):
    case NVA097_LOAD_CONSTANT_BUFFER(12):
    case NVA097_LOAD_CONSTANT_BUFFER(13):
    case NVA097_LOAD_CONSTANT_BUFFER(14):
    case NVA097_LOAD_CONSTANT_BUFFER(15):

        
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(0):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(1):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(2):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(3):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(4):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(5):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(6):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(7):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(8):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(9):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(10):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(11):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(12):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(13):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(14):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(15):

        
    case NVA097_SET_COLOR_CLAMP:

        
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(0):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(1):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(2):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(3):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(4):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(5):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(6):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(7):

        
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(0):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(1):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(2):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(3):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(4):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(5):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(6):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(7):

        
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_TRAP_CONTROL:

        
    case NVA097_SET_MME_SHADOW_SCRATCH(0):
    case NVA097_SET_MME_SHADOW_SCRATCH(1):
    case NVA097_SET_MME_SHADOW_SCRATCH(2):
    case NVA097_SET_MME_SHADOW_SCRATCH(3):
    case NVA097_SET_MME_SHADOW_SCRATCH(4):
    case NVA097_SET_MME_SHADOW_SCRATCH(5):
    case NVA097_SET_MME_SHADOW_SCRATCH(6):
    case NVA097_SET_MME_SHADOW_SCRATCH(7):
    case NVA097_SET_MME_SHADOW_SCRATCH(8):
    case NVA097_SET_MME_SHADOW_SCRATCH(9):
    case NVA097_SET_MME_SHADOW_SCRATCH(10):
    case NVA097_SET_MME_SHADOW_SCRATCH(11):
    case NVA097_SET_MME_SHADOW_SCRATCH(12):
    case NVA097_SET_MME_SHADOW_SCRATCH(13):
    case NVA097_SET_MME_SHADOW_SCRATCH(14):
    case NVA097_SET_MME_SHADOW_SCRATCH(15):
    case NVA097_SET_MME_SHADOW_SCRATCH(16):
    case NVA097_SET_MME_SHADOW_SCRATCH(17):
    case NVA097_SET_MME_SHADOW_SCRATCH(18):
    case NVA097_SET_MME_SHADOW_SCRATCH(19):
    case NVA097_SET_MME_SHADOW_SCRATCH(20):
    case NVA097_SET_MME_SHADOW_SCRATCH(21):
    case NVA097_SET_MME_SHADOW_SCRATCH(22):
    case NVA097_SET_MME_SHADOW_SCRATCH(23):
    case NVA097_SET_MME_SHADOW_SCRATCH(24):
    case NVA097_SET_MME_SHADOW_SCRATCH(25):
    case NVA097_SET_MME_SHADOW_SCRATCH(26):
    case NVA097_SET_MME_SHADOW_SCRATCH(27):
    case NVA097_SET_MME_SHADOW_SCRATCH(28):
    case NVA097_SET_MME_SHADOW_SCRATCH(29):
    case NVA097_SET_MME_SHADOW_SCRATCH(30):
    case NVA097_SET_MME_SHADOW_SCRATCH(31):
    case NVA097_SET_MME_SHADOW_SCRATCH(32):
    case NVA097_SET_MME_SHADOW_SCRATCH(33):
    case NVA097_SET_MME_SHADOW_SCRATCH(34):
    case NVA097_SET_MME_SHADOW_SCRATCH(35):
    case NVA097_SET_MME_SHADOW_SCRATCH(36):
    case NVA097_SET_MME_SHADOW_SCRATCH(37):
    case NVA097_SET_MME_SHADOW_SCRATCH(38):
    case NVA097_SET_MME_SHADOW_SCRATCH(39):
    case NVA097_SET_MME_SHADOW_SCRATCH(40):
    case NVA097_SET_MME_SHADOW_SCRATCH(41):
    case NVA097_SET_MME_SHADOW_SCRATCH(42):
    case NVA097_SET_MME_SHADOW_SCRATCH(43):
    case NVA097_SET_MME_SHADOW_SCRATCH(44):
    case NVA097_SET_MME_SHADOW_SCRATCH(45):
    case NVA097_SET_MME_SHADOW_SCRATCH(46):
    case NVA097_SET_MME_SHADOW_SCRATCH(47):
    case NVA097_SET_MME_SHADOW_SCRATCH(48):
    case NVA097_SET_MME_SHADOW_SCRATCH(49):
    case NVA097_SET_MME_SHADOW_SCRATCH(50):
    case NVA097_SET_MME_SHADOW_SCRATCH(51):
    case NVA097_SET_MME_SHADOW_SCRATCH(52):
    case NVA097_SET_MME_SHADOW_SCRATCH(53):
    case NVA097_SET_MME_SHADOW_SCRATCH(54):
    case NVA097_SET_MME_SHADOW_SCRATCH(55):
    case NVA097_SET_MME_SHADOW_SCRATCH(56):
    case NVA097_SET_MME_SHADOW_SCRATCH(57):
    case NVA097_SET_MME_SHADOW_SCRATCH(58):
    case NVA097_SET_MME_SHADOW_SCRATCH(59):
    case NVA097_SET_MME_SHADOW_SCRATCH(60):
    case NVA097_SET_MME_SHADOW_SCRATCH(61):
    case NVA097_SET_MME_SHADOW_SCRATCH(62):
    case NVA097_SET_MME_SHADOW_SCRATCH(63):
    case NVA097_SET_MME_SHADOW_SCRATCH(64):
    case NVA097_SET_MME_SHADOW_SCRATCH(65):
    case NVA097_SET_MME_SHADOW_SCRATCH(66):
    case NVA097_SET_MME_SHADOW_SCRATCH(67):
    case NVA097_SET_MME_SHADOW_SCRATCH(68):
    case NVA097_SET_MME_SHADOW_SCRATCH(69):
    case NVA097_SET_MME_SHADOW_SCRATCH(70):
    case NVA097_SET_MME_SHADOW_SCRATCH(71):
    case NVA097_SET_MME_SHADOW_SCRATCH(72):
    case NVA097_SET_MME_SHADOW_SCRATCH(73):
    case NVA097_SET_MME_SHADOW_SCRATCH(74):
    case NVA097_SET_MME_SHADOW_SCRATCH(75):
    case NVA097_SET_MME_SHADOW_SCRATCH(76):
    case NVA097_SET_MME_SHADOW_SCRATCH(77):
    case NVA097_SET_MME_SHADOW_SCRATCH(78):
    case NVA097_SET_MME_SHADOW_SCRATCH(79):
    case NVA097_SET_MME_SHADOW_SCRATCH(80):
    case NVA097_SET_MME_SHADOW_SCRATCH(81):
    case NVA097_SET_MME_SHADOW_SCRATCH(82):
    case NVA097_SET_MME_SHADOW_SCRATCH(83):
    case NVA097_SET_MME_SHADOW_SCRATCH(84):
    case NVA097_SET_MME_SHADOW_SCRATCH(85):
    case NVA097_SET_MME_SHADOW_SCRATCH(86):
    case NVA097_SET_MME_SHADOW_SCRATCH(87):
    case NVA097_SET_MME_SHADOW_SCRATCH(88):
    case NVA097_SET_MME_SHADOW_SCRATCH(89):
    case NVA097_SET_MME_SHADOW_SCRATCH(90):
    case NVA097_SET_MME_SHADOW_SCRATCH(91):
    case NVA097_SET_MME_SHADOW_SCRATCH(92):
    case NVA097_SET_MME_SHADOW_SCRATCH(93):
    case NVA097_SET_MME_SHADOW_SCRATCH(94):
    case NVA097_SET_MME_SHADOW_SCRATCH(95):
    case NVA097_SET_MME_SHADOW_SCRATCH(96):
    case NVA097_SET_MME_SHADOW_SCRATCH(97):
    case NVA097_SET_MME_SHADOW_SCRATCH(98):
    case NVA097_SET_MME_SHADOW_SCRATCH(99):
    case NVA097_SET_MME_SHADOW_SCRATCH(100):
    case NVA097_SET_MME_SHADOW_SCRATCH(101):
    case NVA097_SET_MME_SHADOW_SCRATCH(102):
    case NVA097_SET_MME_SHADOW_SCRATCH(103):
    case NVA097_SET_MME_SHADOW_SCRATCH(104):
    case NVA097_SET_MME_SHADOW_SCRATCH(105):
    case NVA097_SET_MME_SHADOW_SCRATCH(106):
    case NVA097_SET_MME_SHADOW_SCRATCH(107):
    case NVA097_SET_MME_SHADOW_SCRATCH(108):
    case NVA097_SET_MME_SHADOW_SCRATCH(109):
    case NVA097_SET_MME_SHADOW_SCRATCH(110):
    case NVA097_SET_MME_SHADOW_SCRATCH(111):
    case NVA097_SET_MME_SHADOW_SCRATCH(112):
    case NVA097_SET_MME_SHADOW_SCRATCH(113):
    case NVA097_SET_MME_SHADOW_SCRATCH(114):
    case NVA097_SET_MME_SHADOW_SCRATCH(115):
    case NVA097_SET_MME_SHADOW_SCRATCH(116):
    case NVA097_SET_MME_SHADOW_SCRATCH(117):
    case NVA097_SET_MME_SHADOW_SCRATCH(118):
    case NVA097_SET_MME_SHADOW_SCRATCH(119):
    case NVA097_SET_MME_SHADOW_SCRATCH(120):
    case NVA097_SET_MME_SHADOW_SCRATCH(121):
    case NVA097_SET_MME_SHADOW_SCRATCH(122):
    case NVA097_SET_MME_SHADOW_SCRATCH(123):
    case NVA097_SET_MME_SHADOW_SCRATCH(124):
    case NVA097_SET_MME_SHADOW_SCRATCH(125):
    case NVA097_SET_MME_SHADOW_SCRATCH(126):
    case NVA097_SET_MME_SHADOW_SCRATCH(127):
    case NVA097_SET_MME_SHADOW_SCRATCH(128):
    case NVA097_SET_MME_SHADOW_SCRATCH(129):
    case NVA097_SET_MME_SHADOW_SCRATCH(130):
    case NVA097_SET_MME_SHADOW_SCRATCH(131):
    case NVA097_SET_MME_SHADOW_SCRATCH(132):
    case NVA097_SET_MME_SHADOW_SCRATCH(133):
    case NVA097_SET_MME_SHADOW_SCRATCH(134):
    case NVA097_SET_MME_SHADOW_SCRATCH(135):
    case NVA097_SET_MME_SHADOW_SCRATCH(136):
    case NVA097_SET_MME_SHADOW_SCRATCH(137):
    case NVA097_SET_MME_SHADOW_SCRATCH(138):
    case NVA097_SET_MME_SHADOW_SCRATCH(139):
    case NVA097_SET_MME_SHADOW_SCRATCH(140):
    case NVA097_SET_MME_SHADOW_SCRATCH(141):
    case NVA097_SET_MME_SHADOW_SCRATCH(142):
    case NVA097_SET_MME_SHADOW_SCRATCH(143):
    case NVA097_SET_MME_SHADOW_SCRATCH(144):
    case NVA097_SET_MME_SHADOW_SCRATCH(145):
    case NVA097_SET_MME_SHADOW_SCRATCH(146):
    case NVA097_SET_MME_SHADOW_SCRATCH(147):
    case NVA097_SET_MME_SHADOW_SCRATCH(148):
    case NVA097_SET_MME_SHADOW_SCRATCH(149):
    case NVA097_SET_MME_SHADOW_SCRATCH(150):
    case NVA097_SET_MME_SHADOW_SCRATCH(151):
    case NVA097_SET_MME_SHADOW_SCRATCH(152):
    case NVA097_SET_MME_SHADOW_SCRATCH(153):
    case NVA097_SET_MME_SHADOW_SCRATCH(154):
    case NVA097_SET_MME_SHADOW_SCRATCH(155):
    case NVA097_SET_MME_SHADOW_SCRATCH(156):
    case NVA097_SET_MME_SHADOW_SCRATCH(157):
    case NVA097_SET_MME_SHADOW_SCRATCH(158):
    case NVA097_SET_MME_SHADOW_SCRATCH(159):
    case NVA097_SET_MME_SHADOW_SCRATCH(160):
    case NVA097_SET_MME_SHADOW_SCRATCH(161):
    case NVA097_SET_MME_SHADOW_SCRATCH(162):
    case NVA097_SET_MME_SHADOW_SCRATCH(163):
    case NVA097_SET_MME_SHADOW_SCRATCH(164):
    case NVA097_SET_MME_SHADOW_SCRATCH(165):
    case NVA097_SET_MME_SHADOW_SCRATCH(166):
    case NVA097_SET_MME_SHADOW_SCRATCH(167):
    case NVA097_SET_MME_SHADOW_SCRATCH(168):
    case NVA097_SET_MME_SHADOW_SCRATCH(169):
    case NVA097_SET_MME_SHADOW_SCRATCH(170):
    case NVA097_SET_MME_SHADOW_SCRATCH(171):
    case NVA097_SET_MME_SHADOW_SCRATCH(172):
    case NVA097_SET_MME_SHADOW_SCRATCH(173):
    case NVA097_SET_MME_SHADOW_SCRATCH(174):
    case NVA097_SET_MME_SHADOW_SCRATCH(175):
    case NVA097_SET_MME_SHADOW_SCRATCH(176):
    case NVA097_SET_MME_SHADOW_SCRATCH(177):
    case NVA097_SET_MME_SHADOW_SCRATCH(178):
    case NVA097_SET_MME_SHADOW_SCRATCH(179):
    case NVA097_SET_MME_SHADOW_SCRATCH(180):
    case NVA097_SET_MME_SHADOW_SCRATCH(181):
    case NVA097_SET_MME_SHADOW_SCRATCH(182):
    case NVA097_SET_MME_SHADOW_SCRATCH(183):
    case NVA097_SET_MME_SHADOW_SCRATCH(184):
    case NVA097_SET_MME_SHADOW_SCRATCH(185):
    case NVA097_SET_MME_SHADOW_SCRATCH(186):
    case NVA097_SET_MME_SHADOW_SCRATCH(187):
    case NVA097_SET_MME_SHADOW_SCRATCH(188):
    case NVA097_SET_MME_SHADOW_SCRATCH(189):
    case NVA097_SET_MME_SHADOW_SCRATCH(190):
    case NVA097_SET_MME_SHADOW_SCRATCH(191):
    case NVA097_SET_MME_SHADOW_SCRATCH(192):
    case NVA097_SET_MME_SHADOW_SCRATCH(193):
    case NVA097_SET_MME_SHADOW_SCRATCH(194):
    case NVA097_SET_MME_SHADOW_SCRATCH(195):
    case NVA097_SET_MME_SHADOW_SCRATCH(196):
    case NVA097_SET_MME_SHADOW_SCRATCH(197):
    case NVA097_SET_MME_SHADOW_SCRATCH(198):
    case NVA097_SET_MME_SHADOW_SCRATCH(199):
    case NVA097_SET_MME_SHADOW_SCRATCH(200):
    case NVA097_SET_MME_SHADOW_SCRATCH(201):
    case NVA097_SET_MME_SHADOW_SCRATCH(202):
    case NVA097_SET_MME_SHADOW_SCRATCH(203):
    case NVA097_SET_MME_SHADOW_SCRATCH(204):
    case NVA097_SET_MME_SHADOW_SCRATCH(205):
    case NVA097_SET_MME_SHADOW_SCRATCH(206):
    case NVA097_SET_MME_SHADOW_SCRATCH(207):
    case NVA097_SET_MME_SHADOW_SCRATCH(208):
    case NVA097_SET_MME_SHADOW_SCRATCH(209):
    case NVA097_SET_MME_SHADOW_SCRATCH(210):
    case NVA097_SET_MME_SHADOW_SCRATCH(211):
    case NVA097_SET_MME_SHADOW_SCRATCH(212):
    case NVA097_SET_MME_SHADOW_SCRATCH(213):
    case NVA097_SET_MME_SHADOW_SCRATCH(214):
    case NVA097_SET_MME_SHADOW_SCRATCH(215):
    case NVA097_SET_MME_SHADOW_SCRATCH(216):
    case NVA097_SET_MME_SHADOW_SCRATCH(217):
    case NVA097_SET_MME_SHADOW_SCRATCH(218):
    case NVA097_SET_MME_SHADOW_SCRATCH(219):
    case NVA097_SET_MME_SHADOW_SCRATCH(220):
    case NVA097_SET_MME_SHADOW_SCRATCH(221):
    case NVA097_SET_MME_SHADOW_SCRATCH(222):
    case NVA097_SET_MME_SHADOW_SCRATCH(223):
    case NVA097_SET_MME_SHADOW_SCRATCH(224):
    case NVA097_SET_MME_SHADOW_SCRATCH(225):
    case NVA097_SET_MME_SHADOW_SCRATCH(226):
    case NVA097_SET_MME_SHADOW_SCRATCH(227):
    case NVA097_SET_MME_SHADOW_SCRATCH(228):
    case NVA097_SET_MME_SHADOW_SCRATCH(229):
    case NVA097_SET_MME_SHADOW_SCRATCH(230):
    case NVA097_SET_MME_SHADOW_SCRATCH(231):
    case NVA097_SET_MME_SHADOW_SCRATCH(232):
    case NVA097_SET_MME_SHADOW_SCRATCH(233):
    case NVA097_SET_MME_SHADOW_SCRATCH(234):
    case NVA097_SET_MME_SHADOW_SCRATCH(235):
    case NVA097_SET_MME_SHADOW_SCRATCH(236):
    case NVA097_SET_MME_SHADOW_SCRATCH(237):
    case NVA097_SET_MME_SHADOW_SCRATCH(238):
    case NVA097_SET_MME_SHADOW_SCRATCH(239):
    case NVA097_SET_MME_SHADOW_SCRATCH(240):
    case NVA097_SET_MME_SHADOW_SCRATCH(241):
    case NVA097_SET_MME_SHADOW_SCRATCH(242):
    case NVA097_SET_MME_SHADOW_SCRATCH(243):
    case NVA097_SET_MME_SHADOW_SCRATCH(244):
    case NVA097_SET_MME_SHADOW_SCRATCH(245):
    case NVA097_SET_MME_SHADOW_SCRATCH(246):
    case NVA097_SET_MME_SHADOW_SCRATCH(247):
    case NVA097_SET_MME_SHADOW_SCRATCH(248):
    case NVA097_SET_MME_SHADOW_SCRATCH(249):
    case NVA097_SET_MME_SHADOW_SCRATCH(250):
    case NVA097_SET_MME_SHADOW_SCRATCH(251):
    case NVA097_SET_MME_SHADOW_SCRATCH(252):
    case NVA097_SET_MME_SHADOW_SCRATCH(253):
    case NVA097_SET_MME_SHADOW_SCRATCH(254):
    case NVA097_SET_MME_SHADOW_SCRATCH(255):

        
    case NVA097_CALL_MME_MACRO(0):
    case NVA097_CALL_MME_MACRO(1):
    case NVA097_CALL_MME_MACRO(2):
    case NVA097_CALL_MME_MACRO(3):
    case NVA097_CALL_MME_MACRO(4):
    case NVA097_CALL_MME_MACRO(5):
    case NVA097_CALL_MME_MACRO(6):
    case NVA097_CALL_MME_MACRO(7):
    case NVA097_CALL_MME_MACRO(8):
    case NVA097_CALL_MME_MACRO(9):
    case NVA097_CALL_MME_MACRO(10):
    case NVA097_CALL_MME_MACRO(11):
    case NVA097_CALL_MME_MACRO(12):
    case NVA097_CALL_MME_MACRO(13):
    case NVA097_CALL_MME_MACRO(14):
    case NVA097_CALL_MME_MACRO(15):
    case NVA097_CALL_MME_MACRO(16):
    case NVA097_CALL_MME_MACRO(17):
    case NVA097_CALL_MME_MACRO(18):
    case NVA097_CALL_MME_MACRO(19):
    case NVA097_CALL_MME_MACRO(20):
    case NVA097_CALL_MME_MACRO(21):
    case NVA097_CALL_MME_MACRO(22):
    case NVA097_CALL_MME_MACRO(23):
    case NVA097_CALL_MME_MACRO(24):
    case NVA097_CALL_MME_MACRO(25):
    case NVA097_CALL_MME_MACRO(26):
    case NVA097_CALL_MME_MACRO(27):
    case NVA097_CALL_MME_MACRO(28):
    case NVA097_CALL_MME_MACRO(29):
    case NVA097_CALL_MME_MACRO(30):
    case NVA097_CALL_MME_MACRO(31):
    case NVA097_CALL_MME_MACRO(32):
    case NVA097_CALL_MME_MACRO(33):
    case NVA097_CALL_MME_MACRO(34):
    case NVA097_CALL_MME_MACRO(35):
    case NVA097_CALL_MME_MACRO(36):
    case NVA097_CALL_MME_MACRO(37):
    case NVA097_CALL_MME_MACRO(38):
    case NVA097_CALL_MME_MACRO(39):
    case NVA097_CALL_MME_MACRO(40):
    case NVA097_CALL_MME_MACRO(41):
    case NVA097_CALL_MME_MACRO(42):
    case NVA097_CALL_MME_MACRO(43):
    case NVA097_CALL_MME_MACRO(44):
    case NVA097_CALL_MME_MACRO(45):
    case NVA097_CALL_MME_MACRO(46):
    case NVA097_CALL_MME_MACRO(47):
    case NVA097_CALL_MME_MACRO(48):
    case NVA097_CALL_MME_MACRO(49):
    case NVA097_CALL_MME_MACRO(50):
    case NVA097_CALL_MME_MACRO(51):
    case NVA097_CALL_MME_MACRO(52):
    case NVA097_CALL_MME_MACRO(53):
    case NVA097_CALL_MME_MACRO(54):
    case NVA097_CALL_MME_MACRO(55):
    case NVA097_CALL_MME_MACRO(56):
    case NVA097_CALL_MME_MACRO(57):
    case NVA097_CALL_MME_MACRO(58):
    case NVA097_CALL_MME_MACRO(59):
    case NVA097_CALL_MME_MACRO(60):
    case NVA097_CALL_MME_MACRO(61):
    case NVA097_CALL_MME_MACRO(62):
    case NVA097_CALL_MME_MACRO(63):
    case NVA097_CALL_MME_MACRO(64):
    case NVA097_CALL_MME_MACRO(65):
    case NVA097_CALL_MME_MACRO(66):
    case NVA097_CALL_MME_MACRO(67):
    case NVA097_CALL_MME_MACRO(68):
    case NVA097_CALL_MME_MACRO(69):
    case NVA097_CALL_MME_MACRO(70):
    case NVA097_CALL_MME_MACRO(71):
    case NVA097_CALL_MME_MACRO(72):
    case NVA097_CALL_MME_MACRO(73):
    case NVA097_CALL_MME_MACRO(74):
    case NVA097_CALL_MME_MACRO(75):
    case NVA097_CALL_MME_MACRO(76):
    case NVA097_CALL_MME_MACRO(77):
    case NVA097_CALL_MME_MACRO(78):
    case NVA097_CALL_MME_MACRO(79):
    case NVA097_CALL_MME_MACRO(80):
    case NVA097_CALL_MME_MACRO(81):
    case NVA097_CALL_MME_MACRO(82):
    case NVA097_CALL_MME_MACRO(83):
    case NVA097_CALL_MME_MACRO(84):
    case NVA097_CALL_MME_MACRO(85):
    case NVA097_CALL_MME_MACRO(86):
    case NVA097_CALL_MME_MACRO(87):
    case NVA097_CALL_MME_MACRO(88):
    case NVA097_CALL_MME_MACRO(89):
    case NVA097_CALL_MME_MACRO(90):
    case NVA097_CALL_MME_MACRO(91):
    case NVA097_CALL_MME_MACRO(92):
    case NVA097_CALL_MME_MACRO(93):
    case NVA097_CALL_MME_MACRO(94):
    case NVA097_CALL_MME_MACRO(95):
    case NVA097_CALL_MME_MACRO(96):
    case NVA097_CALL_MME_MACRO(97):
    case NVA097_CALL_MME_MACRO(98):
    case NVA097_CALL_MME_MACRO(99):
    case NVA097_CALL_MME_MACRO(100):
    case NVA097_CALL_MME_MACRO(101):
    case NVA097_CALL_MME_MACRO(102):
    case NVA097_CALL_MME_MACRO(103):
    case NVA097_CALL_MME_MACRO(104):
    case NVA097_CALL_MME_MACRO(105):
    case NVA097_CALL_MME_MACRO(106):
    case NVA097_CALL_MME_MACRO(107):
    case NVA097_CALL_MME_MACRO(108):
    case NVA097_CALL_MME_MACRO(109):
    case NVA097_CALL_MME_MACRO(110):
    case NVA097_CALL_MME_MACRO(111):
    case NVA097_CALL_MME_MACRO(112):
    case NVA097_CALL_MME_MACRO(113):
    case NVA097_CALL_MME_MACRO(114):
    case NVA097_CALL_MME_MACRO(115):
    case NVA097_CALL_MME_MACRO(116):
    case NVA097_CALL_MME_MACRO(117):
    case NVA097_CALL_MME_MACRO(118):
    case NVA097_CALL_MME_MACRO(119):
    case NVA097_CALL_MME_MACRO(120):
    case NVA097_CALL_MME_MACRO(121):
    case NVA097_CALL_MME_MACRO(122):
    case NVA097_CALL_MME_MACRO(123):
    case NVA097_CALL_MME_MACRO(124):
    case NVA097_CALL_MME_MACRO(125):
    case NVA097_CALL_MME_MACRO(126):
    case NVA097_CALL_MME_MACRO(127):
    case NVA097_CALL_MME_MACRO(128):
    case NVA097_CALL_MME_MACRO(129):
    case NVA097_CALL_MME_MACRO(130):
    case NVA097_CALL_MME_MACRO(131):
    case NVA097_CALL_MME_MACRO(132):
    case NVA097_CALL_MME_MACRO(133):
    case NVA097_CALL_MME_MACRO(134):
    case NVA097_CALL_MME_MACRO(135):
    case NVA097_CALL_MME_MACRO(136):
    case NVA097_CALL_MME_MACRO(137):
    case NVA097_CALL_MME_MACRO(138):
    case NVA097_CALL_MME_MACRO(139):
    case NVA097_CALL_MME_MACRO(140):
    case NVA097_CALL_MME_MACRO(141):
    case NVA097_CALL_MME_MACRO(142):
    case NVA097_CALL_MME_MACRO(143):
    case NVA097_CALL_MME_MACRO(144):
    case NVA097_CALL_MME_MACRO(145):
    case NVA097_CALL_MME_MACRO(146):
    case NVA097_CALL_MME_MACRO(147):
    case NVA097_CALL_MME_MACRO(148):
    case NVA097_CALL_MME_MACRO(149):
    case NVA097_CALL_MME_MACRO(150):
    case NVA097_CALL_MME_MACRO(151):
    case NVA097_CALL_MME_MACRO(152):
    case NVA097_CALL_MME_MACRO(153):
    case NVA097_CALL_MME_MACRO(154):
    case NVA097_CALL_MME_MACRO(155):
    case NVA097_CALL_MME_MACRO(156):
    case NVA097_CALL_MME_MACRO(157):
    case NVA097_CALL_MME_MACRO(158):
    case NVA097_CALL_MME_MACRO(159):
    case NVA097_CALL_MME_MACRO(160):
    case NVA097_CALL_MME_MACRO(161):
    case NVA097_CALL_MME_MACRO(162):
    case NVA097_CALL_MME_MACRO(163):
    case NVA097_CALL_MME_MACRO(164):
    case NVA097_CALL_MME_MACRO(165):
    case NVA097_CALL_MME_MACRO(166):
    case NVA097_CALL_MME_MACRO(167):
    case NVA097_CALL_MME_MACRO(168):
    case NVA097_CALL_MME_MACRO(169):
    case NVA097_CALL_MME_MACRO(170):
    case NVA097_CALL_MME_MACRO(171):
    case NVA097_CALL_MME_MACRO(172):
    case NVA097_CALL_MME_MACRO(173):
    case NVA097_CALL_MME_MACRO(174):
    case NVA097_CALL_MME_MACRO(175):
    case NVA097_CALL_MME_MACRO(176):
    case NVA097_CALL_MME_MACRO(177):
    case NVA097_CALL_MME_MACRO(178):
    case NVA097_CALL_MME_MACRO(179):
    case NVA097_CALL_MME_MACRO(180):
    case NVA097_CALL_MME_MACRO(181):
    case NVA097_CALL_MME_MACRO(182):
    case NVA097_CALL_MME_MACRO(183):
    case NVA097_CALL_MME_MACRO(184):
    case NVA097_CALL_MME_MACRO(185):
    case NVA097_CALL_MME_MACRO(186):
    case NVA097_CALL_MME_MACRO(187):
    case NVA097_CALL_MME_MACRO(188):
    case NVA097_CALL_MME_MACRO(189):
    case NVA097_CALL_MME_MACRO(190):
    case NVA097_CALL_MME_MACRO(191):
    case NVA097_CALL_MME_MACRO(192):
    case NVA097_CALL_MME_MACRO(193):
    case NVA097_CALL_MME_MACRO(194):
    case NVA097_CALL_MME_MACRO(195):
    case NVA097_CALL_MME_MACRO(196):
    case NVA097_CALL_MME_MACRO(197):
    case NVA097_CALL_MME_MACRO(198):
    case NVA097_CALL_MME_MACRO(199):
    case NVA097_CALL_MME_MACRO(200):
    case NVA097_CALL_MME_MACRO(201):
    case NVA097_CALL_MME_MACRO(202):
    case NVA097_CALL_MME_MACRO(203):
    case NVA097_CALL_MME_MACRO(204):
    case NVA097_CALL_MME_MACRO(205):
    case NVA097_CALL_MME_MACRO(206):
    case NVA097_CALL_MME_MACRO(207):
    case NVA097_CALL_MME_MACRO(208):
    case NVA097_CALL_MME_MACRO(209):
    case NVA097_CALL_MME_MACRO(210):
    case NVA097_CALL_MME_MACRO(211):
    case NVA097_CALL_MME_MACRO(212):
    case NVA097_CALL_MME_MACRO(213):
    case NVA097_CALL_MME_MACRO(214):
    case NVA097_CALL_MME_MACRO(215):
    case NVA097_CALL_MME_MACRO(216):
    case NVA097_CALL_MME_MACRO(217):
    case NVA097_CALL_MME_MACRO(218):
    case NVA097_CALL_MME_MACRO(219):
    case NVA097_CALL_MME_MACRO(220):
    case NVA097_CALL_MME_MACRO(221):
    case NVA097_CALL_MME_MACRO(222):
    case NVA097_CALL_MME_MACRO(223):
    case NVA097_CALL_MME_MACRO(224):
    case NVA097_CALL_MME_MACRO(225):
    case NVA097_CALL_MME_MACRO(226):
    case NVA097_CALL_MME_MACRO(227):
    case NVA097_CALL_MME_MACRO(228):
    case NVA097_CALL_MME_MACRO(229):
    case NVA097_CALL_MME_MACRO(230):
    case NVA097_CALL_MME_MACRO(231):
    case NVA097_CALL_MME_MACRO(232):
    case NVA097_CALL_MME_MACRO(233):
    case NVA097_CALL_MME_MACRO(234):
    case NVA097_CALL_MME_MACRO(235):
    case NVA097_CALL_MME_MACRO(236):
    case NVA097_CALL_MME_MACRO(237):
    case NVA097_CALL_MME_MACRO(238):
    case NVA097_CALL_MME_MACRO(239):
    case NVA097_CALL_MME_MACRO(240):
    case NVA097_CALL_MME_MACRO(241):
    case NVA097_CALL_MME_MACRO(242):
    case NVA097_CALL_MME_MACRO(243):
    case NVA097_CALL_MME_MACRO(244):
    case NVA097_CALL_MME_MACRO(245):
    case NVA097_CALL_MME_MACRO(246):
    case NVA097_CALL_MME_MACRO(247):
    case NVA097_CALL_MME_MACRO(248):
    case NVA097_CALL_MME_MACRO(249):
    case NVA097_CALL_MME_MACRO(250):
    case NVA097_CALL_MME_MACRO(251):
    case NVA097_CALL_MME_MACRO(252):
    case NVA097_CALL_MME_MACRO(253):
    case NVA097_CALL_MME_MACRO(254):
    case NVA097_CALL_MME_MACRO(255):

        
    case NVA097_CALL_MME_DATA(0):
    case NVA097_CALL_MME_DATA(1):
    case NVA097_CALL_MME_DATA(2):
    case NVA097_CALL_MME_DATA(3):
    case NVA097_CALL_MME_DATA(4):
    case NVA097_CALL_MME_DATA(5):
    case NVA097_CALL_MME_DATA(6):
    case NVA097_CALL_MME_DATA(7):
    case NVA097_CALL_MME_DATA(8):
    case NVA097_CALL_MME_DATA(9):
    case NVA097_CALL_MME_DATA(10):
    case NVA097_CALL_MME_DATA(11):
    case NVA097_CALL_MME_DATA(12):
    case NVA097_CALL_MME_DATA(13):
    case NVA097_CALL_MME_DATA(14):
    case NVA097_CALL_MME_DATA(15):
    case NVA097_CALL_MME_DATA(16):
    case NVA097_CALL_MME_DATA(17):
    case NVA097_CALL_MME_DATA(18):
    case NVA097_CALL_MME_DATA(19):
    case NVA097_CALL_MME_DATA(20):
    case NVA097_CALL_MME_DATA(21):
    case NVA097_CALL_MME_DATA(22):
    case NVA097_CALL_MME_DATA(23):
    case NVA097_CALL_MME_DATA(24):
    case NVA097_CALL_MME_DATA(25):
    case NVA097_CALL_MME_DATA(26):
    case NVA097_CALL_MME_DATA(27):
    case NVA097_CALL_MME_DATA(28):
    case NVA097_CALL_MME_DATA(29):
    case NVA097_CALL_MME_DATA(30):
    case NVA097_CALL_MME_DATA(31):
    case NVA097_CALL_MME_DATA(32):
    case NVA097_CALL_MME_DATA(33):
    case NVA097_CALL_MME_DATA(34):
    case NVA097_CALL_MME_DATA(35):
    case NVA097_CALL_MME_DATA(36):
    case NVA097_CALL_MME_DATA(37):
    case NVA097_CALL_MME_DATA(38):
    case NVA097_CALL_MME_DATA(39):
    case NVA097_CALL_MME_DATA(40):
    case NVA097_CALL_MME_DATA(41):
    case NVA097_CALL_MME_DATA(42):
    case NVA097_CALL_MME_DATA(43):
    case NVA097_CALL_MME_DATA(44):
    case NVA097_CALL_MME_DATA(45):
    case NVA097_CALL_MME_DATA(46):
    case NVA097_CALL_MME_DATA(47):
    case NVA097_CALL_MME_DATA(48):
    case NVA097_CALL_MME_DATA(49):
    case NVA097_CALL_MME_DATA(50):
    case NVA097_CALL_MME_DATA(51):
    case NVA097_CALL_MME_DATA(52):
    case NVA097_CALL_MME_DATA(53):
    case NVA097_CALL_MME_DATA(54):
    case NVA097_CALL_MME_DATA(55):
    case NVA097_CALL_MME_DATA(56):
    case NVA097_CALL_MME_DATA(57):
    case NVA097_CALL_MME_DATA(58):
    case NVA097_CALL_MME_DATA(59):
    case NVA097_CALL_MME_DATA(60):
    case NVA097_CALL_MME_DATA(61):
    case NVA097_CALL_MME_DATA(62):
    case NVA097_CALL_MME_DATA(63):
    case NVA097_CALL_MME_DATA(64):
    case NVA097_CALL_MME_DATA(65):
    case NVA097_CALL_MME_DATA(66):
    case NVA097_CALL_MME_DATA(67):
    case NVA097_CALL_MME_DATA(68):
    case NVA097_CALL_MME_DATA(69):
    case NVA097_CALL_MME_DATA(70):
    case NVA097_CALL_MME_DATA(71):
    case NVA097_CALL_MME_DATA(72):
    case NVA097_CALL_MME_DATA(73):
    case NVA097_CALL_MME_DATA(74):
    case NVA097_CALL_MME_DATA(75):
    case NVA097_CALL_MME_DATA(76):
    case NVA097_CALL_MME_DATA(77):
    case NVA097_CALL_MME_DATA(78):
    case NVA097_CALL_MME_DATA(79):
    case NVA097_CALL_MME_DATA(80):
    case NVA097_CALL_MME_DATA(81):
    case NVA097_CALL_MME_DATA(82):
    case NVA097_CALL_MME_DATA(83):
    case NVA097_CALL_MME_DATA(84):
    case NVA097_CALL_MME_DATA(85):
    case NVA097_CALL_MME_DATA(86):
    case NVA097_CALL_MME_DATA(87):
    case NVA097_CALL_MME_DATA(88):
    case NVA097_CALL_MME_DATA(89):
    case NVA097_CALL_MME_DATA(90):
    case NVA097_CALL_MME_DATA(91):
    case NVA097_CALL_MME_DATA(92):
    case NVA097_CALL_MME_DATA(93):
    case NVA097_CALL_MME_DATA(94):
    case NVA097_CALL_MME_DATA(95):
    case NVA097_CALL_MME_DATA(96):
    case NVA097_CALL_MME_DATA(97):
    case NVA097_CALL_MME_DATA(98):
    case NVA097_CALL_MME_DATA(99):
    case NVA097_CALL_MME_DATA(100):
    case NVA097_CALL_MME_DATA(101):
    case NVA097_CALL_MME_DATA(102):
    case NVA097_CALL_MME_DATA(103):
    case NVA097_CALL_MME_DATA(104):
    case NVA097_CALL_MME_DATA(105):
    case NVA097_CALL_MME_DATA(106):
    case NVA097_CALL_MME_DATA(107):
    case NVA097_CALL_MME_DATA(108):
    case NVA097_CALL_MME_DATA(109):
    case NVA097_CALL_MME_DATA(110):
    case NVA097_CALL_MME_DATA(111):
    case NVA097_CALL_MME_DATA(112):
    case NVA097_CALL_MME_DATA(113):
    case NVA097_CALL_MME_DATA(114):
    case NVA097_CALL_MME_DATA(115):
    case NVA097_CALL_MME_DATA(116):
    case NVA097_CALL_MME_DATA(117):
    case NVA097_CALL_MME_DATA(118):
    case NVA097_CALL_MME_DATA(119):
    case NVA097_CALL_MME_DATA(120):
    case NVA097_CALL_MME_DATA(121):
    case NVA097_CALL_MME_DATA(122):
    case NVA097_CALL_MME_DATA(123):
    case NVA097_CALL_MME_DATA(124):
    case NVA097_CALL_MME_DATA(125):
    case NVA097_CALL_MME_DATA(126):
    case NVA097_CALL_MME_DATA(127):
    case NVA097_CALL_MME_DATA(128):
    case NVA097_CALL_MME_DATA(129):
    case NVA097_CALL_MME_DATA(130):
    case NVA097_CALL_MME_DATA(131):
    case NVA097_CALL_MME_DATA(132):
    case NVA097_CALL_MME_DATA(133):
    case NVA097_CALL_MME_DATA(134):
    case NVA097_CALL_MME_DATA(135):
    case NVA097_CALL_MME_DATA(136):
    case NVA097_CALL_MME_DATA(137):
    case NVA097_CALL_MME_DATA(138):
    case NVA097_CALL_MME_DATA(139):
    case NVA097_CALL_MME_DATA(140):
    case NVA097_CALL_MME_DATA(141):
    case NVA097_CALL_MME_DATA(142):
    case NVA097_CALL_MME_DATA(143):
    case NVA097_CALL_MME_DATA(144):
    case NVA097_CALL_MME_DATA(145):
    case NVA097_CALL_MME_DATA(146):
    case NVA097_CALL_MME_DATA(147):
    case NVA097_CALL_MME_DATA(148):
    case NVA097_CALL_MME_DATA(149):
    case NVA097_CALL_MME_DATA(150):
    case NVA097_CALL_MME_DATA(151):
    case NVA097_CALL_MME_DATA(152):
    case NVA097_CALL_MME_DATA(153):
    case NVA097_CALL_MME_DATA(154):
    case NVA097_CALL_MME_DATA(155):
    case NVA097_CALL_MME_DATA(156):
    case NVA097_CALL_MME_DATA(157):
    case NVA097_CALL_MME_DATA(158):
    case NVA097_CALL_MME_DATA(159):
    case NVA097_CALL_MME_DATA(160):
    case NVA097_CALL_MME_DATA(161):
    case NVA097_CALL_MME_DATA(162):
    case NVA097_CALL_MME_DATA(163):
    case NVA097_CALL_MME_DATA(164):
    case NVA097_CALL_MME_DATA(165):
    case NVA097_CALL_MME_DATA(166):
    case NVA097_CALL_MME_DATA(167):
    case NVA097_CALL_MME_DATA(168):
    case NVA097_CALL_MME_DATA(169):
    case NVA097_CALL_MME_DATA(170):
    case NVA097_CALL_MME_DATA(171):
    case NVA097_CALL_MME_DATA(172):
    case NVA097_CALL_MME_DATA(173):
    case NVA097_CALL_MME_DATA(174):
    case NVA097_CALL_MME_DATA(175):
    case NVA097_CALL_MME_DATA(176):
    case NVA097_CALL_MME_DATA(177):
    case NVA097_CALL_MME_DATA(178):
    case NVA097_CALL_MME_DATA(179):
    case NVA097_CALL_MME_DATA(180):
    case NVA097_CALL_MME_DATA(181):
    case NVA097_CALL_MME_DATA(182):
    case NVA097_CALL_MME_DATA(183):
    case NVA097_CALL_MME_DATA(184):
    case NVA097_CALL_MME_DATA(185):
    case NVA097_CALL_MME_DATA(186):
    case NVA097_CALL_MME_DATA(187):
    case NVA097_CALL_MME_DATA(188):
    case NVA097_CALL_MME_DATA(189):
    case NVA097_CALL_MME_DATA(190):
    case NVA097_CALL_MME_DATA(191):
    case NVA097_CALL_MME_DATA(192):
    case NVA097_CALL_MME_DATA(193):
    case NVA097_CALL_MME_DATA(194):
    case NVA097_CALL_MME_DATA(195):
    case NVA097_CALL_MME_DATA(196):
    case NVA097_CALL_MME_DATA(197):
    case NVA097_CALL_MME_DATA(198):
    case NVA097_CALL_MME_DATA(199):
    case NVA097_CALL_MME_DATA(200):
    case NVA097_CALL_MME_DATA(201):
    case NVA097_CALL_MME_DATA(202):
    case NVA097_CALL_MME_DATA(203):
    case NVA097_CALL_MME_DATA(204):
    case NVA097_CALL_MME_DATA(205):
    case NVA097_CALL_MME_DATA(206):
    case NVA097_CALL_MME_DATA(207):
    case NVA097_CALL_MME_DATA(208):
    case NVA097_CALL_MME_DATA(209):
    case NVA097_CALL_MME_DATA(210):
    case NVA097_CALL_MME_DATA(211):
    case NVA097_CALL_MME_DATA(212):
    case NVA097_CALL_MME_DATA(213):
    case NVA097_CALL_MME_DATA(214):
    case NVA097_CALL_MME_DATA(215):
    case NVA097_CALL_MME_DATA(216):
    case NVA097_CALL_MME_DATA(217):
    case NVA097_CALL_MME_DATA(218):
    case NVA097_CALL_MME_DATA(219):
    case NVA097_CALL_MME_DATA(220):
    case NVA097_CALL_MME_DATA(221):
    case NVA097_CALL_MME_DATA(222):
    case NVA097_CALL_MME_DATA(223):
    case NVA097_CALL_MME_DATA(224):
    case NVA097_CALL_MME_DATA(225):
    case NVA097_CALL_MME_DATA(226):
    case NVA097_CALL_MME_DATA(227):
    case NVA097_CALL_MME_DATA(228):
    case NVA097_CALL_MME_DATA(229):
    case NVA097_CALL_MME_DATA(230):
    case NVA097_CALL_MME_DATA(231):
    case NVA097_CALL_MME_DATA(232):
    case NVA097_CALL_MME_DATA(233):
    case NVA097_CALL_MME_DATA(234):
    case NVA097_CALL_MME_DATA(235):
    case NVA097_CALL_MME_DATA(236):
    case NVA097_CALL_MME_DATA(237):
    case NVA097_CALL_MME_DATA(238):
    case NVA097_CALL_MME_DATA(239):
    case NVA097_CALL_MME_DATA(240):
    case NVA097_CALL_MME_DATA(241):
    case NVA097_CALL_MME_DATA(242):
    case NVA097_CALL_MME_DATA(243):
    case NVA097_CALL_MME_DATA(244):
    case NVA097_CALL_MME_DATA(245):
    case NVA097_CALL_MME_DATA(246):
    case NVA097_CALL_MME_DATA(247):
    case NVA097_CALL_MME_DATA(248):
    case NVA097_CALL_MME_DATA(249):
    case NVA097_CALL_MME_DATA(250):
    case NVA097_CALL_MME_DATA(251):
    case NVA097_CALL_MME_DATA(252):
    case NVA097_CALL_MME_DATA(253):
    case NVA097_CALL_MME_DATA(254):
    case NVA097_CALL_MME_DATA(255):


    return P_PARSE_NV9297_MTHD(idx);

                                                                            case NVA097_PM_TRIGGER_WFI:
        return "NVA097_PM_TRIGGER_WFI";
            case NVA097_LINE_LENGTH_IN:
        return "NVA097_LINE_LENGTH_IN";
    case NVA097_LINE_COUNT:
        return "NVA097_LINE_COUNT";
    case NVA097_OFFSET_OUT_UPPER:
        return "NVA097_OFFSET_OUT_UPPER";
    case NVA097_OFFSET_OUT:
        return "NVA097_OFFSET_OUT";
    case NVA097_PITCH_OUT:
        return "NVA097_PITCH_OUT";
    case NVA097_SET_DST_BLOCK_SIZE:
        return "NVA097_SET_DST_BLOCK_SIZE";
    case NVA097_SET_DST_WIDTH:
        return "NVA097_SET_DST_WIDTH";
    case NVA097_SET_DST_HEIGHT:
        return "NVA097_SET_DST_HEIGHT";
    case NVA097_SET_DST_DEPTH:
        return "NVA097_SET_DST_DEPTH";
    case NVA097_SET_DST_LAYER:
        return "NVA097_SET_DST_LAYER";
    case NVA097_SET_DST_ORIGIN_BYTES_X:
        return "NVA097_SET_DST_ORIGIN_BYTES_X";
    case NVA097_SET_DST_ORIGIN_SAMPLES_Y:
        return "NVA097_SET_DST_ORIGIN_SAMPLES_Y";
    case NVA097_LAUNCH_DMA:
        return "NVA097_LAUNCH_DMA";
    case NVA097_LOAD_INLINE_DATA:
        return "NVA097_LOAD_INLINE_DATA";
    case NVA097_SET_I2M_SEMAPHORE_A:
        return "NVA097_SET_I2M_SEMAPHORE_A";
    case NVA097_SET_I2M_SEMAPHORE_B:
        return "NVA097_SET_I2M_SEMAPHORE_B";
    case NVA097_SET_I2M_SEMAPHORE_C:
        return "NVA097_SET_I2M_SEMAPHORE_C";
    case NVA097_SET_I2M_SPARE_NOOP00:
        return "NVA097_SET_I2M_SPARE_NOOP00";
    case NVA097_SET_I2M_SPARE_NOOP01:
        return "NVA097_SET_I2M_SPARE_NOOP01";
    case NVA097_SET_I2M_SPARE_NOOP02:
        return "NVA097_SET_I2M_SPARE_NOOP02";
    case NVA097_SET_I2M_SPARE_NOOP03:
        return "NVA097_SET_I2M_SPARE_NOOP03";
                                case NVA097_INVALIDATE_SHADER_CACHES:
        return "NVA097_INVALIDATE_SHADER_CACHES";
                                                                                                        case NVA097_SET_SPA_VERSION:
        return "NVA097_SET_SPA_VERSION";
                                                                                                                                                                                                            case NVA097_SET_ISBE_SAVE_RESTORE_PROGRAM:
        return "NVA097_SET_ISBE_SAVE_RESTORE_PROGRAM";
                                                        case NVA097_SET_TEXTURE_INSTRUCTION_OPERAND:
        return "NVA097_SET_TEXTURE_INSTRUCTION_OPERAND";
                                                                                                                                                case NVA097_FORCE_TRANSITION_TO_BETA:
        return "NVA097_FORCE_TRANSITION_TO_BETA";
            case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI:
        return "NVA097_INVALIDATE_SHADER_CACHES_NO_WFI";
                                                                                                                                                                                                                                                                                                                case NVA097_UNBIND_ALL:
        return "NVA097_UNBIND_ALL";
                                                                                                                                                                                                                    case NVA097_INVALIDATE_TEXTURE_DATA_CACHE:
        return "NVA097_INVALIDATE_TEXTURE_DATA_CACHE";
                                                                                                                                                                                                                                                                                                                                                                case NVA097_SET_CLASS_VERSION:
        return "NVA097_SET_CLASS_VERSION";
                                                            case NVA097_SET_SHADER_CONTROL:
        return "NVA097_SET_SHADER_CONTROL";
        case NVA097_CHECK_CLASS_VERSION:
        return "NVA097_CHECK_CLASS_VERSION";
                                                                                                                                                                                                                                                                    case NVA097_SET_REPORT_SEMAPHORE_D:
        return "NVA097_SET_REPORT_SEMAPHORE_D";
                                                                                                                                                                                                                                                                                                case NVA097_NOOP_X_X_X_SET_VALVE:
        return "NVA097_NOOP_X_X_X_SET_VALVE";
    case NVA097_SET_BINDLESS_TEXTURE:
        return "NVA097_SET_BINDLESS_TEXTURE";
    case NVA097_SET_TRAP_HANDLER:
        return "NVA097_SET_TRAP_HANDLER";
            case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(0):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(0)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(1):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(1)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(2):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(2)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(3):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(3)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(4):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(4)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(5):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(5)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(6):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(6)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(7):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(7)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(0):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(0)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(1):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(1)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(2):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(2)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(3):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(3)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(4):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(4)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(5):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(5)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(6):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(6)";
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(7):
        return "NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(7)";
                
    default:
        return "unknown method";
    }
}

void
P_DUMP_NVA097_MTHD_DATA(FILE *fp, uint16_t idx, uint32_t data,
                         const char *prefix)
{
    UNUSED uint32_t parsed;
    switch (idx) {

  
        
    case NVA097_SET_OBJECT:

        
    case NVA097_NO_OPERATION:

        
    case NVA097_SET_NOTIFY_A:

        
    case NVA097_SET_NOTIFY_B:

        
    case NVA097_NOTIFY:

        
    case NVA097_WAIT_FOR_IDLE:

        
    case NVA097_LOAD_MME_INSTRUCTION_RAM_POINTER:

        
    case NVA097_LOAD_MME_INSTRUCTION_RAM:

        
    case NVA097_LOAD_MME_START_ADDRESS_RAM_POINTER:

        
    case NVA097_LOAD_MME_START_ADDRESS_RAM:

        
    case NVA097_SET_MME_SHADOW_RAM_CONTROL:

        
    case NVA097_PEER_SEMAPHORE_RELEASE_OFFSET_UPPER:

        
    case NVA097_PEER_SEMAPHORE_RELEASE_OFFSET:

        
    case NVA097_SET_GLOBAL_RENDER_ENABLE_A:

        
    case NVA097_SET_GLOBAL_RENDER_ENABLE_B:

        
    case NVA097_SET_GLOBAL_RENDER_ENABLE_C:

        
    case NVA097_SEND_GO_IDLE:

        
    case NVA097_PM_TRIGGER:

        
    case NVA097_SET_INSTRUMENTATION_METHOD_HEADER:

        
    case NVA097_SET_INSTRUMENTATION_METHOD_DATA:

        
    case NVA097_RUN_DS_NOW:

        
    case NVA097_SET_OPPORTUNISTIC_EARLY_Z_HYSTERESIS:

        
    case NVA097_SET_RASTER_PIPE_SYNC_CONTROL:

        
    case NVA097_SET_ALIASED_LINE_WIDTH_ENABLE:

        
    case NVA097_SET_API_MANDATED_EARLY_Z:

        
    case NVA097_SET_GS_DM_FIFO:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_PREFETCH_READ_REQUESTS:

        

        

        

        

        

        

        

        

        

        

        
    case NVA097_SET_TASK_CIRCULAR_BUFFER_THROTTLE:

        
    case NVA097_SET_PRIM_CIRCULAR_BUFFER_THROTTLE:

        
    case NVA097_FLUSH_AND_INVALIDATE_ROP_MINI_CACHE:

        
    case NVA097_SET_SURFACE_CLIP_ID_BLOCK_SIZE:

        
    case NVA097_SET_ALPHA_CIRCULAR_BUFFER_SIZE:

        
    case NVA097_SET_ZCULL_ROP_BYPASS:

        
    case NVA097_SET_ZCULL_SUBREGION:

        
    case NVA097_SET_RASTER_BOUNDING_BOX:

        
    case NVA097_PEER_SEMAPHORE_RELEASE:

        
    case NVA097_SET_ZCULL_SUBREGION_ALLOCATION:

        
    case NVA097_ASSIGN_ZCULL_SUBREGIONS:

        
    case NVA097_SET_PS_OUTPUT_SAMPLE_MASK_USAGE:

        
    case NVA097_DRAW_ZERO_INDEX:

        
    case NVA097_SET_L1_CONFIGURATION:

        
    case NVA097_SET_RENDER_ENABLE_CONTROL:

        
    case NVA097_SET_IEEE_CLEAN_UPDATE:

        
    case NVA097_SET_SNAP_GRID_LINE:

        
    case NVA097_SET_SNAP_GRID_NON_LINE:

        
    case NVA097_SET_TESSELLATION_PARAMETERS:

        
    case NVA097_SET_TESSELLATION_LOD_U0_OR_DENSITY:

        
    case NVA097_SET_TESSELLATION_LOD_V0_OR_DETAIL:

        
    case NVA097_SET_TESSELLATION_LOD_U1_OR_W0:

        
    case NVA097_SET_TESSELLATION_LOD_V1:

        
    case NVA097_SET_TG_LOD_INTERIOR_U:

        
    case NVA097_SET_TG_LOD_INTERIOR_V:

        
    case NVA097_RESERVED_TG07:

        
    case NVA097_RESERVED_TG08:

        
    case NVA097_RESERVED_TG09:

        
    case NVA097_RESERVED_TG10:

        
    case NVA097_RESERVED_TG11:

        
    case NVA097_RESERVED_TG12:

        
    case NVA097_RESERVED_TG13:

        
    case NVA097_RESERVED_TG14:

        
    case NVA097_RESERVED_TG15:

        
    case NVA097_SET_SUBTILING_PERF_KNOB_A:

        
    case NVA097_SET_SUBTILING_PERF_KNOB_B:

        
    case NVA097_SET_SUBTILING_PERF_KNOB_C:

        
    case NVA097_SET_ZCULL_SUBREGION_TO_REPORT:

        
    case NVA097_SET_ZCULL_SUBREGION_REPORT_TYPE:

        
    case NVA097_SET_BALANCED_PRIMITIVE_WORKLOAD:

        
    case NVA097_SET_MAX_PATCHES_PER_BATCH:

        
    case NVA097_SET_RASTER_ENABLE:

        
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(0):
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(1):
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(2):
    case NVA097_SET_STREAM_OUT_BUFFER_ENABLE(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(0):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(1):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(2):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_A(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(0):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(1):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(2):
    case NVA097_SET_STREAM_OUT_BUFFER_ADDRESS_B(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(0):
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(1):
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(2):
    case NVA097_SET_STREAM_OUT_BUFFER_SIZE(3):

        
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(0):
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(1):
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(2):
    case NVA097_SET_STREAM_OUT_BUFFER_LOAD_WRITE_POINTER(3):

        

        
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(0):
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(1):
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(2):
    case NVA097_SET_STREAM_OUT_CONTROL_STREAM(3):

        
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(0):
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(1):
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(2):
    case NVA097_SET_STREAM_OUT_CONTROL_COMPONENT_COUNT(3):

        
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(0):
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(1):
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(2):
    case NVA097_SET_STREAM_OUT_CONTROL_STRIDE(3):

        
    case NVA097_SET_RASTER_INPUT:

        
    case NVA097_SET_STREAM_OUTPUT:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_TOPOLOGY_CHANGE:

        
    case NVA097_SET_ALPHA_FRACTION:

        
    case NVA097_SET_HYBRID_ANTI_ALIAS_CONTROL:

        
    case NVA097_SET_MAX_TI_WARPS_PER_BATCH:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_WINDOW:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_A:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_B:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_C:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_D:

        
    case NVA097_SET_SHADER_LOCAL_MEMORY_E:

        
    case NVA097_SET_COLOR_ZERO_BANDWIDTH_CLEAR:

        
    case NVA097_SET_Z_ZERO_BANDWIDTH_CLEAR:

        

        
    case NVA097_SET_ZCULL_REGION_SIZE_A:

        
    case NVA097_SET_ZCULL_REGION_SIZE_B:

        
    case NVA097_SET_ZCULL_REGION_SIZE_C:

        
    case NVA097_SET_ZCULL_REGION_PIXEL_OFFSET_C:

        
    case NVA097_SET_CULL_BEFORE_FETCH:

        
    case NVA097_SET_ZCULL_REGION_LOCATION:

        
    case NVA097_SET_ZCULL_REGION_ALIQUOTS:

        
    case NVA097_SET_ZCULL_STORAGE_A:

        
    case NVA097_SET_ZCULL_STORAGE_B:

        
    case NVA097_SET_ZCULL_STORAGE_C:

        
    case NVA097_SET_ZCULL_STORAGE_D:

        
    case NVA097_SET_ZT_READ_ONLY:

        
    case NVA097_SET_COLOR_TARGET_A(0):
    case NVA097_SET_COLOR_TARGET_A(1):
    case NVA097_SET_COLOR_TARGET_A(2):
    case NVA097_SET_COLOR_TARGET_A(3):
    case NVA097_SET_COLOR_TARGET_A(4):
    case NVA097_SET_COLOR_TARGET_A(5):
    case NVA097_SET_COLOR_TARGET_A(6):
    case NVA097_SET_COLOR_TARGET_A(7):

        
    case NVA097_SET_COLOR_TARGET_B(0):
    case NVA097_SET_COLOR_TARGET_B(1):
    case NVA097_SET_COLOR_TARGET_B(2):
    case NVA097_SET_COLOR_TARGET_B(3):
    case NVA097_SET_COLOR_TARGET_B(4):
    case NVA097_SET_COLOR_TARGET_B(5):
    case NVA097_SET_COLOR_TARGET_B(6):
    case NVA097_SET_COLOR_TARGET_B(7):

        
    case NVA097_SET_COLOR_TARGET_WIDTH(0):
    case NVA097_SET_COLOR_TARGET_WIDTH(1):
    case NVA097_SET_COLOR_TARGET_WIDTH(2):
    case NVA097_SET_COLOR_TARGET_WIDTH(3):
    case NVA097_SET_COLOR_TARGET_WIDTH(4):
    case NVA097_SET_COLOR_TARGET_WIDTH(5):
    case NVA097_SET_COLOR_TARGET_WIDTH(6):
    case NVA097_SET_COLOR_TARGET_WIDTH(7):

        
    case NVA097_SET_COLOR_TARGET_HEIGHT(0):
    case NVA097_SET_COLOR_TARGET_HEIGHT(1):
    case NVA097_SET_COLOR_TARGET_HEIGHT(2):
    case NVA097_SET_COLOR_TARGET_HEIGHT(3):
    case NVA097_SET_COLOR_TARGET_HEIGHT(4):
    case NVA097_SET_COLOR_TARGET_HEIGHT(5):
    case NVA097_SET_COLOR_TARGET_HEIGHT(6):
    case NVA097_SET_COLOR_TARGET_HEIGHT(7):

        
    case NVA097_SET_COLOR_TARGET_FORMAT(0):
    case NVA097_SET_COLOR_TARGET_FORMAT(1):
    case NVA097_SET_COLOR_TARGET_FORMAT(2):
    case NVA097_SET_COLOR_TARGET_FORMAT(3):
    case NVA097_SET_COLOR_TARGET_FORMAT(4):
    case NVA097_SET_COLOR_TARGET_FORMAT(5):
    case NVA097_SET_COLOR_TARGET_FORMAT(6):
    case NVA097_SET_COLOR_TARGET_FORMAT(7):

        
    case NVA097_SET_COLOR_TARGET_MEMORY(0):
    case NVA097_SET_COLOR_TARGET_MEMORY(1):
    case NVA097_SET_COLOR_TARGET_MEMORY(2):
    case NVA097_SET_COLOR_TARGET_MEMORY(3):
    case NVA097_SET_COLOR_TARGET_MEMORY(4):
    case NVA097_SET_COLOR_TARGET_MEMORY(5):
    case NVA097_SET_COLOR_TARGET_MEMORY(6):
    case NVA097_SET_COLOR_TARGET_MEMORY(7):

        
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(0):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(1):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(2):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(3):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(4):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(5):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(6):
    case NVA097_SET_COLOR_TARGET_THIRD_DIMENSION(7):

        
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(0):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(1):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(2):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(3):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(4):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(5):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(6):
    case NVA097_SET_COLOR_TARGET_ARRAY_PITCH(7):

        
    case NVA097_SET_COLOR_TARGET_LAYER(0):
    case NVA097_SET_COLOR_TARGET_LAYER(1):
    case NVA097_SET_COLOR_TARGET_LAYER(2):
    case NVA097_SET_COLOR_TARGET_LAYER(3):
    case NVA097_SET_COLOR_TARGET_LAYER(4):
    case NVA097_SET_COLOR_TARGET_LAYER(5):
    case NVA097_SET_COLOR_TARGET_LAYER(6):
    case NVA097_SET_COLOR_TARGET_LAYER(7):

        
    case NVA097_SET_COLOR_TARGET_MARK(0):
    case NVA097_SET_COLOR_TARGET_MARK(1):
    case NVA097_SET_COLOR_TARGET_MARK(2):
    case NVA097_SET_COLOR_TARGET_MARK(3):
    case NVA097_SET_COLOR_TARGET_MARK(4):
    case NVA097_SET_COLOR_TARGET_MARK(5):
    case NVA097_SET_COLOR_TARGET_MARK(6):
    case NVA097_SET_COLOR_TARGET_MARK(7):

        
    case NVA097_SET_VIEWPORT_SCALE_X(0):
    case NVA097_SET_VIEWPORT_SCALE_X(1):
    case NVA097_SET_VIEWPORT_SCALE_X(2):
    case NVA097_SET_VIEWPORT_SCALE_X(3):
    case NVA097_SET_VIEWPORT_SCALE_X(4):
    case NVA097_SET_VIEWPORT_SCALE_X(5):
    case NVA097_SET_VIEWPORT_SCALE_X(6):
    case NVA097_SET_VIEWPORT_SCALE_X(7):
    case NVA097_SET_VIEWPORT_SCALE_X(8):
    case NVA097_SET_VIEWPORT_SCALE_X(9):
    case NVA097_SET_VIEWPORT_SCALE_X(10):
    case NVA097_SET_VIEWPORT_SCALE_X(11):
    case NVA097_SET_VIEWPORT_SCALE_X(12):
    case NVA097_SET_VIEWPORT_SCALE_X(13):
    case NVA097_SET_VIEWPORT_SCALE_X(14):
    case NVA097_SET_VIEWPORT_SCALE_X(15):

        
    case NVA097_SET_VIEWPORT_SCALE_Y(0):
    case NVA097_SET_VIEWPORT_SCALE_Y(1):
    case NVA097_SET_VIEWPORT_SCALE_Y(2):
    case NVA097_SET_VIEWPORT_SCALE_Y(3):
    case NVA097_SET_VIEWPORT_SCALE_Y(4):
    case NVA097_SET_VIEWPORT_SCALE_Y(5):
    case NVA097_SET_VIEWPORT_SCALE_Y(6):
    case NVA097_SET_VIEWPORT_SCALE_Y(7):
    case NVA097_SET_VIEWPORT_SCALE_Y(8):
    case NVA097_SET_VIEWPORT_SCALE_Y(9):
    case NVA097_SET_VIEWPORT_SCALE_Y(10):
    case NVA097_SET_VIEWPORT_SCALE_Y(11):
    case NVA097_SET_VIEWPORT_SCALE_Y(12):
    case NVA097_SET_VIEWPORT_SCALE_Y(13):
    case NVA097_SET_VIEWPORT_SCALE_Y(14):
    case NVA097_SET_VIEWPORT_SCALE_Y(15):

        
    case NVA097_SET_VIEWPORT_SCALE_Z(0):
    case NVA097_SET_VIEWPORT_SCALE_Z(1):
    case NVA097_SET_VIEWPORT_SCALE_Z(2):
    case NVA097_SET_VIEWPORT_SCALE_Z(3):
    case NVA097_SET_VIEWPORT_SCALE_Z(4):
    case NVA097_SET_VIEWPORT_SCALE_Z(5):
    case NVA097_SET_VIEWPORT_SCALE_Z(6):
    case NVA097_SET_VIEWPORT_SCALE_Z(7):
    case NVA097_SET_VIEWPORT_SCALE_Z(8):
    case NVA097_SET_VIEWPORT_SCALE_Z(9):
    case NVA097_SET_VIEWPORT_SCALE_Z(10):
    case NVA097_SET_VIEWPORT_SCALE_Z(11):
    case NVA097_SET_VIEWPORT_SCALE_Z(12):
    case NVA097_SET_VIEWPORT_SCALE_Z(13):
    case NVA097_SET_VIEWPORT_SCALE_Z(14):
    case NVA097_SET_VIEWPORT_SCALE_Z(15):

        
    case NVA097_SET_VIEWPORT_OFFSET_X(0):
    case NVA097_SET_VIEWPORT_OFFSET_X(1):
    case NVA097_SET_VIEWPORT_OFFSET_X(2):
    case NVA097_SET_VIEWPORT_OFFSET_X(3):
    case NVA097_SET_VIEWPORT_OFFSET_X(4):
    case NVA097_SET_VIEWPORT_OFFSET_X(5):
    case NVA097_SET_VIEWPORT_OFFSET_X(6):
    case NVA097_SET_VIEWPORT_OFFSET_X(7):
    case NVA097_SET_VIEWPORT_OFFSET_X(8):
    case NVA097_SET_VIEWPORT_OFFSET_X(9):
    case NVA097_SET_VIEWPORT_OFFSET_X(10):
    case NVA097_SET_VIEWPORT_OFFSET_X(11):
    case NVA097_SET_VIEWPORT_OFFSET_X(12):
    case NVA097_SET_VIEWPORT_OFFSET_X(13):
    case NVA097_SET_VIEWPORT_OFFSET_X(14):
    case NVA097_SET_VIEWPORT_OFFSET_X(15):

        
    case NVA097_SET_VIEWPORT_OFFSET_Y(0):
    case NVA097_SET_VIEWPORT_OFFSET_Y(1):
    case NVA097_SET_VIEWPORT_OFFSET_Y(2):
    case NVA097_SET_VIEWPORT_OFFSET_Y(3):
    case NVA097_SET_VIEWPORT_OFFSET_Y(4):
    case NVA097_SET_VIEWPORT_OFFSET_Y(5):
    case NVA097_SET_VIEWPORT_OFFSET_Y(6):
    case NVA097_SET_VIEWPORT_OFFSET_Y(7):
    case NVA097_SET_VIEWPORT_OFFSET_Y(8):
    case NVA097_SET_VIEWPORT_OFFSET_Y(9):
    case NVA097_SET_VIEWPORT_OFFSET_Y(10):
    case NVA097_SET_VIEWPORT_OFFSET_Y(11):
    case NVA097_SET_VIEWPORT_OFFSET_Y(12):
    case NVA097_SET_VIEWPORT_OFFSET_Y(13):
    case NVA097_SET_VIEWPORT_OFFSET_Y(14):
    case NVA097_SET_VIEWPORT_OFFSET_Y(15):

        
    case NVA097_SET_VIEWPORT_OFFSET_Z(0):
    case NVA097_SET_VIEWPORT_OFFSET_Z(1):
    case NVA097_SET_VIEWPORT_OFFSET_Z(2):
    case NVA097_SET_VIEWPORT_OFFSET_Z(3):
    case NVA097_SET_VIEWPORT_OFFSET_Z(4):
    case NVA097_SET_VIEWPORT_OFFSET_Z(5):
    case NVA097_SET_VIEWPORT_OFFSET_Z(6):
    case NVA097_SET_VIEWPORT_OFFSET_Z(7):
    case NVA097_SET_VIEWPORT_OFFSET_Z(8):
    case NVA097_SET_VIEWPORT_OFFSET_Z(9):
    case NVA097_SET_VIEWPORT_OFFSET_Z(10):
    case NVA097_SET_VIEWPORT_OFFSET_Z(11):
    case NVA097_SET_VIEWPORT_OFFSET_Z(12):
    case NVA097_SET_VIEWPORT_OFFSET_Z(13):
    case NVA097_SET_VIEWPORT_OFFSET_Z(14):
    case NVA097_SET_VIEWPORT_OFFSET_Z(15):

        
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(0):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(1):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(2):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(3):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(4):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(5):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(6):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(7):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(8):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(9):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(10):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(11):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(12):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(13):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(14):
    case NVA097_SET_VIEWPORT_CLIP_HORIZONTAL(15):

        
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(0):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(1):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(2):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(3):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(4):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(5):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(6):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(7):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(8):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(9):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(10):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(11):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(12):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(13):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(14):
    case NVA097_SET_VIEWPORT_CLIP_VERTICAL(15):

        
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(0):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(1):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(2):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(3):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(4):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(5):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(6):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(7):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(8):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(9):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(10):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(11):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(12):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(13):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(14):
    case NVA097_SET_VIEWPORT_CLIP_MIN_Z(15):

        
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(0):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(1):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(2):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(3):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(4):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(5):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(6):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(7):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(8):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(9):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(10):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(11):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(12):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(13):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(14):
    case NVA097_SET_VIEWPORT_CLIP_MAX_Z(15):

        
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(0):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(1):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(2):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(3):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(4):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(5):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(6):
    case NVA097_SET_WINDOW_CLIP_HORIZONTAL(7):

        
    case NVA097_SET_WINDOW_CLIP_VERTICAL(0):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(1):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(2):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(3):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(4):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(5):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(6):
    case NVA097_SET_WINDOW_CLIP_VERTICAL(7):

        
    case NVA097_SET_CLIP_ID_EXTENT_X(0):
    case NVA097_SET_CLIP_ID_EXTENT_X(1):
    case NVA097_SET_CLIP_ID_EXTENT_X(2):
    case NVA097_SET_CLIP_ID_EXTENT_X(3):

        
    case NVA097_SET_CLIP_ID_EXTENT_Y(0):
    case NVA097_SET_CLIP_ID_EXTENT_Y(1):
    case NVA097_SET_CLIP_ID_EXTENT_Y(2):
    case NVA097_SET_CLIP_ID_EXTENT_Y(3):

        
    case NVA097_SET_MAX_STREAM_OUTPUT_GS_INSTANCES_PER_TASK:

        
    case NVA097_SET_API_VISIBLE_CALL_LIMIT:

        
    case NVA097_SET_STATISTICS_COUNTER:

        
    case NVA097_SET_CLEAR_RECT_HORIZONTAL:

        
    case NVA097_SET_CLEAR_RECT_VERTICAL:

        
    case NVA097_SET_VERTEX_ARRAY_START:

        
    case NVA097_DRAW_VERTEX_ARRAY:

        
    case NVA097_SET_VIEWPORT_Z_CLIP:

        
    case NVA097_SET_COLOR_CLEAR_VALUE(0):
    case NVA097_SET_COLOR_CLEAR_VALUE(1):
    case NVA097_SET_COLOR_CLEAR_VALUE(2):
    case NVA097_SET_COLOR_CLEAR_VALUE(3):

        
    case NVA097_SET_Z_CLEAR_VALUE:

        
    case NVA097_SET_SHADER_CACHE_CONTROL:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_ENABLE:

        
    case NVA097_SET_STENCIL_CLEAR_VALUE:

        
    case NVA097_SET_FRONT_POLYGON_MODE:

        
    case NVA097_SET_BACK_POLYGON_MODE:

        
    case NVA097_SET_POLY_SMOOTH:

        
    case NVA097_SET_ZT_MARK:

        
    case NVA097_SET_ZCULL_DIR_FORMAT:

        
    case NVA097_SET_POLY_OFFSET_POINT:

        
    case NVA097_SET_POLY_OFFSET_LINE:

        
    case NVA097_SET_POLY_OFFSET_FILL:

        
    case NVA097_SET_PATCH:

        
    case NVA097_SET_ZCULL_CRITERION:

        
    case NVA097_SET_SM_TIMEOUT_INTERVAL:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_VERTEX_ARRAY:

        
    case NVA097_SET_DRAW_INLINE_VERTEX_VAB_UPDATE:

        
    case NVA097_SET_WINDOW_OFFSET_X:

        
    case NVA097_SET_WINDOW_OFFSET_Y:

        
    case NVA097_SET_SCISSOR_ENABLE(0):
    case NVA097_SET_SCISSOR_ENABLE(1):
    case NVA097_SET_SCISSOR_ENABLE(2):
    case NVA097_SET_SCISSOR_ENABLE(3):
    case NVA097_SET_SCISSOR_ENABLE(4):
    case NVA097_SET_SCISSOR_ENABLE(5):
    case NVA097_SET_SCISSOR_ENABLE(6):
    case NVA097_SET_SCISSOR_ENABLE(7):
    case NVA097_SET_SCISSOR_ENABLE(8):
    case NVA097_SET_SCISSOR_ENABLE(9):
    case NVA097_SET_SCISSOR_ENABLE(10):
    case NVA097_SET_SCISSOR_ENABLE(11):
    case NVA097_SET_SCISSOR_ENABLE(12):
    case NVA097_SET_SCISSOR_ENABLE(13):
    case NVA097_SET_SCISSOR_ENABLE(14):
    case NVA097_SET_SCISSOR_ENABLE(15):

        
    case NVA097_SET_SCISSOR_HORIZONTAL(0):
    case NVA097_SET_SCISSOR_HORIZONTAL(1):
    case NVA097_SET_SCISSOR_HORIZONTAL(2):
    case NVA097_SET_SCISSOR_HORIZONTAL(3):
    case NVA097_SET_SCISSOR_HORIZONTAL(4):
    case NVA097_SET_SCISSOR_HORIZONTAL(5):
    case NVA097_SET_SCISSOR_HORIZONTAL(6):
    case NVA097_SET_SCISSOR_HORIZONTAL(7):
    case NVA097_SET_SCISSOR_HORIZONTAL(8):
    case NVA097_SET_SCISSOR_HORIZONTAL(9):
    case NVA097_SET_SCISSOR_HORIZONTAL(10):
    case NVA097_SET_SCISSOR_HORIZONTAL(11):
    case NVA097_SET_SCISSOR_HORIZONTAL(12):
    case NVA097_SET_SCISSOR_HORIZONTAL(13):
    case NVA097_SET_SCISSOR_HORIZONTAL(14):
    case NVA097_SET_SCISSOR_HORIZONTAL(15):

        
    case NVA097_SET_SCISSOR_VERTICAL(0):
    case NVA097_SET_SCISSOR_VERTICAL(1):
    case NVA097_SET_SCISSOR_VERTICAL(2):
    case NVA097_SET_SCISSOR_VERTICAL(3):
    case NVA097_SET_SCISSOR_VERTICAL(4):
    case NVA097_SET_SCISSOR_VERTICAL(5):
    case NVA097_SET_SCISSOR_VERTICAL(6):
    case NVA097_SET_SCISSOR_VERTICAL(7):
    case NVA097_SET_SCISSOR_VERTICAL(8):
    case NVA097_SET_SCISSOR_VERTICAL(9):
    case NVA097_SET_SCISSOR_VERTICAL(10):
    case NVA097_SET_SCISSOR_VERTICAL(11):
    case NVA097_SET_SCISSOR_VERTICAL(12):
    case NVA097_SET_SCISSOR_VERTICAL(13):
    case NVA097_SET_SCISSOR_VERTICAL(14):
    case NVA097_SET_SCISSOR_VERTICAL(15):

        

        
    case NVA097_SET_BACK_STENCIL_FUNC_REF:

        
    case NVA097_SET_BACK_STENCIL_MASK:

        
    case NVA097_SET_BACK_STENCIL_FUNC_MASK:

        
    case NVA097_SET_VERTEX_STREAM_SUBSTITUTE_A:

        
    case NVA097_SET_VERTEX_STREAM_SUBSTITUTE_B:

        
    case NVA097_SET_LINE_MODE_POLYGON_CLIP:

        
    case NVA097_SET_SINGLE_CT_WRITE_CONTROL:

        
    case NVA097_SET_VTG_WARP_WATERMARKS:

        
    case NVA097_SET_DEPTH_BOUNDS_MIN:

        
    case NVA097_SET_DEPTH_BOUNDS_MAX:

        
    case NVA097_SET_CT_MRT_ENABLE:

        
    case NVA097_SET_NONMULTISAMPLED_Z:

        
    case NVA097_SET_SAMPLE_MASK_X0_Y0:

        
    case NVA097_SET_SAMPLE_MASK_X1_Y0:

        
    case NVA097_SET_SAMPLE_MASK_X0_Y1:

        
    case NVA097_SET_SAMPLE_MASK_X1_Y1:

        
    case NVA097_SET_SURFACE_CLIP_ID_MEMORY_A:

        
    case NVA097_SET_SURFACE_CLIP_ID_MEMORY_B:

        
    case NVA097_SET_BLEND_OPT_CONTROL:

        
    case NVA097_SET_ZT_A:

        
    case NVA097_SET_ZT_B:

        
    case NVA097_SET_ZT_FORMAT:

        
    case NVA097_SET_ZT_BLOCK_SIZE:

        
    case NVA097_SET_ZT_ARRAY_PITCH:

        
    case NVA097_SET_SURFACE_CLIP_HORIZONTAL:

        
    case NVA097_SET_SURFACE_CLIP_VERTICAL:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_VAF_REQUESTS:

        
    case NVA097_SET_TESSELLATION_CUT_HEIGHT:

        
    case NVA097_SET_MAX_GS_INSTANCES_PER_TASK:

        
    case NVA097_SET_MAX_GS_OUTPUT_VERTICES_PER_TASK:

        
    case NVA097_SET_GS_OUTPUT_CB_STORAGE_MULTIPLIER:

        
    case NVA097_SET_BETA_CB_STORAGE_CONSTRAINT:

        
    case NVA097_SET_TI_OUTPUT_CB_STORAGE_MULTIPLIER:

        
    case NVA097_SET_ALPHA_CB_STORAGE_CONSTRAINT:

        
    case NVA097_SET_SPARE_NOOP00:

        
    case NVA097_SET_SPARE_NOOP01:

        
    case NVA097_SET_SPARE_NOOP02:

        
    case NVA097_SET_SPARE_NOOP03:

        
    case NVA097_SET_SPARE_NOOP04:

        
    case NVA097_SET_SPARE_NOOP05:

        
    case NVA097_SET_SPARE_NOOP06:

        
    case NVA097_SET_SPARE_NOOP07:

        
    case NVA097_SET_SPARE_NOOP08:

        
    case NVA097_SET_SPARE_NOOP09:

        
    case NVA097_SET_SPARE_NOOP10:

        
    case NVA097_SET_SPARE_NOOP11:

        
    case NVA097_SET_SPARE_NOOP12:

        
    case NVA097_SET_SPARE_NOOP13:

        
    case NVA097_SET_SPARE_NOOP14:

        
    case NVA097_SET_SPARE_NOOP15:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_UNORM8:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_UNORM10:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_UNORM16:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_FP11:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_FP16:

        
    case NVA097_SET_REDUCE_COLOR_THRESHOLDS_SRGB8:

        
    case NVA097_SET_CLEAR_SURFACE_CONTROL:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_NONINTERLOCKED_READ_REQUESTS:

        
    case NVA097_NO_OPERATION_DATA_HI:

        
    case NVA097_SET_DEPTH_BIAS_CONTROL:

        
    case NVA097_PM_TRIGGER_END:

        
    case NVA097_SET_VERTEX_ID_BASE:

        

        

        
    case NVA097_SET_BLEND_PER_FORMAT_ENABLE:

        
    case NVA097_FLUSH_PENDING_WRITES:

        
    case NVA097_SET_VAB_DATA_CONTROL:

        

        
    case NVA097_SET_VERTEX_ATTRIBUTE_A(0):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(1):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(2):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(3):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(4):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(5):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(6):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(7):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(8):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(9):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(10):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(11):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(12):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(13):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(14):
    case NVA097_SET_VERTEX_ATTRIBUTE_A(15):

        
    case NVA097_SET_VERTEX_ATTRIBUTE_B(0):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(1):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(2):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(3):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(4):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(5):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(6):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(7):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(8):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(9):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(10):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(11):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(12):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(13):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(14):
    case NVA097_SET_VERTEX_ATTRIBUTE_B(15):

        
    case NVA097_DRAW_VERTEX_ARRAY_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_VERTEX_ARRAY_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_SET_CT_SELECT:

        
    case NVA097_SET_COMPRESSION_THRESHOLD:

        
    case NVA097_SET_ZT_SIZE_A:

        
    case NVA097_SET_ZT_SIZE_B:

        
    case NVA097_SET_ZT_SIZE_C:

        
    case NVA097_SET_SAMPLER_BINDING:

        
    case NVA097_DRAW_AUTO:

        
    case NVA097_SET_CIRCULAR_BUFFER_SIZE:

        
    case NVA097_SET_VTG_REGISTER_WATERMARKS:

        
    case NVA097_INVALIDATE_TEXTURE_DATA_CACHE_NO_WFI:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_INTERLOCKED_READ_REQUESTS:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_INDEX_TOPOLOGY_CHANGE:

        
    case NVA097_SET_SHADER_SCHEDULING:

        
    case NVA097_CLEAR_ZCULL_REGION:

        
    case NVA097_SET_DEPTH_TEST:

        
    case NVA097_SET_FILL_MODE:

        
    case NVA097_SET_SHADE_MODE:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_NONINTERLOCKED_WRITE_REQUESTS:

        
    case NVA097_SET_L2_CACHE_CONTROL_FOR_ROP_INTERLOCKED_WRITE_REQUESTS:

        
    case NVA097_SET_ALPHA_TO_COVERAGE_DITHER_CONTROL:

        
    case NVA097_SET_BLEND_STATE_PER_TARGET:

        
    case NVA097_SET_DEPTH_WRITE:

        
    case NVA097_SET_ALPHA_TEST:

        
    case NVA097_SET_INLINE_INDEX4X8_ALIGN:

        
    case NVA097_DRAW_INLINE_INDEX4X8:

        
    case NVA097_D3D_SET_CULL_MODE:

        
    case NVA097_SET_DEPTH_FUNC:

        
    case NVA097_SET_ALPHA_REF:

        
    case NVA097_SET_ALPHA_FUNC:

        
    case NVA097_SET_DRAW_AUTO_STRIDE:

        
    case NVA097_SET_BLEND_CONST_RED:

        
    case NVA097_SET_BLEND_CONST_GREEN:

        
    case NVA097_SET_BLEND_CONST_BLUE:

        
    case NVA097_SET_BLEND_CONST_ALPHA:

        
    case NVA097_INVALIDATE_SAMPLER_CACHE:

        
    case NVA097_INVALIDATE_TEXTURE_HEADER_CACHE:

        
    case NVA097_SET_BLEND_SEPARATE_FOR_ALPHA:

        
    case NVA097_SET_BLEND_COLOR_OP:

        
    case NVA097_SET_BLEND_COLOR_SOURCE_COEFF:

        
    case NVA097_SET_BLEND_COLOR_DEST_COEFF:

        
    case NVA097_SET_BLEND_ALPHA_OP:

        
    case NVA097_SET_BLEND_ALPHA_SOURCE_COEFF:

        
    case NVA097_SET_GLOBAL_COLOR_KEY:

        
    case NVA097_SET_BLEND_ALPHA_DEST_COEFF:

        
    case NVA097_SET_SINGLE_ROP_CONTROL:

        
    case NVA097_SET_BLEND(0):
    case NVA097_SET_BLEND(1):
    case NVA097_SET_BLEND(2):
    case NVA097_SET_BLEND(3):
    case NVA097_SET_BLEND(4):
    case NVA097_SET_BLEND(5):
    case NVA097_SET_BLEND(6):
    case NVA097_SET_BLEND(7):

        
    case NVA097_SET_STENCIL_TEST:

        
    case NVA097_SET_STENCIL_OP_FAIL:

        
    case NVA097_SET_STENCIL_OP_ZFAIL:

        
    case NVA097_SET_STENCIL_OP_ZPASS:

        
    case NVA097_SET_STENCIL_FUNC:

        
    case NVA097_SET_STENCIL_FUNC_REF:

        
    case NVA097_SET_STENCIL_FUNC_MASK:

        
    case NVA097_SET_STENCIL_MASK:

        
    case NVA097_SET_DRAW_AUTO_START:

        
    case NVA097_SET_PS_SATURATE:

        
    case NVA097_SET_WINDOW_ORIGIN:

        
    case NVA097_SET_LINE_WIDTH_FLOAT:

        
    case NVA097_SET_ALIASED_LINE_WIDTH_FLOAT:

        
    case NVA097_SET_LINE_MULTISAMPLE_OVERRIDE:

        
    case NVA097_SET_ALPHA_HYSTERESIS:

        
    case NVA097_INVALIDATE_SAMPLER_CACHE_NO_WFI:

        
    case NVA097_INVALIDATE_TEXTURE_HEADER_CACHE_NO_WFI:

        
    case NVA097_INVALIDATE_DA_DMA_CACHE:

        
    case NVA097_SET_GLOBAL_BASE_VERTEX_INDEX:

        
    case NVA097_SET_GLOBAL_BASE_INSTANCE_INDEX:

        
    case NVA097_SET_PS_WARP_WATERMARKS:

        
    case NVA097_SET_PS_REGISTER_WATERMARKS:

        
    case NVA097_STORE_ZCULL:

        
    case NVA097_LOAD_ZCULL:

        
    case NVA097_SET_SURFACE_CLIP_ID_HEIGHT:

        
    case NVA097_SET_CLIP_ID_CLEAR_RECT_HORIZONTAL:

        
    case NVA097_SET_CLIP_ID_CLEAR_RECT_VERTICAL:

        
    case NVA097_SET_USER_CLIP_ENABLE:

        
    case NVA097_SET_ZPASS_PIXEL_COUNT:

        
    case NVA097_SET_POINT_SIZE:

        
    case NVA097_SET_ZCULL_STATS:

        
    case NVA097_SET_POINT_SPRITE:

        
    case NVA097_SET_SHADER_EXCEPTIONS:

        
    case NVA097_CLEAR_REPORT_VALUE:

        
    case NVA097_SET_ANTI_ALIAS_ENABLE:

        
    case NVA097_SET_ZT_SELECT:

        
    case NVA097_SET_ANTI_ALIAS_ALPHA_CONTROL:

        
    case NVA097_SET_RENDER_ENABLE_A:

        
    case NVA097_SET_RENDER_ENABLE_B:

        
    case NVA097_SET_RENDER_ENABLE_C:

        
    case NVA097_SET_TEX_SAMPLER_POOL_A:

        
    case NVA097_SET_TEX_SAMPLER_POOL_B:

        
    case NVA097_SET_TEX_SAMPLER_POOL_C:

        
    case NVA097_SET_SLOPE_SCALE_DEPTH_BIAS:

        
    case NVA097_SET_ANTI_ALIASED_LINE:

        
    case NVA097_SET_TEX_HEADER_POOL_A:

        
    case NVA097_SET_TEX_HEADER_POOL_B:

        
    case NVA097_SET_TEX_HEADER_POOL_C:

        
    case NVA097_SET_ACTIVE_ZCULL_REGION:

        
    case NVA097_SET_TWO_SIDED_STENCIL_TEST:

        
    case NVA097_SET_BACK_STENCIL_OP_FAIL:

        
    case NVA097_SET_BACK_STENCIL_OP_ZFAIL:

        
    case NVA097_SET_BACK_STENCIL_OP_ZPASS:

        
    case NVA097_SET_BACK_STENCIL_FUNC:

        
    case NVA097_SET_SRGB_WRITE:

        
    case NVA097_SET_DEPTH_BIAS:

        
    case NVA097_SET_ZCULL_REGION_FORMAT:

        
    case NVA097_SET_RT_LAYER:

        
    case NVA097_SET_ANTI_ALIAS:

        
    case NVA097_SET_EDGE_FLAG:

        
    case NVA097_DRAW_INLINE_INDEX:

        
    case NVA097_SET_INLINE_INDEX2X16_ALIGN:

        
    case NVA097_DRAW_INLINE_INDEX2X16:

        
    case NVA097_SET_VERTEX_GLOBAL_BASE_OFFSET_A:

        
    case NVA097_SET_VERTEX_GLOBAL_BASE_OFFSET_B:

        
    case NVA097_SET_ZCULL_REGION_PIXEL_OFFSET_A:

        
    case NVA097_SET_ZCULL_REGION_PIXEL_OFFSET_B:

        
    case NVA097_SET_POINT_SPRITE_SELECT:

        
    case NVA097_SET_PROGRAM_REGION_A:

        
    case NVA097_SET_PROGRAM_REGION_B:

        
    case NVA097_SET_ATTRIBUTE_DEFAULT:

        
    case NVA097_END:

        
    case NVA097_BEGIN:

        
    case NVA097_SET_VERTEX_ID_COPY:

        
    case NVA097_ADD_TO_PRIMITIVE_ID:

        
    case NVA097_LOAD_PRIMITIVE_ID:

        
    case NVA097_SET_SHADER_BASED_CULL:

        
    case NVA097_SET_VAB_PAGE:

        
    case NVA097_DRAW_INLINE_VERTEX:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART:

        
    case NVA097_SET_DA_PRIMITIVE_RESTART_INDEX:

        
    case NVA097_SET_DA_OUTPUT:

        
    case NVA097_SET_ANTI_ALIASED_POINT:

        
    case NVA097_SET_POINT_CENTER_MODE:

        
    case NVA097_SET_LINE_SMOOTH_PARAMETERS:

        
    case NVA097_SET_LINE_STIPPLE:

        

        
    case NVA097_SET_LINE_STIPPLE_PARAMETERS:

        
    case NVA097_SET_PROVOKING_VERTEX:

        
    case NVA097_SET_TWO_SIDED_LIGHT:

        
    case NVA097_SET_POLYGON_STIPPLE:

        
    case NVA097_LAUNCH_VERTEX:

        
    case NVA097_SET_SPH_VERSION:

        
    case NVA097_CHECK_SPH_VERSION:

        
    case NVA097_SET_ALPHA_TO_COVERAGE_OVERRIDE:

        

        
    case NVA097_SET_AAM_VERSION:

        
    case NVA097_CHECK_AAM_VERSION:

        
    case NVA097_SET_ZT_LAYER:

        
    case NVA097_SET_VAB_MEMORY_AREA_A:

        
    case NVA097_SET_VAB_MEMORY_AREA_B:

        
    case NVA097_SET_VAB_MEMORY_AREA_C:

        
    case NVA097_SET_INDEX_BUFFER_A:

        
    case NVA097_SET_INDEX_BUFFER_B:

        
    case NVA097_SET_INDEX_BUFFER_C:

        
    case NVA097_SET_INDEX_BUFFER_D:

        
    case NVA097_SET_INDEX_BUFFER_E:

        
    case NVA097_SET_INDEX_BUFFER_F:

        
    case NVA097_DRAW_INDEX_BUFFER:

        
    case NVA097_DRAW_INDEX_BUFFER32_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_INDEX_BUFFER16_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_INDEX_BUFFER8_BEGIN_END_INSTANCE_FIRST:

        
    case NVA097_DRAW_INDEX_BUFFER32_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_DRAW_INDEX_BUFFER16_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_DRAW_INDEX_BUFFER8_BEGIN_END_INSTANCE_SUBSEQUENT:

        
    case NVA097_SET_DEPTH_BIAS_CLAMP:

        
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(0):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(1):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(2):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(3):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(4):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(5):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(6):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(7):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(8):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(9):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(10):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(11):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(12):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(13):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(14):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_A(15):

        
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(0):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(1):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(2):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(3):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(4):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(5):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(6):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(7):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(8):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(9):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(10):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(11):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(12):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(13):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(14):
    case NVA097_SET_VERTEX_STREAM_INSTANCE_B(15):

        
    case NVA097_SET_ATTRIBUTE_POINT_SIZE:

        
    case NVA097_OGL_SET_CULL:

        
    case NVA097_OGL_SET_FRONT_FACE:

        
    case NVA097_OGL_SET_CULL_FACE:

        
    case NVA097_SET_VIEWPORT_PIXEL:

        
    case NVA097_SET_VIEWPORT_SCALE_OFFSET:

        
    case NVA097_INVALIDATE_CONSTANT_BUFFER_CACHE:

        
    case NVA097_SET_VIEWPORT_CLIP_CONTROL:

        
    case NVA097_SET_USER_CLIP_OP:

        
    case NVA097_SET_RENDER_ENABLE_OVERRIDE:

        
    case NVA097_SET_PRIMITIVE_TOPOLOGY_CONTROL:

        
    case NVA097_SET_WINDOW_CLIP_ENABLE:

        
    case NVA097_SET_WINDOW_CLIP_TYPE:

        
    case NVA097_INVALIDATE_ZCULL:

        
    case NVA097_SET_ZCULL:

        
    case NVA097_SET_ZCULL_BOUNDS:

        
    case NVA097_SET_PRIMITIVE_TOPOLOGY:

        
    case NVA097_ZCULL_SYNC:

        
    case NVA097_SET_CLIP_ID_TEST:

        
    case NVA097_SET_SURFACE_CLIP_ID_WIDTH:

        
    case NVA097_SET_CLIP_ID:

        
    case NVA097_SET_DEPTH_BOUNDS_TEST:

        
    case NVA097_SET_BLEND_FLOAT_OPTION:

        
    case NVA097_SET_LOGIC_OP:

        
    case NVA097_SET_LOGIC_OP_FUNC:

        
    case NVA097_SET_Z_COMPRESSION:

        
    case NVA097_CLEAR_SURFACE:

        
    case NVA097_CLEAR_CLIP_ID_SURFACE:

        
    case NVA097_SET_COLOR_COMPRESSION(0):
    case NVA097_SET_COLOR_COMPRESSION(1):
    case NVA097_SET_COLOR_COMPRESSION(2):
    case NVA097_SET_COLOR_COMPRESSION(3):
    case NVA097_SET_COLOR_COMPRESSION(4):
    case NVA097_SET_COLOR_COMPRESSION(5):
    case NVA097_SET_COLOR_COMPRESSION(6):
    case NVA097_SET_COLOR_COMPRESSION(7):

        
    case NVA097_SET_CT_WRITE(0):
    case NVA097_SET_CT_WRITE(1):
    case NVA097_SET_CT_WRITE(2):
    case NVA097_SET_CT_WRITE(3):
    case NVA097_SET_CT_WRITE(4):
    case NVA097_SET_CT_WRITE(5):
    case NVA097_SET_CT_WRITE(6):
    case NVA097_SET_CT_WRITE(7):

        
    case NVA097_PIPE_NOP:

        
    case NVA097_SET_SPARE00:

        
    case NVA097_SET_SPARE01:

        
    case NVA097_SET_SPARE02:

        
    case NVA097_SET_SPARE03:

        
    case NVA097_SET_REPORT_SEMAPHORE_A:

        
    case NVA097_SET_REPORT_SEMAPHORE_B:

        
    case NVA097_SET_REPORT_SEMAPHORE_C:

        
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(0):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(1):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(2):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(3):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(4):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(5):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(6):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(7):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(8):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(9):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(10):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(11):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(12):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(13):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(14):
    case NVA097_SET_VERTEX_STREAM_A_FORMAT(15):

        
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(0):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(1):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(2):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(3):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(4):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(5):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(6):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(7):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(8):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(9):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(10):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(11):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(12):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(13):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(14):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_A(15):

        
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(0):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(1):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(2):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(3):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(4):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(5):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(6):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(7):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(8):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(9):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(10):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(11):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(12):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(13):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(14):
    case NVA097_SET_VERTEX_STREAM_A_LOCATION_B(15):

        
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(0):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(1):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(2):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(3):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(4):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(5):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(6):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(7):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(8):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(9):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(10):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(11):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(12):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(13):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(14):
    case NVA097_SET_VERTEX_STREAM_A_FREQUENCY(15):

        
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(0):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(1):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(2):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(3):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(4):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(5):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(6):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(7):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(8):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(9):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(10):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(11):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(12):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(13):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(14):
    case NVA097_SET_VERTEX_STREAM_B_FORMAT(15):

        
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(0):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(1):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(2):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(3):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(4):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(5):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(6):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(7):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(8):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(9):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(10):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(11):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(12):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(13):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(14):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_A(15):

        
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(0):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(1):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(2):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(3):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(4):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(5):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(6):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(7):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(8):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(9):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(10):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(11):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(12):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(13):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(14):
    case NVA097_SET_VERTEX_STREAM_B_LOCATION_B(15):

        
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(0):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(1):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(2):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(3):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(4):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(5):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(6):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(7):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(8):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(9):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(10):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(11):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(12):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(13):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(14):
    case NVA097_SET_VERTEX_STREAM_B_FREQUENCY(15):

        
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(0):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(1):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(2):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(3):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(4):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(5):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(6):
    case NVA097_SET_BLEND_PER_TARGET_SEPARATE_FOR_ALPHA(7):

        
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(0):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(1):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(2):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(3):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(4):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(5):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(6):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_OP(7):

        
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_SOURCE_COEFF(7):

        
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_COLOR_DEST_COEFF(7):

        
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(0):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(1):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(2):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(3):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(4):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(5):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(6):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_OP(7):

        
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_SOURCE_COEFF(7):

        
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(0):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(1):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(2):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(3):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(4):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(5):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(6):
    case NVA097_SET_BLEND_PER_TARGET_ALPHA_DEST_COEFF(7):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_A(15):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_A_B(15):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_A(15):

        
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(0):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(1):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(2):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(3):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(4):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(5):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(6):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(7):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(8):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(9):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(10):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(11):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(12):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(13):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(14):
    case NVA097_SET_VERTEX_STREAM_LIMIT_B_B(15):

        
    case NVA097_SET_PIPELINE_SHADER(0):
    case NVA097_SET_PIPELINE_SHADER(1):
    case NVA097_SET_PIPELINE_SHADER(2):
    case NVA097_SET_PIPELINE_SHADER(3):
    case NVA097_SET_PIPELINE_SHADER(4):
    case NVA097_SET_PIPELINE_SHADER(5):

        
    case NVA097_SET_PIPELINE_PROGRAM(0):
    case NVA097_SET_PIPELINE_PROGRAM(1):
    case NVA097_SET_PIPELINE_PROGRAM(2):
    case NVA097_SET_PIPELINE_PROGRAM(3):
    case NVA097_SET_PIPELINE_PROGRAM(4):
    case NVA097_SET_PIPELINE_PROGRAM(5):

        
    case NVA097_SET_PIPELINE_RESERVED_A(0):
    case NVA097_SET_PIPELINE_RESERVED_A(1):
    case NVA097_SET_PIPELINE_RESERVED_A(2):
    case NVA097_SET_PIPELINE_RESERVED_A(3):
    case NVA097_SET_PIPELINE_RESERVED_A(4):
    case NVA097_SET_PIPELINE_RESERVED_A(5):

        
    case NVA097_SET_PIPELINE_REGISTER_COUNT(0):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(1):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(2):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(3):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(4):
    case NVA097_SET_PIPELINE_REGISTER_COUNT(5):

        
    case NVA097_SET_PIPELINE_BINDING(0):
    case NVA097_SET_PIPELINE_BINDING(1):
    case NVA097_SET_PIPELINE_BINDING(2):
    case NVA097_SET_PIPELINE_BINDING(3):
    case NVA097_SET_PIPELINE_BINDING(4):
    case NVA097_SET_PIPELINE_BINDING(5):

        
    case NVA097_SET_PIPELINE_RESERVED_B(0):
    case NVA097_SET_PIPELINE_RESERVED_B(1):
    case NVA097_SET_PIPELINE_RESERVED_B(2):
    case NVA097_SET_PIPELINE_RESERVED_B(3):
    case NVA097_SET_PIPELINE_RESERVED_B(4):
    case NVA097_SET_PIPELINE_RESERVED_B(5):

        
    case NVA097_SET_PIPELINE_RESERVED_C(0):
    case NVA097_SET_PIPELINE_RESERVED_C(1):
    case NVA097_SET_PIPELINE_RESERVED_C(2):
    case NVA097_SET_PIPELINE_RESERVED_C(3):
    case NVA097_SET_PIPELINE_RESERVED_C(4):
    case NVA097_SET_PIPELINE_RESERVED_C(5):

        
    case NVA097_SET_PIPELINE_RESERVED_D(0):
    case NVA097_SET_PIPELINE_RESERVED_D(1):
    case NVA097_SET_PIPELINE_RESERVED_D(2):
    case NVA097_SET_PIPELINE_RESERVED_D(3):
    case NVA097_SET_PIPELINE_RESERVED_D(4):
    case NVA097_SET_PIPELINE_RESERVED_D(5):

        
    case NVA097_SET_PIPELINE_RESERVED_E(0):
    case NVA097_SET_PIPELINE_RESERVED_E(1):
    case NVA097_SET_PIPELINE_RESERVED_E(2):
    case NVA097_SET_PIPELINE_RESERVED_E(3):
    case NVA097_SET_PIPELINE_RESERVED_E(4):
    case NVA097_SET_PIPELINE_RESERVED_E(5):

        
    case NVA097_SET_FALCON00:

        
    case NVA097_SET_FALCON01:

        
    case NVA097_SET_FALCON02:

        
    case NVA097_SET_FALCON03:

        
    case NVA097_SET_FALCON04:

        
    case NVA097_SET_FALCON05:

        
    case NVA097_SET_FALCON06:

        
    case NVA097_SET_FALCON07:

        
    case NVA097_SET_FALCON08:

        
    case NVA097_SET_FALCON09:

        
    case NVA097_SET_FALCON10:

        
    case NVA097_SET_FALCON11:

        
    case NVA097_SET_FALCON12:

        
    case NVA097_SET_FALCON13:

        
    case NVA097_SET_FALCON14:

        
    case NVA097_SET_FALCON15:

        
    case NVA097_SET_FALCON16:

        
    case NVA097_SET_FALCON17:

        
    case NVA097_SET_FALCON18:

        
    case NVA097_SET_FALCON19:

        
    case NVA097_SET_FALCON20:

        
    case NVA097_SET_FALCON21:

        
    case NVA097_SET_FALCON22:

        
    case NVA097_SET_FALCON23:

        
    case NVA097_SET_FALCON24:

        
    case NVA097_SET_FALCON25:

        
    case NVA097_SET_FALCON26:

        
    case NVA097_SET_FALCON27:

        
    case NVA097_SET_FALCON28:

        
    case NVA097_SET_FALCON29:

        
    case NVA097_SET_FALCON30:

        
    case NVA097_SET_FALCON31:

        
    case NVA097_SET_CONSTANT_BUFFER_SELECTOR_A:

        
    case NVA097_SET_CONSTANT_BUFFER_SELECTOR_B:

        
    case NVA097_SET_CONSTANT_BUFFER_SELECTOR_C:

        
    case NVA097_LOAD_CONSTANT_BUFFER_OFFSET:

        
    case NVA097_LOAD_CONSTANT_BUFFER(0):
    case NVA097_LOAD_CONSTANT_BUFFER(1):
    case NVA097_LOAD_CONSTANT_BUFFER(2):
    case NVA097_LOAD_CONSTANT_BUFFER(3):
    case NVA097_LOAD_CONSTANT_BUFFER(4):
    case NVA097_LOAD_CONSTANT_BUFFER(5):
    case NVA097_LOAD_CONSTANT_BUFFER(6):
    case NVA097_LOAD_CONSTANT_BUFFER(7):
    case NVA097_LOAD_CONSTANT_BUFFER(8):
    case NVA097_LOAD_CONSTANT_BUFFER(9):
    case NVA097_LOAD_CONSTANT_BUFFER(10):
    case NVA097_LOAD_CONSTANT_BUFFER(11):
    case NVA097_LOAD_CONSTANT_BUFFER(12):
    case NVA097_LOAD_CONSTANT_BUFFER(13):
    case NVA097_LOAD_CONSTANT_BUFFER(14):
    case NVA097_LOAD_CONSTANT_BUFFER(15):

        
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(0):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(1):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(2):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(3):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(4):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(5):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(6):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(7):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(8):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(9):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(10):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(11):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(12):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(13):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(14):
    case NVA097_BIND_GROUP_CONSTANT_BUFFER(15):

        
    case NVA097_SET_COLOR_CLAMP:

        
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(0):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(1):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(2):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(3):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(4):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(5):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(6):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_VALUE(7):

        
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(0):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(1):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(2):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(3):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(4):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(5):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(6):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_EVENT(7):

        
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_TRAP_CONTROL:

        
    case NVA097_SET_MME_SHADOW_SCRATCH(0):
    case NVA097_SET_MME_SHADOW_SCRATCH(1):
    case NVA097_SET_MME_SHADOW_SCRATCH(2):
    case NVA097_SET_MME_SHADOW_SCRATCH(3):
    case NVA097_SET_MME_SHADOW_SCRATCH(4):
    case NVA097_SET_MME_SHADOW_SCRATCH(5):
    case NVA097_SET_MME_SHADOW_SCRATCH(6):
    case NVA097_SET_MME_SHADOW_SCRATCH(7):
    case NVA097_SET_MME_SHADOW_SCRATCH(8):
    case NVA097_SET_MME_SHADOW_SCRATCH(9):
    case NVA097_SET_MME_SHADOW_SCRATCH(10):
    case NVA097_SET_MME_SHADOW_SCRATCH(11):
    case NVA097_SET_MME_SHADOW_SCRATCH(12):
    case NVA097_SET_MME_SHADOW_SCRATCH(13):
    case NVA097_SET_MME_SHADOW_SCRATCH(14):
    case NVA097_SET_MME_SHADOW_SCRATCH(15):
    case NVA097_SET_MME_SHADOW_SCRATCH(16):
    case NVA097_SET_MME_SHADOW_SCRATCH(17):
    case NVA097_SET_MME_SHADOW_SCRATCH(18):
    case NVA097_SET_MME_SHADOW_SCRATCH(19):
    case NVA097_SET_MME_SHADOW_SCRATCH(20):
    case NVA097_SET_MME_SHADOW_SCRATCH(21):
    case NVA097_SET_MME_SHADOW_SCRATCH(22):
    case NVA097_SET_MME_SHADOW_SCRATCH(23):
    case NVA097_SET_MME_SHADOW_SCRATCH(24):
    case NVA097_SET_MME_SHADOW_SCRATCH(25):
    case NVA097_SET_MME_SHADOW_SCRATCH(26):
    case NVA097_SET_MME_SHADOW_SCRATCH(27):
    case NVA097_SET_MME_SHADOW_SCRATCH(28):
    case NVA097_SET_MME_SHADOW_SCRATCH(29):
    case NVA097_SET_MME_SHADOW_SCRATCH(30):
    case NVA097_SET_MME_SHADOW_SCRATCH(31):
    case NVA097_SET_MME_SHADOW_SCRATCH(32):
    case NVA097_SET_MME_SHADOW_SCRATCH(33):
    case NVA097_SET_MME_SHADOW_SCRATCH(34):
    case NVA097_SET_MME_SHADOW_SCRATCH(35):
    case NVA097_SET_MME_SHADOW_SCRATCH(36):
    case NVA097_SET_MME_SHADOW_SCRATCH(37):
    case NVA097_SET_MME_SHADOW_SCRATCH(38):
    case NVA097_SET_MME_SHADOW_SCRATCH(39):
    case NVA097_SET_MME_SHADOW_SCRATCH(40):
    case NVA097_SET_MME_SHADOW_SCRATCH(41):
    case NVA097_SET_MME_SHADOW_SCRATCH(42):
    case NVA097_SET_MME_SHADOW_SCRATCH(43):
    case NVA097_SET_MME_SHADOW_SCRATCH(44):
    case NVA097_SET_MME_SHADOW_SCRATCH(45):
    case NVA097_SET_MME_SHADOW_SCRATCH(46):
    case NVA097_SET_MME_SHADOW_SCRATCH(47):
    case NVA097_SET_MME_SHADOW_SCRATCH(48):
    case NVA097_SET_MME_SHADOW_SCRATCH(49):
    case NVA097_SET_MME_SHADOW_SCRATCH(50):
    case NVA097_SET_MME_SHADOW_SCRATCH(51):
    case NVA097_SET_MME_SHADOW_SCRATCH(52):
    case NVA097_SET_MME_SHADOW_SCRATCH(53):
    case NVA097_SET_MME_SHADOW_SCRATCH(54):
    case NVA097_SET_MME_SHADOW_SCRATCH(55):
    case NVA097_SET_MME_SHADOW_SCRATCH(56):
    case NVA097_SET_MME_SHADOW_SCRATCH(57):
    case NVA097_SET_MME_SHADOW_SCRATCH(58):
    case NVA097_SET_MME_SHADOW_SCRATCH(59):
    case NVA097_SET_MME_SHADOW_SCRATCH(60):
    case NVA097_SET_MME_SHADOW_SCRATCH(61):
    case NVA097_SET_MME_SHADOW_SCRATCH(62):
    case NVA097_SET_MME_SHADOW_SCRATCH(63):
    case NVA097_SET_MME_SHADOW_SCRATCH(64):
    case NVA097_SET_MME_SHADOW_SCRATCH(65):
    case NVA097_SET_MME_SHADOW_SCRATCH(66):
    case NVA097_SET_MME_SHADOW_SCRATCH(67):
    case NVA097_SET_MME_SHADOW_SCRATCH(68):
    case NVA097_SET_MME_SHADOW_SCRATCH(69):
    case NVA097_SET_MME_SHADOW_SCRATCH(70):
    case NVA097_SET_MME_SHADOW_SCRATCH(71):
    case NVA097_SET_MME_SHADOW_SCRATCH(72):
    case NVA097_SET_MME_SHADOW_SCRATCH(73):
    case NVA097_SET_MME_SHADOW_SCRATCH(74):
    case NVA097_SET_MME_SHADOW_SCRATCH(75):
    case NVA097_SET_MME_SHADOW_SCRATCH(76):
    case NVA097_SET_MME_SHADOW_SCRATCH(77):
    case NVA097_SET_MME_SHADOW_SCRATCH(78):
    case NVA097_SET_MME_SHADOW_SCRATCH(79):
    case NVA097_SET_MME_SHADOW_SCRATCH(80):
    case NVA097_SET_MME_SHADOW_SCRATCH(81):
    case NVA097_SET_MME_SHADOW_SCRATCH(82):
    case NVA097_SET_MME_SHADOW_SCRATCH(83):
    case NVA097_SET_MME_SHADOW_SCRATCH(84):
    case NVA097_SET_MME_SHADOW_SCRATCH(85):
    case NVA097_SET_MME_SHADOW_SCRATCH(86):
    case NVA097_SET_MME_SHADOW_SCRATCH(87):
    case NVA097_SET_MME_SHADOW_SCRATCH(88):
    case NVA097_SET_MME_SHADOW_SCRATCH(89):
    case NVA097_SET_MME_SHADOW_SCRATCH(90):
    case NVA097_SET_MME_SHADOW_SCRATCH(91):
    case NVA097_SET_MME_SHADOW_SCRATCH(92):
    case NVA097_SET_MME_SHADOW_SCRATCH(93):
    case NVA097_SET_MME_SHADOW_SCRATCH(94):
    case NVA097_SET_MME_SHADOW_SCRATCH(95):
    case NVA097_SET_MME_SHADOW_SCRATCH(96):
    case NVA097_SET_MME_SHADOW_SCRATCH(97):
    case NVA097_SET_MME_SHADOW_SCRATCH(98):
    case NVA097_SET_MME_SHADOW_SCRATCH(99):
    case NVA097_SET_MME_SHADOW_SCRATCH(100):
    case NVA097_SET_MME_SHADOW_SCRATCH(101):
    case NVA097_SET_MME_SHADOW_SCRATCH(102):
    case NVA097_SET_MME_SHADOW_SCRATCH(103):
    case NVA097_SET_MME_SHADOW_SCRATCH(104):
    case NVA097_SET_MME_SHADOW_SCRATCH(105):
    case NVA097_SET_MME_SHADOW_SCRATCH(106):
    case NVA097_SET_MME_SHADOW_SCRATCH(107):
    case NVA097_SET_MME_SHADOW_SCRATCH(108):
    case NVA097_SET_MME_SHADOW_SCRATCH(109):
    case NVA097_SET_MME_SHADOW_SCRATCH(110):
    case NVA097_SET_MME_SHADOW_SCRATCH(111):
    case NVA097_SET_MME_SHADOW_SCRATCH(112):
    case NVA097_SET_MME_SHADOW_SCRATCH(113):
    case NVA097_SET_MME_SHADOW_SCRATCH(114):
    case NVA097_SET_MME_SHADOW_SCRATCH(115):
    case NVA097_SET_MME_SHADOW_SCRATCH(116):
    case NVA097_SET_MME_SHADOW_SCRATCH(117):
    case NVA097_SET_MME_SHADOW_SCRATCH(118):
    case NVA097_SET_MME_SHADOW_SCRATCH(119):
    case NVA097_SET_MME_SHADOW_SCRATCH(120):
    case NVA097_SET_MME_SHADOW_SCRATCH(121):
    case NVA097_SET_MME_SHADOW_SCRATCH(122):
    case NVA097_SET_MME_SHADOW_SCRATCH(123):
    case NVA097_SET_MME_SHADOW_SCRATCH(124):
    case NVA097_SET_MME_SHADOW_SCRATCH(125):
    case NVA097_SET_MME_SHADOW_SCRATCH(126):
    case NVA097_SET_MME_SHADOW_SCRATCH(127):
    case NVA097_SET_MME_SHADOW_SCRATCH(128):
    case NVA097_SET_MME_SHADOW_SCRATCH(129):
    case NVA097_SET_MME_SHADOW_SCRATCH(130):
    case NVA097_SET_MME_SHADOW_SCRATCH(131):
    case NVA097_SET_MME_SHADOW_SCRATCH(132):
    case NVA097_SET_MME_SHADOW_SCRATCH(133):
    case NVA097_SET_MME_SHADOW_SCRATCH(134):
    case NVA097_SET_MME_SHADOW_SCRATCH(135):
    case NVA097_SET_MME_SHADOW_SCRATCH(136):
    case NVA097_SET_MME_SHADOW_SCRATCH(137):
    case NVA097_SET_MME_SHADOW_SCRATCH(138):
    case NVA097_SET_MME_SHADOW_SCRATCH(139):
    case NVA097_SET_MME_SHADOW_SCRATCH(140):
    case NVA097_SET_MME_SHADOW_SCRATCH(141):
    case NVA097_SET_MME_SHADOW_SCRATCH(142):
    case NVA097_SET_MME_SHADOW_SCRATCH(143):
    case NVA097_SET_MME_SHADOW_SCRATCH(144):
    case NVA097_SET_MME_SHADOW_SCRATCH(145):
    case NVA097_SET_MME_SHADOW_SCRATCH(146):
    case NVA097_SET_MME_SHADOW_SCRATCH(147):
    case NVA097_SET_MME_SHADOW_SCRATCH(148):
    case NVA097_SET_MME_SHADOW_SCRATCH(149):
    case NVA097_SET_MME_SHADOW_SCRATCH(150):
    case NVA097_SET_MME_SHADOW_SCRATCH(151):
    case NVA097_SET_MME_SHADOW_SCRATCH(152):
    case NVA097_SET_MME_SHADOW_SCRATCH(153):
    case NVA097_SET_MME_SHADOW_SCRATCH(154):
    case NVA097_SET_MME_SHADOW_SCRATCH(155):
    case NVA097_SET_MME_SHADOW_SCRATCH(156):
    case NVA097_SET_MME_SHADOW_SCRATCH(157):
    case NVA097_SET_MME_SHADOW_SCRATCH(158):
    case NVA097_SET_MME_SHADOW_SCRATCH(159):
    case NVA097_SET_MME_SHADOW_SCRATCH(160):
    case NVA097_SET_MME_SHADOW_SCRATCH(161):
    case NVA097_SET_MME_SHADOW_SCRATCH(162):
    case NVA097_SET_MME_SHADOW_SCRATCH(163):
    case NVA097_SET_MME_SHADOW_SCRATCH(164):
    case NVA097_SET_MME_SHADOW_SCRATCH(165):
    case NVA097_SET_MME_SHADOW_SCRATCH(166):
    case NVA097_SET_MME_SHADOW_SCRATCH(167):
    case NVA097_SET_MME_SHADOW_SCRATCH(168):
    case NVA097_SET_MME_SHADOW_SCRATCH(169):
    case NVA097_SET_MME_SHADOW_SCRATCH(170):
    case NVA097_SET_MME_SHADOW_SCRATCH(171):
    case NVA097_SET_MME_SHADOW_SCRATCH(172):
    case NVA097_SET_MME_SHADOW_SCRATCH(173):
    case NVA097_SET_MME_SHADOW_SCRATCH(174):
    case NVA097_SET_MME_SHADOW_SCRATCH(175):
    case NVA097_SET_MME_SHADOW_SCRATCH(176):
    case NVA097_SET_MME_SHADOW_SCRATCH(177):
    case NVA097_SET_MME_SHADOW_SCRATCH(178):
    case NVA097_SET_MME_SHADOW_SCRATCH(179):
    case NVA097_SET_MME_SHADOW_SCRATCH(180):
    case NVA097_SET_MME_SHADOW_SCRATCH(181):
    case NVA097_SET_MME_SHADOW_SCRATCH(182):
    case NVA097_SET_MME_SHADOW_SCRATCH(183):
    case NVA097_SET_MME_SHADOW_SCRATCH(184):
    case NVA097_SET_MME_SHADOW_SCRATCH(185):
    case NVA097_SET_MME_SHADOW_SCRATCH(186):
    case NVA097_SET_MME_SHADOW_SCRATCH(187):
    case NVA097_SET_MME_SHADOW_SCRATCH(188):
    case NVA097_SET_MME_SHADOW_SCRATCH(189):
    case NVA097_SET_MME_SHADOW_SCRATCH(190):
    case NVA097_SET_MME_SHADOW_SCRATCH(191):
    case NVA097_SET_MME_SHADOW_SCRATCH(192):
    case NVA097_SET_MME_SHADOW_SCRATCH(193):
    case NVA097_SET_MME_SHADOW_SCRATCH(194):
    case NVA097_SET_MME_SHADOW_SCRATCH(195):
    case NVA097_SET_MME_SHADOW_SCRATCH(196):
    case NVA097_SET_MME_SHADOW_SCRATCH(197):
    case NVA097_SET_MME_SHADOW_SCRATCH(198):
    case NVA097_SET_MME_SHADOW_SCRATCH(199):
    case NVA097_SET_MME_SHADOW_SCRATCH(200):
    case NVA097_SET_MME_SHADOW_SCRATCH(201):
    case NVA097_SET_MME_SHADOW_SCRATCH(202):
    case NVA097_SET_MME_SHADOW_SCRATCH(203):
    case NVA097_SET_MME_SHADOW_SCRATCH(204):
    case NVA097_SET_MME_SHADOW_SCRATCH(205):
    case NVA097_SET_MME_SHADOW_SCRATCH(206):
    case NVA097_SET_MME_SHADOW_SCRATCH(207):
    case NVA097_SET_MME_SHADOW_SCRATCH(208):
    case NVA097_SET_MME_SHADOW_SCRATCH(209):
    case NVA097_SET_MME_SHADOW_SCRATCH(210):
    case NVA097_SET_MME_SHADOW_SCRATCH(211):
    case NVA097_SET_MME_SHADOW_SCRATCH(212):
    case NVA097_SET_MME_SHADOW_SCRATCH(213):
    case NVA097_SET_MME_SHADOW_SCRATCH(214):
    case NVA097_SET_MME_SHADOW_SCRATCH(215):
    case NVA097_SET_MME_SHADOW_SCRATCH(216):
    case NVA097_SET_MME_SHADOW_SCRATCH(217):
    case NVA097_SET_MME_SHADOW_SCRATCH(218):
    case NVA097_SET_MME_SHADOW_SCRATCH(219):
    case NVA097_SET_MME_SHADOW_SCRATCH(220):
    case NVA097_SET_MME_SHADOW_SCRATCH(221):
    case NVA097_SET_MME_SHADOW_SCRATCH(222):
    case NVA097_SET_MME_SHADOW_SCRATCH(223):
    case NVA097_SET_MME_SHADOW_SCRATCH(224):
    case NVA097_SET_MME_SHADOW_SCRATCH(225):
    case NVA097_SET_MME_SHADOW_SCRATCH(226):
    case NVA097_SET_MME_SHADOW_SCRATCH(227):
    case NVA097_SET_MME_SHADOW_SCRATCH(228):
    case NVA097_SET_MME_SHADOW_SCRATCH(229):
    case NVA097_SET_MME_SHADOW_SCRATCH(230):
    case NVA097_SET_MME_SHADOW_SCRATCH(231):
    case NVA097_SET_MME_SHADOW_SCRATCH(232):
    case NVA097_SET_MME_SHADOW_SCRATCH(233):
    case NVA097_SET_MME_SHADOW_SCRATCH(234):
    case NVA097_SET_MME_SHADOW_SCRATCH(235):
    case NVA097_SET_MME_SHADOW_SCRATCH(236):
    case NVA097_SET_MME_SHADOW_SCRATCH(237):
    case NVA097_SET_MME_SHADOW_SCRATCH(238):
    case NVA097_SET_MME_SHADOW_SCRATCH(239):
    case NVA097_SET_MME_SHADOW_SCRATCH(240):
    case NVA097_SET_MME_SHADOW_SCRATCH(241):
    case NVA097_SET_MME_SHADOW_SCRATCH(242):
    case NVA097_SET_MME_SHADOW_SCRATCH(243):
    case NVA097_SET_MME_SHADOW_SCRATCH(244):
    case NVA097_SET_MME_SHADOW_SCRATCH(245):
    case NVA097_SET_MME_SHADOW_SCRATCH(246):
    case NVA097_SET_MME_SHADOW_SCRATCH(247):
    case NVA097_SET_MME_SHADOW_SCRATCH(248):
    case NVA097_SET_MME_SHADOW_SCRATCH(249):
    case NVA097_SET_MME_SHADOW_SCRATCH(250):
    case NVA097_SET_MME_SHADOW_SCRATCH(251):
    case NVA097_SET_MME_SHADOW_SCRATCH(252):
    case NVA097_SET_MME_SHADOW_SCRATCH(253):
    case NVA097_SET_MME_SHADOW_SCRATCH(254):
    case NVA097_SET_MME_SHADOW_SCRATCH(255):

        
    case NVA097_CALL_MME_MACRO(0):
    case NVA097_CALL_MME_MACRO(1):
    case NVA097_CALL_MME_MACRO(2):
    case NVA097_CALL_MME_MACRO(3):
    case NVA097_CALL_MME_MACRO(4):
    case NVA097_CALL_MME_MACRO(5):
    case NVA097_CALL_MME_MACRO(6):
    case NVA097_CALL_MME_MACRO(7):
    case NVA097_CALL_MME_MACRO(8):
    case NVA097_CALL_MME_MACRO(9):
    case NVA097_CALL_MME_MACRO(10):
    case NVA097_CALL_MME_MACRO(11):
    case NVA097_CALL_MME_MACRO(12):
    case NVA097_CALL_MME_MACRO(13):
    case NVA097_CALL_MME_MACRO(14):
    case NVA097_CALL_MME_MACRO(15):
    case NVA097_CALL_MME_MACRO(16):
    case NVA097_CALL_MME_MACRO(17):
    case NVA097_CALL_MME_MACRO(18):
    case NVA097_CALL_MME_MACRO(19):
    case NVA097_CALL_MME_MACRO(20):
    case NVA097_CALL_MME_MACRO(21):
    case NVA097_CALL_MME_MACRO(22):
    case NVA097_CALL_MME_MACRO(23):
    case NVA097_CALL_MME_MACRO(24):
    case NVA097_CALL_MME_MACRO(25):
    case NVA097_CALL_MME_MACRO(26):
    case NVA097_CALL_MME_MACRO(27):
    case NVA097_CALL_MME_MACRO(28):
    case NVA097_CALL_MME_MACRO(29):
    case NVA097_CALL_MME_MACRO(30):
    case NVA097_CALL_MME_MACRO(31):
    case NVA097_CALL_MME_MACRO(32):
    case NVA097_CALL_MME_MACRO(33):
    case NVA097_CALL_MME_MACRO(34):
    case NVA097_CALL_MME_MACRO(35):
    case NVA097_CALL_MME_MACRO(36):
    case NVA097_CALL_MME_MACRO(37):
    case NVA097_CALL_MME_MACRO(38):
    case NVA097_CALL_MME_MACRO(39):
    case NVA097_CALL_MME_MACRO(40):
    case NVA097_CALL_MME_MACRO(41):
    case NVA097_CALL_MME_MACRO(42):
    case NVA097_CALL_MME_MACRO(43):
    case NVA097_CALL_MME_MACRO(44):
    case NVA097_CALL_MME_MACRO(45):
    case NVA097_CALL_MME_MACRO(46):
    case NVA097_CALL_MME_MACRO(47):
    case NVA097_CALL_MME_MACRO(48):
    case NVA097_CALL_MME_MACRO(49):
    case NVA097_CALL_MME_MACRO(50):
    case NVA097_CALL_MME_MACRO(51):
    case NVA097_CALL_MME_MACRO(52):
    case NVA097_CALL_MME_MACRO(53):
    case NVA097_CALL_MME_MACRO(54):
    case NVA097_CALL_MME_MACRO(55):
    case NVA097_CALL_MME_MACRO(56):
    case NVA097_CALL_MME_MACRO(57):
    case NVA097_CALL_MME_MACRO(58):
    case NVA097_CALL_MME_MACRO(59):
    case NVA097_CALL_MME_MACRO(60):
    case NVA097_CALL_MME_MACRO(61):
    case NVA097_CALL_MME_MACRO(62):
    case NVA097_CALL_MME_MACRO(63):
    case NVA097_CALL_MME_MACRO(64):
    case NVA097_CALL_MME_MACRO(65):
    case NVA097_CALL_MME_MACRO(66):
    case NVA097_CALL_MME_MACRO(67):
    case NVA097_CALL_MME_MACRO(68):
    case NVA097_CALL_MME_MACRO(69):
    case NVA097_CALL_MME_MACRO(70):
    case NVA097_CALL_MME_MACRO(71):
    case NVA097_CALL_MME_MACRO(72):
    case NVA097_CALL_MME_MACRO(73):
    case NVA097_CALL_MME_MACRO(74):
    case NVA097_CALL_MME_MACRO(75):
    case NVA097_CALL_MME_MACRO(76):
    case NVA097_CALL_MME_MACRO(77):
    case NVA097_CALL_MME_MACRO(78):
    case NVA097_CALL_MME_MACRO(79):
    case NVA097_CALL_MME_MACRO(80):
    case NVA097_CALL_MME_MACRO(81):
    case NVA097_CALL_MME_MACRO(82):
    case NVA097_CALL_MME_MACRO(83):
    case NVA097_CALL_MME_MACRO(84):
    case NVA097_CALL_MME_MACRO(85):
    case NVA097_CALL_MME_MACRO(86):
    case NVA097_CALL_MME_MACRO(87):
    case NVA097_CALL_MME_MACRO(88):
    case NVA097_CALL_MME_MACRO(89):
    case NVA097_CALL_MME_MACRO(90):
    case NVA097_CALL_MME_MACRO(91):
    case NVA097_CALL_MME_MACRO(92):
    case NVA097_CALL_MME_MACRO(93):
    case NVA097_CALL_MME_MACRO(94):
    case NVA097_CALL_MME_MACRO(95):
    case NVA097_CALL_MME_MACRO(96):
    case NVA097_CALL_MME_MACRO(97):
    case NVA097_CALL_MME_MACRO(98):
    case NVA097_CALL_MME_MACRO(99):
    case NVA097_CALL_MME_MACRO(100):
    case NVA097_CALL_MME_MACRO(101):
    case NVA097_CALL_MME_MACRO(102):
    case NVA097_CALL_MME_MACRO(103):
    case NVA097_CALL_MME_MACRO(104):
    case NVA097_CALL_MME_MACRO(105):
    case NVA097_CALL_MME_MACRO(106):
    case NVA097_CALL_MME_MACRO(107):
    case NVA097_CALL_MME_MACRO(108):
    case NVA097_CALL_MME_MACRO(109):
    case NVA097_CALL_MME_MACRO(110):
    case NVA097_CALL_MME_MACRO(111):
    case NVA097_CALL_MME_MACRO(112):
    case NVA097_CALL_MME_MACRO(113):
    case NVA097_CALL_MME_MACRO(114):
    case NVA097_CALL_MME_MACRO(115):
    case NVA097_CALL_MME_MACRO(116):
    case NVA097_CALL_MME_MACRO(117):
    case NVA097_CALL_MME_MACRO(118):
    case NVA097_CALL_MME_MACRO(119):
    case NVA097_CALL_MME_MACRO(120):
    case NVA097_CALL_MME_MACRO(121):
    case NVA097_CALL_MME_MACRO(122):
    case NVA097_CALL_MME_MACRO(123):
    case NVA097_CALL_MME_MACRO(124):
    case NVA097_CALL_MME_MACRO(125):
    case NVA097_CALL_MME_MACRO(126):
    case NVA097_CALL_MME_MACRO(127):
    case NVA097_CALL_MME_MACRO(128):
    case NVA097_CALL_MME_MACRO(129):
    case NVA097_CALL_MME_MACRO(130):
    case NVA097_CALL_MME_MACRO(131):
    case NVA097_CALL_MME_MACRO(132):
    case NVA097_CALL_MME_MACRO(133):
    case NVA097_CALL_MME_MACRO(134):
    case NVA097_CALL_MME_MACRO(135):
    case NVA097_CALL_MME_MACRO(136):
    case NVA097_CALL_MME_MACRO(137):
    case NVA097_CALL_MME_MACRO(138):
    case NVA097_CALL_MME_MACRO(139):
    case NVA097_CALL_MME_MACRO(140):
    case NVA097_CALL_MME_MACRO(141):
    case NVA097_CALL_MME_MACRO(142):
    case NVA097_CALL_MME_MACRO(143):
    case NVA097_CALL_MME_MACRO(144):
    case NVA097_CALL_MME_MACRO(145):
    case NVA097_CALL_MME_MACRO(146):
    case NVA097_CALL_MME_MACRO(147):
    case NVA097_CALL_MME_MACRO(148):
    case NVA097_CALL_MME_MACRO(149):
    case NVA097_CALL_MME_MACRO(150):
    case NVA097_CALL_MME_MACRO(151):
    case NVA097_CALL_MME_MACRO(152):
    case NVA097_CALL_MME_MACRO(153):
    case NVA097_CALL_MME_MACRO(154):
    case NVA097_CALL_MME_MACRO(155):
    case NVA097_CALL_MME_MACRO(156):
    case NVA097_CALL_MME_MACRO(157):
    case NVA097_CALL_MME_MACRO(158):
    case NVA097_CALL_MME_MACRO(159):
    case NVA097_CALL_MME_MACRO(160):
    case NVA097_CALL_MME_MACRO(161):
    case NVA097_CALL_MME_MACRO(162):
    case NVA097_CALL_MME_MACRO(163):
    case NVA097_CALL_MME_MACRO(164):
    case NVA097_CALL_MME_MACRO(165):
    case NVA097_CALL_MME_MACRO(166):
    case NVA097_CALL_MME_MACRO(167):
    case NVA097_CALL_MME_MACRO(168):
    case NVA097_CALL_MME_MACRO(169):
    case NVA097_CALL_MME_MACRO(170):
    case NVA097_CALL_MME_MACRO(171):
    case NVA097_CALL_MME_MACRO(172):
    case NVA097_CALL_MME_MACRO(173):
    case NVA097_CALL_MME_MACRO(174):
    case NVA097_CALL_MME_MACRO(175):
    case NVA097_CALL_MME_MACRO(176):
    case NVA097_CALL_MME_MACRO(177):
    case NVA097_CALL_MME_MACRO(178):
    case NVA097_CALL_MME_MACRO(179):
    case NVA097_CALL_MME_MACRO(180):
    case NVA097_CALL_MME_MACRO(181):
    case NVA097_CALL_MME_MACRO(182):
    case NVA097_CALL_MME_MACRO(183):
    case NVA097_CALL_MME_MACRO(184):
    case NVA097_CALL_MME_MACRO(185):
    case NVA097_CALL_MME_MACRO(186):
    case NVA097_CALL_MME_MACRO(187):
    case NVA097_CALL_MME_MACRO(188):
    case NVA097_CALL_MME_MACRO(189):
    case NVA097_CALL_MME_MACRO(190):
    case NVA097_CALL_MME_MACRO(191):
    case NVA097_CALL_MME_MACRO(192):
    case NVA097_CALL_MME_MACRO(193):
    case NVA097_CALL_MME_MACRO(194):
    case NVA097_CALL_MME_MACRO(195):
    case NVA097_CALL_MME_MACRO(196):
    case NVA097_CALL_MME_MACRO(197):
    case NVA097_CALL_MME_MACRO(198):
    case NVA097_CALL_MME_MACRO(199):
    case NVA097_CALL_MME_MACRO(200):
    case NVA097_CALL_MME_MACRO(201):
    case NVA097_CALL_MME_MACRO(202):
    case NVA097_CALL_MME_MACRO(203):
    case NVA097_CALL_MME_MACRO(204):
    case NVA097_CALL_MME_MACRO(205):
    case NVA097_CALL_MME_MACRO(206):
    case NVA097_CALL_MME_MACRO(207):
    case NVA097_CALL_MME_MACRO(208):
    case NVA097_CALL_MME_MACRO(209):
    case NVA097_CALL_MME_MACRO(210):
    case NVA097_CALL_MME_MACRO(211):
    case NVA097_CALL_MME_MACRO(212):
    case NVA097_CALL_MME_MACRO(213):
    case NVA097_CALL_MME_MACRO(214):
    case NVA097_CALL_MME_MACRO(215):
    case NVA097_CALL_MME_MACRO(216):
    case NVA097_CALL_MME_MACRO(217):
    case NVA097_CALL_MME_MACRO(218):
    case NVA097_CALL_MME_MACRO(219):
    case NVA097_CALL_MME_MACRO(220):
    case NVA097_CALL_MME_MACRO(221):
    case NVA097_CALL_MME_MACRO(222):
    case NVA097_CALL_MME_MACRO(223):
    case NVA097_CALL_MME_MACRO(224):
    case NVA097_CALL_MME_MACRO(225):
    case NVA097_CALL_MME_MACRO(226):
    case NVA097_CALL_MME_MACRO(227):
    case NVA097_CALL_MME_MACRO(228):
    case NVA097_CALL_MME_MACRO(229):
    case NVA097_CALL_MME_MACRO(230):
    case NVA097_CALL_MME_MACRO(231):
    case NVA097_CALL_MME_MACRO(232):
    case NVA097_CALL_MME_MACRO(233):
    case NVA097_CALL_MME_MACRO(234):
    case NVA097_CALL_MME_MACRO(235):
    case NVA097_CALL_MME_MACRO(236):
    case NVA097_CALL_MME_MACRO(237):
    case NVA097_CALL_MME_MACRO(238):
    case NVA097_CALL_MME_MACRO(239):
    case NVA097_CALL_MME_MACRO(240):
    case NVA097_CALL_MME_MACRO(241):
    case NVA097_CALL_MME_MACRO(242):
    case NVA097_CALL_MME_MACRO(243):
    case NVA097_CALL_MME_MACRO(244):
    case NVA097_CALL_MME_MACRO(245):
    case NVA097_CALL_MME_MACRO(246):
    case NVA097_CALL_MME_MACRO(247):
    case NVA097_CALL_MME_MACRO(248):
    case NVA097_CALL_MME_MACRO(249):
    case NVA097_CALL_MME_MACRO(250):
    case NVA097_CALL_MME_MACRO(251):
    case NVA097_CALL_MME_MACRO(252):
    case NVA097_CALL_MME_MACRO(253):
    case NVA097_CALL_MME_MACRO(254):
    case NVA097_CALL_MME_MACRO(255):

        
    case NVA097_CALL_MME_DATA(0):
    case NVA097_CALL_MME_DATA(1):
    case NVA097_CALL_MME_DATA(2):
    case NVA097_CALL_MME_DATA(3):
    case NVA097_CALL_MME_DATA(4):
    case NVA097_CALL_MME_DATA(5):
    case NVA097_CALL_MME_DATA(6):
    case NVA097_CALL_MME_DATA(7):
    case NVA097_CALL_MME_DATA(8):
    case NVA097_CALL_MME_DATA(9):
    case NVA097_CALL_MME_DATA(10):
    case NVA097_CALL_MME_DATA(11):
    case NVA097_CALL_MME_DATA(12):
    case NVA097_CALL_MME_DATA(13):
    case NVA097_CALL_MME_DATA(14):
    case NVA097_CALL_MME_DATA(15):
    case NVA097_CALL_MME_DATA(16):
    case NVA097_CALL_MME_DATA(17):
    case NVA097_CALL_MME_DATA(18):
    case NVA097_CALL_MME_DATA(19):
    case NVA097_CALL_MME_DATA(20):
    case NVA097_CALL_MME_DATA(21):
    case NVA097_CALL_MME_DATA(22):
    case NVA097_CALL_MME_DATA(23):
    case NVA097_CALL_MME_DATA(24):
    case NVA097_CALL_MME_DATA(25):
    case NVA097_CALL_MME_DATA(26):
    case NVA097_CALL_MME_DATA(27):
    case NVA097_CALL_MME_DATA(28):
    case NVA097_CALL_MME_DATA(29):
    case NVA097_CALL_MME_DATA(30):
    case NVA097_CALL_MME_DATA(31):
    case NVA097_CALL_MME_DATA(32):
    case NVA097_CALL_MME_DATA(33):
    case NVA097_CALL_MME_DATA(34):
    case NVA097_CALL_MME_DATA(35):
    case NVA097_CALL_MME_DATA(36):
    case NVA097_CALL_MME_DATA(37):
    case NVA097_CALL_MME_DATA(38):
    case NVA097_CALL_MME_DATA(39):
    case NVA097_CALL_MME_DATA(40):
    case NVA097_CALL_MME_DATA(41):
    case NVA097_CALL_MME_DATA(42):
    case NVA097_CALL_MME_DATA(43):
    case NVA097_CALL_MME_DATA(44):
    case NVA097_CALL_MME_DATA(45):
    case NVA097_CALL_MME_DATA(46):
    case NVA097_CALL_MME_DATA(47):
    case NVA097_CALL_MME_DATA(48):
    case NVA097_CALL_MME_DATA(49):
    case NVA097_CALL_MME_DATA(50):
    case NVA097_CALL_MME_DATA(51):
    case NVA097_CALL_MME_DATA(52):
    case NVA097_CALL_MME_DATA(53):
    case NVA097_CALL_MME_DATA(54):
    case NVA097_CALL_MME_DATA(55):
    case NVA097_CALL_MME_DATA(56):
    case NVA097_CALL_MME_DATA(57):
    case NVA097_CALL_MME_DATA(58):
    case NVA097_CALL_MME_DATA(59):
    case NVA097_CALL_MME_DATA(60):
    case NVA097_CALL_MME_DATA(61):
    case NVA097_CALL_MME_DATA(62):
    case NVA097_CALL_MME_DATA(63):
    case NVA097_CALL_MME_DATA(64):
    case NVA097_CALL_MME_DATA(65):
    case NVA097_CALL_MME_DATA(66):
    case NVA097_CALL_MME_DATA(67):
    case NVA097_CALL_MME_DATA(68):
    case NVA097_CALL_MME_DATA(69):
    case NVA097_CALL_MME_DATA(70):
    case NVA097_CALL_MME_DATA(71):
    case NVA097_CALL_MME_DATA(72):
    case NVA097_CALL_MME_DATA(73):
    case NVA097_CALL_MME_DATA(74):
    case NVA097_CALL_MME_DATA(75):
    case NVA097_CALL_MME_DATA(76):
    case NVA097_CALL_MME_DATA(77):
    case NVA097_CALL_MME_DATA(78):
    case NVA097_CALL_MME_DATA(79):
    case NVA097_CALL_MME_DATA(80):
    case NVA097_CALL_MME_DATA(81):
    case NVA097_CALL_MME_DATA(82):
    case NVA097_CALL_MME_DATA(83):
    case NVA097_CALL_MME_DATA(84):
    case NVA097_CALL_MME_DATA(85):
    case NVA097_CALL_MME_DATA(86):
    case NVA097_CALL_MME_DATA(87):
    case NVA097_CALL_MME_DATA(88):
    case NVA097_CALL_MME_DATA(89):
    case NVA097_CALL_MME_DATA(90):
    case NVA097_CALL_MME_DATA(91):
    case NVA097_CALL_MME_DATA(92):
    case NVA097_CALL_MME_DATA(93):
    case NVA097_CALL_MME_DATA(94):
    case NVA097_CALL_MME_DATA(95):
    case NVA097_CALL_MME_DATA(96):
    case NVA097_CALL_MME_DATA(97):
    case NVA097_CALL_MME_DATA(98):
    case NVA097_CALL_MME_DATA(99):
    case NVA097_CALL_MME_DATA(100):
    case NVA097_CALL_MME_DATA(101):
    case NVA097_CALL_MME_DATA(102):
    case NVA097_CALL_MME_DATA(103):
    case NVA097_CALL_MME_DATA(104):
    case NVA097_CALL_MME_DATA(105):
    case NVA097_CALL_MME_DATA(106):
    case NVA097_CALL_MME_DATA(107):
    case NVA097_CALL_MME_DATA(108):
    case NVA097_CALL_MME_DATA(109):
    case NVA097_CALL_MME_DATA(110):
    case NVA097_CALL_MME_DATA(111):
    case NVA097_CALL_MME_DATA(112):
    case NVA097_CALL_MME_DATA(113):
    case NVA097_CALL_MME_DATA(114):
    case NVA097_CALL_MME_DATA(115):
    case NVA097_CALL_MME_DATA(116):
    case NVA097_CALL_MME_DATA(117):
    case NVA097_CALL_MME_DATA(118):
    case NVA097_CALL_MME_DATA(119):
    case NVA097_CALL_MME_DATA(120):
    case NVA097_CALL_MME_DATA(121):
    case NVA097_CALL_MME_DATA(122):
    case NVA097_CALL_MME_DATA(123):
    case NVA097_CALL_MME_DATA(124):
    case NVA097_CALL_MME_DATA(125):
    case NVA097_CALL_MME_DATA(126):
    case NVA097_CALL_MME_DATA(127):
    case NVA097_CALL_MME_DATA(128):
    case NVA097_CALL_MME_DATA(129):
    case NVA097_CALL_MME_DATA(130):
    case NVA097_CALL_MME_DATA(131):
    case NVA097_CALL_MME_DATA(132):
    case NVA097_CALL_MME_DATA(133):
    case NVA097_CALL_MME_DATA(134):
    case NVA097_CALL_MME_DATA(135):
    case NVA097_CALL_MME_DATA(136):
    case NVA097_CALL_MME_DATA(137):
    case NVA097_CALL_MME_DATA(138):
    case NVA097_CALL_MME_DATA(139):
    case NVA097_CALL_MME_DATA(140):
    case NVA097_CALL_MME_DATA(141):
    case NVA097_CALL_MME_DATA(142):
    case NVA097_CALL_MME_DATA(143):
    case NVA097_CALL_MME_DATA(144):
    case NVA097_CALL_MME_DATA(145):
    case NVA097_CALL_MME_DATA(146):
    case NVA097_CALL_MME_DATA(147):
    case NVA097_CALL_MME_DATA(148):
    case NVA097_CALL_MME_DATA(149):
    case NVA097_CALL_MME_DATA(150):
    case NVA097_CALL_MME_DATA(151):
    case NVA097_CALL_MME_DATA(152):
    case NVA097_CALL_MME_DATA(153):
    case NVA097_CALL_MME_DATA(154):
    case NVA097_CALL_MME_DATA(155):
    case NVA097_CALL_MME_DATA(156):
    case NVA097_CALL_MME_DATA(157):
    case NVA097_CALL_MME_DATA(158):
    case NVA097_CALL_MME_DATA(159):
    case NVA097_CALL_MME_DATA(160):
    case NVA097_CALL_MME_DATA(161):
    case NVA097_CALL_MME_DATA(162):
    case NVA097_CALL_MME_DATA(163):
    case NVA097_CALL_MME_DATA(164):
    case NVA097_CALL_MME_DATA(165):
    case NVA097_CALL_MME_DATA(166):
    case NVA097_CALL_MME_DATA(167):
    case NVA097_CALL_MME_DATA(168):
    case NVA097_CALL_MME_DATA(169):
    case NVA097_CALL_MME_DATA(170):
    case NVA097_CALL_MME_DATA(171):
    case NVA097_CALL_MME_DATA(172):
    case NVA097_CALL_MME_DATA(173):
    case NVA097_CALL_MME_DATA(174):
    case NVA097_CALL_MME_DATA(175):
    case NVA097_CALL_MME_DATA(176):
    case NVA097_CALL_MME_DATA(177):
    case NVA097_CALL_MME_DATA(178):
    case NVA097_CALL_MME_DATA(179):
    case NVA097_CALL_MME_DATA(180):
    case NVA097_CALL_MME_DATA(181):
    case NVA097_CALL_MME_DATA(182):
    case NVA097_CALL_MME_DATA(183):
    case NVA097_CALL_MME_DATA(184):
    case NVA097_CALL_MME_DATA(185):
    case NVA097_CALL_MME_DATA(186):
    case NVA097_CALL_MME_DATA(187):
    case NVA097_CALL_MME_DATA(188):
    case NVA097_CALL_MME_DATA(189):
    case NVA097_CALL_MME_DATA(190):
    case NVA097_CALL_MME_DATA(191):
    case NVA097_CALL_MME_DATA(192):
    case NVA097_CALL_MME_DATA(193):
    case NVA097_CALL_MME_DATA(194):
    case NVA097_CALL_MME_DATA(195):
    case NVA097_CALL_MME_DATA(196):
    case NVA097_CALL_MME_DATA(197):
    case NVA097_CALL_MME_DATA(198):
    case NVA097_CALL_MME_DATA(199):
    case NVA097_CALL_MME_DATA(200):
    case NVA097_CALL_MME_DATA(201):
    case NVA097_CALL_MME_DATA(202):
    case NVA097_CALL_MME_DATA(203):
    case NVA097_CALL_MME_DATA(204):
    case NVA097_CALL_MME_DATA(205):
    case NVA097_CALL_MME_DATA(206):
    case NVA097_CALL_MME_DATA(207):
    case NVA097_CALL_MME_DATA(208):
    case NVA097_CALL_MME_DATA(209):
    case NVA097_CALL_MME_DATA(210):
    case NVA097_CALL_MME_DATA(211):
    case NVA097_CALL_MME_DATA(212):
    case NVA097_CALL_MME_DATA(213):
    case NVA097_CALL_MME_DATA(214):
    case NVA097_CALL_MME_DATA(215):
    case NVA097_CALL_MME_DATA(216):
    case NVA097_CALL_MME_DATA(217):
    case NVA097_CALL_MME_DATA(218):
    case NVA097_CALL_MME_DATA(219):
    case NVA097_CALL_MME_DATA(220):
    case NVA097_CALL_MME_DATA(221):
    case NVA097_CALL_MME_DATA(222):
    case NVA097_CALL_MME_DATA(223):
    case NVA097_CALL_MME_DATA(224):
    case NVA097_CALL_MME_DATA(225):
    case NVA097_CALL_MME_DATA(226):
    case NVA097_CALL_MME_DATA(227):
    case NVA097_CALL_MME_DATA(228):
    case NVA097_CALL_MME_DATA(229):
    case NVA097_CALL_MME_DATA(230):
    case NVA097_CALL_MME_DATA(231):
    case NVA097_CALL_MME_DATA(232):
    case NVA097_CALL_MME_DATA(233):
    case NVA097_CALL_MME_DATA(234):
    case NVA097_CALL_MME_DATA(235):
    case NVA097_CALL_MME_DATA(236):
    case NVA097_CALL_MME_DATA(237):
    case NVA097_CALL_MME_DATA(238):
    case NVA097_CALL_MME_DATA(239):
    case NVA097_CALL_MME_DATA(240):
    case NVA097_CALL_MME_DATA(241):
    case NVA097_CALL_MME_DATA(242):
    case NVA097_CALL_MME_DATA(243):
    case NVA097_CALL_MME_DATA(244):
    case NVA097_CALL_MME_DATA(245):
    case NVA097_CALL_MME_DATA(246):
    case NVA097_CALL_MME_DATA(247):
    case NVA097_CALL_MME_DATA(248):
    case NVA097_CALL_MME_DATA(249):
    case NVA097_CALL_MME_DATA(250):
    case NVA097_CALL_MME_DATA(251):
    case NVA097_CALL_MME_DATA(252):
    case NVA097_CALL_MME_DATA(253):
    case NVA097_CALL_MME_DATA(254):
    case NVA097_CALL_MME_DATA(255):


    P_DUMP_NV9297_MTHD_DATA(fp, idx, data, prefix);
    break;

                                                                          
    case NVA097_PM_TRIGGER_WFI:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
          
    case NVA097_LINE_LENGTH_IN:

    
        parsed = data;
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_LINE_COUNT:

    
        parsed = data;
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_OFFSET_OUT_UPPER:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_OFFSET_OUT:

    
        parsed = data;
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_PITCH_OUT:

    
        parsed = data;
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_DST_BLOCK_SIZE:

    
        parsed = (data >> 0) & ((1u << 4) - 1);
        fprintf(fp, "%s.WIDTH = ", prefix);
        switch (parsed) {
        case NVA097_SET_DST_BLOCK_SIZE_WIDTH_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 4) - 1);
        fprintf(fp, "%s.HEIGHT = ", prefix);
        switch (parsed) {
        case NVA097_SET_DST_BLOCK_SIZE_HEIGHT_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_HEIGHT_TWO_GOBS:
            fprintf(fp, "TWO_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_HEIGHT_FOUR_GOBS:
            fprintf(fp, "FOUR_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_HEIGHT_EIGHT_GOBS:
            fprintf(fp, "EIGHT_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_HEIGHT_SIXTEEN_GOBS:
            fprintf(fp, "SIXTEEN_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_HEIGHT_THIRTYTWO_GOBS:
            fprintf(fp, "THIRTYTWO_GOBS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 8) & ((1u << 4) - 1);
        fprintf(fp, "%s.DEPTH = ", prefix);
        switch (parsed) {
        case NVA097_SET_DST_BLOCK_SIZE_DEPTH_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_DEPTH_TWO_GOBS:
            fprintf(fp, "TWO_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_DEPTH_FOUR_GOBS:
            fprintf(fp, "FOUR_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_DEPTH_EIGHT_GOBS:
            fprintf(fp, "EIGHT_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_DEPTH_SIXTEEN_GOBS:
            fprintf(fp, "SIXTEEN_GOBS\n");
            break;
        case NVA097_SET_DST_BLOCK_SIZE_DEPTH_THIRTYTWO_GOBS:
            fprintf(fp, "THIRTYTWO_GOBS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NVA097_SET_DST_WIDTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_DST_HEIGHT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_DST_DEPTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_DST_LAYER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_DST_ORIGIN_BYTES_X:

    
        parsed = (data >> 0) & ((1u << 20) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_DST_ORIGIN_SAMPLES_Y:

    
        parsed = (data >> 0) & ((1u << 16) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_LAUNCH_DMA:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.DST_MEMORY_LAYOUT = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_DST_MEMORY_LAYOUT_BLOCKLINEAR:
            fprintf(fp, "BLOCKLINEAR\n");
            break;
        case NVA097_LAUNCH_DMA_DST_MEMORY_LAYOUT_PITCH:
            fprintf(fp, "PITCH\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 2) - 1);
        fprintf(fp, "%s.COMPLETION_TYPE = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_COMPLETION_TYPE_FLUSH_DISABLE:
            fprintf(fp, "FLUSH_DISABLE\n");
            break;
        case NVA097_LAUNCH_DMA_COMPLETION_TYPE_FLUSH_ONLY:
            fprintf(fp, "FLUSH_ONLY\n");
            break;
        case NVA097_LAUNCH_DMA_COMPLETION_TYPE_RELEASE_SEMAPHORE:
            fprintf(fp, "RELEASE_SEMAPHORE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 8) & ((1u << 2) - 1);
        fprintf(fp, "%s.INTERRUPT_TYPE = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_INTERRUPT_TYPE_NONE:
            fprintf(fp, "NONE\n");
            break;
        case NVA097_LAUNCH_DMA_INTERRUPT_TYPE_INTERRUPT:
            fprintf(fp, "INTERRUPT\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 12) & ((1u << 1) - 1);
        fprintf(fp, "%s.SEMAPHORE_STRUCT_SIZE = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_SEMAPHORE_STRUCT_SIZE_FOUR_WORDS:
            fprintf(fp, "FOUR_WORDS\n");
            break;
        case NVA097_LAUNCH_DMA_SEMAPHORE_STRUCT_SIZE_ONE_WORD:
            fprintf(fp, "ONE_WORD\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 1) & ((1u << 1) - 1);
        fprintf(fp, "%s.REDUCTION_ENABLE = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_REDUCTION_ENABLE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_ENABLE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 13) & ((1u << 3) - 1);
        fprintf(fp, "%s.REDUCTION_OP = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_ADD:
            fprintf(fp, "RED_ADD\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_MIN:
            fprintf(fp, "RED_MIN\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_MAX:
            fprintf(fp, "RED_MAX\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_INC:
            fprintf(fp, "RED_INC\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_DEC:
            fprintf(fp, "RED_DEC\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_AND:
            fprintf(fp, "RED_AND\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_OR:
            fprintf(fp, "RED_OR\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_OP_RED_XOR:
            fprintf(fp, "RED_XOR\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 2) & ((1u << 2) - 1);
        fprintf(fp, "%s.REDUCTION_FORMAT = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_REDUCTION_FORMAT_UNSIGNED_32:
            fprintf(fp, "UNSIGNED_32\n");
            break;
        case NVA097_LAUNCH_DMA_REDUCTION_FORMAT_SIGNED_32:
            fprintf(fp, "SIGNED_32\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 6) & ((1u << 1) - 1);
        fprintf(fp, "%s.SYSMEMBAR_DISABLE = ", prefix);
        switch (parsed) {
        case NVA097_LAUNCH_DMA_SYSMEMBAR_DISABLE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_LAUNCH_DMA_SYSMEMBAR_DISABLE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NVA097_LOAD_INLINE_DATA:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SEMAPHORE_A:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SEMAPHORE_B:

    
        parsed = data;
        fprintf(fp, "%s.OFFSET_LOWER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SEMAPHORE_C:

    
        parsed = data;
        fprintf(fp, "%s.PAYLOAD = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SPARE_NOOP00:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SPARE_NOOP01:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SPARE_NOOP02:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_I2M_SPARE_NOOP03:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                              
    case NVA097_INVALIDATE_SHADER_CACHES:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.INSTRUCTION = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_INSTRUCTION_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_INSTRUCTION_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 1) - 1);
        fprintf(fp, "%s.DATA = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_DATA_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_DATA_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 12) & ((1u << 1) - 1);
        fprintf(fp, "%s.CONSTANT = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_CONSTANT_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_CONSTANT_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 1) & ((1u << 1) - 1);
        fprintf(fp, "%s.LOCKS = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_LOCKS_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_LOCKS_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 2) & ((1u << 1) - 1);
        fprintf(fp, "%s.FLUSH_DATA = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_FLUSH_DATA_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_FLUSH_DATA_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
                                                                                                      
    case NVA097_SET_SPA_VERSION:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.MINOR = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 8) & ((1u << 8) - 1);
        fprintf(fp, "%s.MAJOR = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                                                                                                                                                                          
    case NVA097_SET_ISBE_SAVE_RESTORE_PROGRAM:

    
        parsed = data;
        fprintf(fp, "%s.OFFSET = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                      
    case NVA097_SET_TEXTURE_INSTRUCTION_OPERAND:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.ORDERING = ", prefix);
        switch (parsed) {
        case NVA097_SET_TEXTURE_INSTRUCTION_OPERAND_ORDERING_FERMI_ORDER:
            fprintf(fp, "FERMI_ORDER\n");
            break;
        case NVA097_SET_TEXTURE_INSTRUCTION_OPERAND_ORDERING_KEPLER_ORDER:
            fprintf(fp, "KEPLER_ORDER\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
                                                                                                                                              
    case NVA097_FORCE_TRANSITION_TO_BETA:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
          
    case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.INSTRUCTION = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI_INSTRUCTION_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI_INSTRUCTION_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 1) - 1);
        fprintf(fp, "%s.GLOBAL_DATA = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI_GLOBAL_DATA_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI_GLOBAL_DATA_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 12) & ((1u << 1) - 1);
        fprintf(fp, "%s.CONSTANT = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI_CONSTANT_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_INVALIDATE_SHADER_CACHES_NO_WFI_CONSTANT_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
                                                                                                                                                                                                                                                                                                              
    case NVA097_UNBIND_ALL:

    
        parsed = (data >> 8) & ((1u << 1) - 1);
        fprintf(fp, "%s.CONSTANT_BUFFERS = ", prefix);
        switch (parsed) {
        case NVA097_UNBIND_ALL_CONSTANT_BUFFERS_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_UNBIND_ALL_CONSTANT_BUFFERS_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
                                                                                                                                                                                                                  
    case NVA097_INVALIDATE_TEXTURE_DATA_CACHE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.LINES = ", prefix);
        switch (parsed) {
        case NVA097_INVALIDATE_TEXTURE_DATA_CACHE_LINES_ALL:
            fprintf(fp, "ALL\n");
            break;
        case NVA097_INVALIDATE_TEXTURE_DATA_CACHE_LINES_ONE:
            fprintf(fp, "ONE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 22) - 1);
        fprintf(fp, "%s.TAG = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                                                                                                                                                                                                                                                                                                                              
    case NVA097_SET_CLASS_VERSION:

    
        parsed = (data >> 0) & ((1u << 16) - 1);
        fprintf(fp, "%s.CURRENT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 16) - 1);
        fprintf(fp, "%s.OLDEST_SUPPORTED = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                          
    case NVA097_SET_SHADER_CONTROL:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.DEFAULT_PARTIAL = ", prefix);
        switch (parsed) {
        case NVA097_SET_SHADER_CONTROL_DEFAULT_PARTIAL_ZERO:
            fprintf(fp, "ZERO\n");
            break;
        case NVA097_SET_SHADER_CONTROL_DEFAULT_PARTIAL_INFINITY:
            fprintf(fp, "INFINITY\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 1) & ((1u << 1) - 1);
        fprintf(fp, "%s.FP32_NAN_BEHAVIOR = ", prefix);
        switch (parsed) {
        case NVA097_SET_SHADER_CONTROL_FP32_NAN_BEHAVIOR_LEGACY:
            fprintf(fp, "LEGACY\n");
            break;
        case NVA097_SET_SHADER_CONTROL_FP32_NAN_BEHAVIOR_FP64_COMPATIBLE:
            fprintf(fp, "FP64_COMPATIBLE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 2) & ((1u << 1) - 1);
        fprintf(fp, "%s.FP32_F2I_NAN_BEHAVIOR = ", prefix);
        switch (parsed) {
        case NVA097_SET_SHADER_CONTROL_FP32_F2I_NAN_BEHAVIOR_PASS_ZERO:
            fprintf(fp, "PASS_ZERO\n");
            break;
        case NVA097_SET_SHADER_CONTROL_FP32_F2I_NAN_BEHAVIOR_PASS_INDEFINITE:
            fprintf(fp, "PASS_INDEFINITE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
      
    case NVA097_CHECK_CLASS_VERSION:

    
        parsed = (data >> 0) & ((1u << 16) - 1);
        fprintf(fp, "%s.CURRENT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 16) - 1);
        fprintf(fp, "%s.OLDEST_SUPPORTED = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                                                                                                                                                                                                                                                                  
    case NVA097_SET_REPORT_SEMAPHORE_D:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.OPERATION = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_OPERATION_RELEASE:
            fprintf(fp, "RELEASE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_OPERATION_ACQUIRE:
            fprintf(fp, "ACQUIRE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_OPERATION_REPORT_ONLY:
            fprintf(fp, "REPORT_ONLY\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_OPERATION_TRAP:
            fprintf(fp, "TRAP\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 1) - 1);
        fprintf(fp, "%s.RELEASE = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_RELEASE_AFTER_ALL_PRECEEDING_READS_COMPLETE:
            fprintf(fp, "AFTER_ALL_PRECEEDING_READS_COMPLETE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_RELEASE_AFTER_ALL_PRECEEDING_WRITES_COMPLETE:
            fprintf(fp, "AFTER_ALL_PRECEEDING_WRITES_COMPLETE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 8) & ((1u << 1) - 1);
        fprintf(fp, "%s.ACQUIRE = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_ACQUIRE_BEFORE_ANY_FOLLOWING_WRITES_START:
            fprintf(fp, "BEFORE_ANY_FOLLOWING_WRITES_START\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_ACQUIRE_BEFORE_ANY_FOLLOWING_READS_START:
            fprintf(fp, "BEFORE_ANY_FOLLOWING_READS_START\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 12) & ((1u << 4) - 1);
        fprintf(fp, "%s.PIPELINE_LOCATION = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_NONE:
            fprintf(fp, "NONE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_DATA_ASSEMBLER:
            fprintf(fp, "DATA_ASSEMBLER\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_VERTEX_SHADER:
            fprintf(fp, "VERTEX_SHADER\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_TESSELATION_INIT_SHADER:
            fprintf(fp, "TESSELATION_INIT_SHADER\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_TESSELATION_SHADER:
            fprintf(fp, "TESSELATION_SHADER\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_GEOMETRY_SHADER:
            fprintf(fp, "GEOMETRY_SHADER\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_STREAMING_OUTPUT:
            fprintf(fp, "STREAMING_OUTPUT\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_VPC:
            fprintf(fp, "VPC\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_ZCULL:
            fprintf(fp, "ZCULL\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_PIXEL_SHADER:
            fprintf(fp, "PIXEL_SHADER\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_DEPTH_TEST:
            fprintf(fp, "DEPTH_TEST\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_PIPELINE_LOCATION_ALL:
            fprintf(fp, "ALL\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 16) & ((1u << 1) - 1);
        fprintf(fp, "%s.COMPARISON = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_COMPARISON_EQ:
            fprintf(fp, "EQ\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_COMPARISON_GE:
            fprintf(fp, "GE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 20) & ((1u << 1) - 1);
        fprintf(fp, "%s.AWAKEN_ENABLE = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_AWAKEN_ENABLE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_AWAKEN_ENABLE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 23) & ((1u << 5) - 1);
        fprintf(fp, "%s.REPORT = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_NONE:
            fprintf(fp, "NONE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_DA_VERTICES_GENERATED:
            fprintf(fp, "DA_VERTICES_GENERATED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_DA_PRIMITIVES_GENERATED:
            fprintf(fp, "DA_PRIMITIVES_GENERATED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_VS_INVOCATIONS:
            fprintf(fp, "VS_INVOCATIONS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_TI_INVOCATIONS:
            fprintf(fp, "TI_INVOCATIONS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_TS_INVOCATIONS:
            fprintf(fp, "TS_INVOCATIONS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_TS_PRIMITIVES_GENERATED:
            fprintf(fp, "TS_PRIMITIVES_GENERATED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_GS_INVOCATIONS:
            fprintf(fp, "GS_INVOCATIONS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_GS_PRIMITIVES_GENERATED:
            fprintf(fp, "GS_PRIMITIVES_GENERATED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ALPHA_BETA_CLOCKS:
            fprintf(fp, "ALPHA_BETA_CLOCKS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_VTG_PRIMITIVES_OUT:
            fprintf(fp, "VTG_PRIMITIVES_OUT\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_TOTAL_STREAMING_PRIMITIVES_NEEDED_MINUS_SUCCEEDED:
            fprintf(fp, "TOTAL_STREAMING_PRIMITIVES_NEEDED_MINUS_SUCCEEDED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_STREAMING_PRIMITIVES_SUCCEEDED:
            fprintf(fp, "STREAMING_PRIMITIVES_SUCCEEDED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_STREAMING_PRIMITIVES_NEEDED:
            fprintf(fp, "STREAMING_PRIMITIVES_NEEDED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_STREAMING_PRIMITIVES_NEEDED_MINUS_SUCCEEDED:
            fprintf(fp, "STREAMING_PRIMITIVES_NEEDED_MINUS_SUCCEEDED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_STREAMING_BYTE_COUNT:
            fprintf(fp, "STREAMING_BYTE_COUNT\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_CLIPPER_INVOCATIONS:
            fprintf(fp, "CLIPPER_INVOCATIONS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_CLIPPER_PRIMITIVES_GENERATED:
            fprintf(fp, "CLIPPER_PRIMITIVES_GENERATED\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ZCULL_STATS0:
            fprintf(fp, "ZCULL_STATS0\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ZCULL_STATS1:
            fprintf(fp, "ZCULL_STATS1\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ZCULL_STATS2:
            fprintf(fp, "ZCULL_STATS2\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ZCULL_STATS3:
            fprintf(fp, "ZCULL_STATS3\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_PS_INVOCATIONS:
            fprintf(fp, "PS_INVOCATIONS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ZPASS_PIXEL_CNT:
            fprintf(fp, "ZPASS_PIXEL_CNT\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_ZPASS_PIXEL_CNT64:
            fprintf(fp, "ZPASS_PIXEL_CNT64\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_IEEE_CLEAN_COLOR_TARGET:
            fprintf(fp, "IEEE_CLEAN_COLOR_TARGET\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_IEEE_CLEAN_ZETA_TARGET:
            fprintf(fp, "IEEE_CLEAN_ZETA_TARGET\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REPORT_BOUNDING_RECTANGLE:
            fprintf(fp, "BOUNDING_RECTANGLE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 28) & ((1u << 1) - 1);
        fprintf(fp, "%s.STRUCTURE_SIZE = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_STRUCTURE_SIZE_FOUR_WORDS:
            fprintf(fp, "FOUR_WORDS\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_STRUCTURE_SIZE_ONE_WORD:
            fprintf(fp, "ONE_WORD\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 5) & ((1u << 3) - 1);
        fprintf(fp, "%s.SUB_REPORT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 21) & ((1u << 1) - 1);
        fprintf(fp, "%s.REPORT_DWORD_NUMBER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 2) & ((1u << 1) - 1);
        fprintf(fp, "%s.FLUSH_DISABLE = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_FLUSH_DISABLE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_FLUSH_DISABLE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 3) & ((1u << 1) - 1);
        fprintf(fp, "%s.REDUCTION_ENABLE = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_ENABLE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_ENABLE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 9) & ((1u << 3) - 1);
        fprintf(fp, "%s.REDUCTION_OP = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_ADD:
            fprintf(fp, "RED_ADD\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_MIN:
            fprintf(fp, "RED_MIN\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_MAX:
            fprintf(fp, "RED_MAX\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_INC:
            fprintf(fp, "RED_INC\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_DEC:
            fprintf(fp, "RED_DEC\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_AND:
            fprintf(fp, "RED_AND\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_OR:
            fprintf(fp, "RED_OR\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_OP_RED_XOR:
            fprintf(fp, "RED_XOR\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 17) & ((1u << 2) - 1);
        fprintf(fp, "%s.REDUCTION_FORMAT = ", prefix);
        switch (parsed) {
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_FORMAT_UNSIGNED_32:
            fprintf(fp, "UNSIGNED_32\n");
            break;
        case NVA097_SET_REPORT_SEMAPHORE_D_REDUCTION_FORMAT_SIGNED_32:
            fprintf(fp, "SIGNED_32\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
                                                                                                                                                                                                                                                                                              
    case NVA097_NOOP_X_X_X_SET_VALVE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.HIGHER_PRIORITY = ", prefix);
        switch (parsed) {
        case NVA097_NOOP_X_X_X_SET_VALVE_HIGHER_PRIORITY_COMPUTE:
            fprintf(fp, "COMPUTE\n");
            break;
        case NVA097_NOOP_X_X_X_SET_VALVE_HIGHER_PRIORITY_GRAPHICS:
            fprintf(fp, "GRAPHICS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NVA097_SET_BINDLESS_TEXTURE:

    
        parsed = (data >> 0) & ((1u << 5) - 1);
        fprintf(fp, "%s.CONSTANT_BUFFER_SLOT_SELECT = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_TRAP_HANDLER:

    
        parsed = data;
        fprintf(fp, "%s.OFFSET = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
          
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(0):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(1):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(2):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(3):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(4):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(5):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(6):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_A(7):

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.EVENT0 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 2) & ((1u << 3) - 1);
        fprintf(fp, "%s.BIT_SELECT0 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 5) & ((1u << 2) - 1);
        fprintf(fp, "%s.EVENT1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 7) & ((1u << 3) - 1);
        fprintf(fp, "%s.BIT_SELECT1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 10) & ((1u << 2) - 1);
        fprintf(fp, "%s.EVENT2 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 12) & ((1u << 3) - 1);
        fprintf(fp, "%s.BIT_SELECT2 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 15) & ((1u << 2) - 1);
        fprintf(fp, "%s.EVENT3 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 17) & ((1u << 3) - 1);
        fprintf(fp, "%s.BIT_SELECT3 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 20) & ((1u << 2) - 1);
        fprintf(fp, "%s.EVENT4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 22) & ((1u << 3) - 1);
        fprintf(fp, "%s.BIT_SELECT4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 25) & ((1u << 2) - 1);
        fprintf(fp, "%s.EVENT5 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 27) & ((1u << 3) - 1);
        fprintf(fp, "%s.BIT_SELECT5 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 30) & ((1u << 2) - 1);
        fprintf(fp, "%s.SPARE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(0):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(1):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(2):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(3):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(4):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(5):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(6):
    case NVA097_SET_SHADER_PERFORMANCE_COUNTER_CONTROL_B(7):

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.EDGE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 1) & ((1u << 2) - 1);
        fprintf(fp, "%s.MODE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 3) & ((1u << 1) - 1);
        fprintf(fp, "%s.WINDOWED = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 4) & ((1u << 16) - 1);
        fprintf(fp, "%s.FUNC = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                    default:
        fprintf(fp, "%s.VALUE = 0x%x\n", prefix, data);
        break;
    }
}
